---------------------------------------------------
-- This script upgrade MI 3.2.5.1 database to v 3.7
-- 1/10/2007
---------------------------------------------------


USE [WaspTrackInventory]


print ''
print '------------------------------------'
print '-- .. Create Data Types    '
print '------------------------------------'

if not exists (select * from systypes where name = 'description_type')
BEGIN
	EXEC sp_addtype N'description_type', N'varchar (255)', N'not null'
END

if not exists (select * from systypes where name = 'phone_type')
BEGIN
	EXEC sp_addtype N'phone_type', N'varchar (20)', N'null'
END

if not exists (select * from systypes where name = 'qb_list_id')
BEGIN
	EXEC sp_addtype N'qb_list_id', N'varchar (36)', N'null'
END

if not exists (select * from systypes where name = 'record_status_type')
BEGIN
	EXEC sp_addtype N'record_status_type', N'smallint', N'not null'
END

if not exists (select * from systypes where name = 'wtbool')
BEGIN
	EXEC sp_addtype N'wtbool', N'char (1)', N'not null'
END

if not exists (select * from systypes where name = 'wtpassword')
BEGIN
	EXEC sp_addtype N'wtpassword', N'varchar (20)', N'null'
END

GO


print ''
print '------------------------------------'
print '-- ..  Create New Tables'
print '------------------------------------'


SET QUOTED_IDENTIFIER OFF 
SET ANSI_NULLS ON 

if NOT EXISTS (select * from dbo.syscolumns where name = 'address3' and id = object_id(N'[dbo].[address]'))
BEGIN
ALTER TABLE [dbo].[address] ADD 
	[address3] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[address4] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
END

GO

if EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[asset_transactions]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	DROP TABLE [dbo].[asset_transactions]
	
GO

if NOT EXISTS (select * from dbo.syscolumns where name = 'po_id' and id = object_id(N'[dbo].[audit_transactions]'))
BEGIN
ALTER TABLE [dbo].[audit_transactions] ADD
	[po_id] [int] NULL ,
	[invoice_id] [int] NULL ,
	[adjust_trans_code] [varchar] (25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
	
ALTER TABLE [dbo].[audit_transactions] WITH NOCHECK ADD 
	CONSTRAINT [DF_audit_transactions_po_id] DEFAULT (0) FOR [po_id],
	CONSTRAINT [DF_audit_transactions_invoice_id] DEFAULT (0) FOR [invoice_id]
END	


GO

print '------'
print '[form_field_meta]'

if NOT EXISTS (select * from dbo.syscolumns where name = 'should_find' 
	and id = object_id(N'[dbo].[form_field_meta]'))
BEGIN

ALTER TABLE [dbo].[form_field_meta] ADD 
	[should_find] [char] (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF_form_field_meta_should_find_1] DEFAULT ('T'),
	[should_export] [char] (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF_form_field_meta_should_export_1] DEFAULT (1),
	[should_import] [char] (1) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF_form_field_meta_should_import_1] DEFAULT (1)
	
END



GO

if NOT EXISTS (select * from dbo.syscolumns where name = 'allow_shorting' and id = object_id(N'[dbo].[customer]'))
BEGIN

ALTER TABLE [dbo].[customer] ADD 
	[allow_shorting] [wtbool] NULL ,
	[list_id] [qb_list_id] NULL 
	
CREATE  INDEX [IX_customer_list_id] ON [dbo].[customer]([list_id]) ON [PRIMARY]
	
END	


GO


if NOT EXISTS (select * from dbo.syscolumns where name = 'line_item_id' and id = object_id(N'[dbo].[history_transactions]'))
BEGIN
ALTER TABLE [dbo].[history_transactions] ADD
	[line_item_id] [int] NULL ,
	[adjust_type] [char] (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[po_id] [int] NULL ,
	[invoice_id] [int] NULL ,
	[adjust_reason_id] [int] NULL ,
	[print_label_no] [int] NULL ,
	[adjust_trans_code] [varchar] (25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
	
ALTER TABLE [dbo].[history_transactions] WITH NOCHECK ADD 
	CONSTRAINT [DF_history_transactions_po_id] DEFAULT (0) FOR [po_id],
	CONSTRAINT [DF_history_transactions_invoice_id] DEFAULT (0) FOR [invoice_id],
	CONSTRAINT [DF_history_transactions_print_label_no] DEFAULT (0) FOR [print_label_no]
END	


if EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[import_export_errors]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	DROP TABLE [dbo].[import_export_errors]

CREATE TABLE [dbo].[import_export_errors] (
	[id] [int] IDENTITY (1, 1) NOT NULL ,
	[process_id] [int] NOT NULL ,
	[original_data] [varchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[error_number] [varchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[error_description] [varchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[internal_id] [int] NULL ,
	[dvalue] [decimal](18, 4) NULL 
) ON [PRIMARY]

	
if NOT EXISTS (select * from dbo.syscolumns where name = 'max_stock_level' 
	and id = object_id(N'[dbo].[inventory]'))
BEGIN
ALTER TABLE [dbo].[inventory] ADD 
	[max_stock_level] [decimal](18, 4) NOT NULL DEFAULT(0),
	[min_stock_level] [decimal](18, 4) NOT NULL DEFAULT(0),
	[reorder_qty] [decimal](18, 4) NOT NULL DEFAULT(0)
END		
	
if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[inventory_request]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[inventory_request] (
	[inventory_request_id] [int] IDENTITY (1, 1) NOT NULL ,
	[request_number] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[creation_date] [datetime] NULL ,
	[last_modified_date] [datetime] NULL ,
	[due_date] [datetime] NULL ,
	[ship_date] [datetime] NULL ,
	[request_status] [int] NOT NULL ,
	[customer_id] [int] NULL ,
	[carrier] [varchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[tracking_number] [varchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[staging_location_id] [int] NULL ,
	[is_canceled] [wtbool] NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[line_item_count] [int] NOT NULL ,
	[parent_id] [int] NOT NULL ,
	[backorder_id] [int] NOT NULL ,
	[is_printed] [wtbool] NULL ,
	[print_no] [int] NOT NULL ,
	[last_printed_date] [datetime] NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[inventory_request] WITH NOCHECK ADD 
	CONSTRAINT [DF_inventory_request_is_canceled] DEFAULT ('F') FOR [is_canceled],
	CONSTRAINT [DF_inventory_request_print_no] DEFAULT (0) FOR [print_no]

END

if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[inventory_request_detail]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[inventory_request_detail] (
	[inventory_request_line_item_id] [int] NOT NULL ,
	[site] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[location] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[is_selected] [wtbool] NOT NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[inventory_request_detail] WITH NOCHECK ADD 
	CONSTRAINT [PK_inventory_request_detail] PRIMARY KEY  CLUSTERED 
	(
		[inventory_request_line_item_id],
		[site],
		[location]
	)  ON [PRIMARY] 
	
ALTER TABLE [dbo].[inventory_request_detail] WITH NOCHECK ADD 
	CONSTRAINT [DF_inventory_request_detail_is_selected] DEFAULT ('F') FOR [is_selected]
	
END

if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[inventory_request_line_item]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[inventory_request_line_item] (
	[line_item_id] [int] IDENTITY (1, 1) NOT NULL ,
	[inventory_request_id] [int] NOT NULL ,
	[item_id] [int] NOT NULL ,
	[request_quantity] [decimal](15, 4) NOT NULL ,
	[picked_quantity] [decimal](15, 4) NOT NULL ,
	[shipped_quantity] [decimal](15, 4) NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[backorder] [wtbool] NULL 
) ON [PRIMARY]

END

if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[inventory_request_manual_line]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[inventory_request_manual_line] (
	[manual_line_id] [int] IDENTITY (1, 1) NOT NULL ,
	[inventory_request_id] [int] NOT NULL ,
	[item_number] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[description] [varchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[date_acquired] [datetime] NULL ,
	[cost] [money] NOT NULL ,
	[quantity] [decimal](15, 4) NOT NULL ,
	[picked_quantity] [decimal](15, 4) NOT NULL ,
	[shipped_quantity] [decimal](15, 4) NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[inventory_request_manual_line] WITH NOCHECK ADD 
	CONSTRAINT [PK_inventory_request_manual_line] PRIMARY KEY  CLUSTERED 
	(
		[manual_line_id]
	)  ON [PRIMARY] 
	
ALTER TABLE [dbo].[inventory_request_manual_line] WITH NOCHECK ADD 
	CONSTRAINT [DF_inventory_request_manual_line_cost] DEFAULT (0) FOR [cost],
	CONSTRAINT [DF_inventory_request_manual_line_quantity] DEFAULT (0) FOR [quantity]
	
END

if EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[inventory_temp]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	DROP TABLE [dbo].[inventory_temp]

CREATE TABLE [dbo].[inventory_temp] (
	[item_number] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[item_desc] [varchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[site_name] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[code] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[pallet] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[lot] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[po] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[date_code] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[serial_number] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[quantity] [decimal](18, 0) NULL ,
	[supplier_number] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[date_acquired] [datetime] NULL ,
	[min_stock_level] [decimal](18, 0) NULL ,
	[max_stock_level] [decimal](18, 0) NULL ,
	[reorder_qty] [decimal](18, 0) NULL 
) ON [PRIMARY]


if NOT EXISTS (select * from dbo.syscolumns where name = 'line_item_id' 
	and id = object_id(N'[dbo].[inventory_transactions]'))
BEGIN

ALTER TABLE [dbo].[inventory_transactions] ADD 
	[line_item_id] [int] NULL ,
	[adjust_type] [char] (1) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[po_id] [int] NOT NULL DEFAULT(0),
	[invoice_id] [int] NOT NULL DEFAULT(0),
	[adjust_reason_id] [int] NULL ,
	[print_label_no] [int] NULL ,
	[adjust_trans_code] [varchar] (25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
	
CREATE  INDEX [IX_TRANS_PO] ON [dbo].[inventory_transactions]([po]) ON [PRIMARY]

CREATE  INDEX [IX_TRANS_INVOICE_ID] ON [dbo].[inventory_transactions]([invoice_id]) ON [PRIMARY]
	
END

if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[invoice_line_items]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[invoice_line_items] (
	[line_item_id] [int] IDENTITY (1, 1) NOT NULL ,
	[txn_line_id] [qb_list_id] NULL ,
	[invoice_id] [int] NOT NULL ,
	[item_id] [int] NOT NULL ,
	[quantity] [decimal](18, 4) NOT NULL ,
	[picked_quantity] [decimal](18, 4) NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[amount] [decimal](18, 4) NOT NULL ,
	[backorder] [wtbool] NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[invoice_line_items] WITH NOCHECK ADD 
	CONSTRAINT [PK_invoice_line_items] PRIMARY KEY  CLUSTERED 
	(
		[line_item_id]
	)  ON [PRIMARY] 
	
ALTER TABLE [dbo].[invoice_line_items] WITH NOCHECK ADD 
	CONSTRAINT [DF_invoice_line_items_picked_quantity] DEFAULT (0) FOR [picked_quantity],
	CONSTRAINT [DF_invoice_line_items_amount] DEFAULT (0) FOR [amount]
	
END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[invoice_line_items_archive]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[invoice_line_items_archive] (
	[line_item_id] [int] NOT NULL ,
	[txn_line_id] [qb_list_id] NULL ,
	[invoice_id] [int] NOT NULL ,
	[item_id] [int] NOT NULL ,
	[quantity] [decimal](18, 4) NOT NULL ,
	[picked_quantity] [decimal](18, 4) NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[amount] [decimal](18, 4) NOT NULL ,
	[backorder] [wtbool] NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[invoice_line_items_archive] WITH NOCHECK ADD 
	CONSTRAINT [PK_invoice_line_items_archive] PRIMARY KEY  CLUSTERED 
	(
		[line_item_id]
	)  ON [PRIMARY] 

ALTER TABLE [dbo].[invoice_line_items_archive] WITH NOCHECK ADD 
	CONSTRAINT [DF_invoice_line_items_archive_picked_quantity] DEFAULT (0) FOR [picked_quantity],
	CONSTRAINT [DF_invoice_line_items_archive_amount] DEFAULT (0) FOR [amount]

CREATE  INDEX [IX_invoice_line_items_archive_invoice_Id] ON [dbo].[invoice_line_items_archive]([invoice_id]) ON [PRIMARY]

END

if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[invoice_master]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[invoice_master] (
	[invoice_id] [int] IDENTITY (1, 1) NOT NULL ,
	[ref_number] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[customer_id] [int] NULL ,
	[is_pending] [wtbool] NULL ,
	[txn_id] [qb_list_id] NOT NULL ,
	[txn_number] [int] NOT NULL ,
	[due_date] [datetime] NULL ,
	[invoice_status] [int] NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[edit_sequence] [varchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[line_item_count] [int] NOT NULL ,
	[parent_id] [int] NOT NULL ,
	[backorder_id] [int] NOT NULL ,
	[po_number] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[is_printed] [wtbool] NULL ,
	[date_printed] [datetime] NULL ,
	[has_error] [wtbool] NULL ,
	[record_status_date] [datetime] NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[invoice_master] WITH NOCHECK ADD 
	CONSTRAINT [PK_invoice_master] PRIMARY KEY  CLUSTERED 
	(
		[invoice_id]
	)  ON [PRIMARY] 

ALTER TABLE [dbo].[invoice_master] WITH NOCHECK ADD 
	CONSTRAINT [DF_invoice_master_invoice_status] DEFAULT (1) FOR [invoice_status],
	CONSTRAINT [DF_invoice_master_line_item_count] DEFAULT (0) FOR [line_item_count],
	CONSTRAINT [DF_invoice_master_parent_id] DEFAULT (0) FOR [parent_id],
	CONSTRAINT [DF_invoice_master_backorder_id] DEFAULT (0) FOR [backorder_id],
	CONSTRAINT [DF_invoice_master_record_status_date] DEFAULT (getdate()) FOR [record_status_date]

CREATE  INDEX [IX_invoice_master_ref_number] ON [dbo].[invoice_master]([ref_number]) ON [PRIMARY]

END

if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[invoice_master_archive]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[invoice_master_archive] (
	[invoice_id] [int] NOT NULL ,
	[ref_number] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[customer_id] [int] NULL ,
	[is_pending] [wtbool] NULL ,
	[txn_id] [qb_list_id] NOT NULL ,
	[txn_number] [int] NOT NULL ,
	[due_date] [datetime] NULL ,
	[invoice_status] [int] NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[edit_sequence] [varchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[line_item_count] [int] NOT NULL ,
	[parent_id] [int] NOT NULL ,
	[backorder_id] [int] NOT NULL ,
	[po_number] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[is_printed] [wtbool] NULL ,
	[date_printed] [datetime] NULL ,
	[has_error] [wtbool] NULL ,
	[record_status_date] [datetime] NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[invoice_master_archive] WITH NOCHECK ADD 
	CONSTRAINT [PK_invoice_master_archive] PRIMARY KEY  CLUSTERED 
	(
		[invoice_id]
	)  ON [PRIMARY] 
	
ALTER TABLE [dbo].[invoice_master_archive] WITH NOCHECK ADD 
	CONSTRAINT [DF_invoice_master_archive_invoice_status] DEFAULT (1) FOR [invoice_status],
	CONSTRAINT [DF_invoice_master_archive_line_item_count] DEFAULT (0) FOR [line_item_count],
	CONSTRAINT [DF_invoice_master_archive_parent_id] DEFAULT (0) FOR [parent_id],
	CONSTRAINT [DF_invoice_master_archive_backorder_id] DEFAULT (0) FOR [backorder_id]

END

if NOT EXISTS (select * from dbo.syscolumns where name = 'default_location_id' 
	and id = object_id(N'[dbo].[item]'))
BEGIN

ALTER TABLE [dbo].[item] ADD 
	[default_location_id] [int] NOT NULL DEFAULT(0),
	[list_id] [qb_list_id] NULL ,
	[date_updated] [datetime] NULL ,
	[auto_sn] [wtbool] NULL ,
	[auto_sn_value] [numeric](18, 0) NULL 
	
ALTER TABLE [dbo].[item] WITH NOCHECK ADD 
	CONSTRAINT [DF_item_auto_sn] DEFAULT ('F') FOR [auto_sn],
	CONSTRAINT [DF_item_auto_sn_value] DEFAULT (0) FOR [auto_sn_value]	

CREATE  INDEX [IX_Item_ListId] ON [dbo].[item]([list_id]) ON [PRIMARY]

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[label_names]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[label_names] (
	[lbl_id] [int] NULL ,
	[lbl_type] [int] NULL ,
	[lbl_display_order] [int] NULL ,
	[lbl_name] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[lbl_file_name] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[lbl_default_name] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[lbl_tool_tips] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]
END

if NOT EXISTS (select * from dbo.syscolumns where name = 'note_date' 
	and id = object_id(N'[dbo].[notes]'))
BEGIN
ALTER TABLE [dbo].[notes] ADD 
	[note_date] [datetime] NULL ,
	[note_user_ID] [int] NULL 
END

ALTER TABLE [dbo].[notes]
	ALTER COLUMN [note_text] [varchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL

if EXISTS (select * from dbo.sysobjects where name = N'PK_notes')
BEGIN
   ALTER TABLE [dbo].[notes] DROP CONSTRAINT [PK_notes] 
END

if EXISTS (select * from dbo.sysobjects where name = N'DF_notes_note_date')
BEGIN
   ALTER TABLE [dbo].[notes] DROP CONSTRAINT [DF_notes_note_date] 
END

if EXISTS (select * from dbo.sysobjects where name = N'DF_notes_note_user_id')
BEGIN
   ALTER TABLE [dbo].[notes] DROP CONSTRAINT [DF_notes_note_user_id] 
END
	
ALTER TABLE [dbo].[notes] WITH NOCHECK ADD 
	CONSTRAINT [DF_notes_note_date] DEFAULT (getdate()) FOR [note_date],
	CONSTRAINT [DF_notes_note_user_id] DEFAULT (0) FOR [note_user_id]

if NOT EXISTS (select * from dbo.sysindexes where name = N'IX_notes')
BEGIN
   CREATE  INDEX [IX_notes] ON [dbo].[notes]([note_id], [table_name]) ON [PRIMARY]
END

if EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[notesmulti]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
   DROP TABLE [dbo].[notesmulti]
END

if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[po_invoice_status]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[po_invoice_status] (
	[status_id] [int] NOT NULL ,
	[description] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[po_invoice_status] WITH NOCHECK ADD 
	CONSTRAINT [PK_po_invoice_status] PRIMARY KEY  CLUSTERED 
	(
		[status_id]
	)  ON [PRIMARY] 
END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[po_line_item]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[po_line_item] (
	[line_item_id] [int] IDENTITY (1, 1) NOT NULL ,
	[txn_line_id] [qb_list_id] NULL ,
	[purchase_order_id] [int] NOT NULL ,
	[item_id] [int] NOT NULL ,
	[quantity] [decimal](18, 4) NOT NULL ,
	[quantity_received] [decimal](18, 4) NOT NULL ,
	[quantity_reported] [decimal](18, 4) NOT NULL ,
	[quantity_original] [decimal](18, 4) NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[company_id] [int] NOT NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[po_line_item] WITH NOCHECK ADD 
	CONSTRAINT [PK_po_line_item] PRIMARY KEY  CLUSTERED 
	(
		[line_item_id]
	)  ON [PRIMARY] 

ALTER TABLE [dbo].[po_line_item] WITH NOCHECK ADD 
	CONSTRAINT [DF_po_line_item_quantity] DEFAULT (0) FOR [quantity],
	CONSTRAINT [DF_po_line_item_picked_quantity] DEFAULT (0) FOR [quantity_received],
	CONSTRAINT [DF_po_line_item_quantity_reported] DEFAULT (0) FOR [quantity_reported],
	CONSTRAINT [DF_po_line_item_quantity_original] DEFAULT (0) FOR [quantity_original]

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[po_line_item_archive]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[po_line_item_archive] (
	[line_item_id] [int] NOT NULL ,
	[txn_line_id] [qb_list_id] NULL ,
	[purchase_order_id] [int] NOT NULL ,
	[item_id] [int] NOT NULL ,
	[quantity] [decimal](18, 4) NOT NULL ,
	[quantity_received] [decimal](18, 4) NOT NULL ,
	[quantity_reported] [decimal](18, 4) NOT NULL ,
	[quantity_original] [decimal](18, 4) NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[company_id] [int] NOT NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[po_line_item_archive] WITH NOCHECK ADD 
	CONSTRAINT [PK_po_line_item_archive] PRIMARY KEY  CLUSTERED 
	(
		[line_item_id]
	)  ON [PRIMARY] 

ALTER TABLE [dbo].[po_line_item_archive] WITH NOCHECK ADD 
	CONSTRAINT [DF_po_line_item_archive_quantity] DEFAULT (0) FOR [quantity],
	CONSTRAINT [DF_po_line_item_archive_picked_quantity] DEFAULT (0) FOR [quantity_received],
	CONSTRAINT [DF_po_line_item_archive_quantity_reported] DEFAULT (0) FOR [quantity_reported],
	CONSTRAINT [DF_po_line_item_archive_quantity_original] DEFAULT (0) FOR [quantity_original]

CREATE  INDEX [IX_po_line_item_archive_po_id] ON [dbo].[po_line_item_archive]([purchase_order_id]) ON [PRIMARY]

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[purchase_orders]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[purchase_orders] (
	[purchase_order_id] [int] IDENTITY (1, 1) NOT NULL ,
	[po_type] [varchar] (10) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[ref_number] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[vendor_id] [int] NULL ,
	[customer_id] [int] NULL ,
	[txn_id] [qb_list_id] NOT NULL ,
	[txn_number] [int] NULL ,
	[due_date] [datetime] NULL ,
	[po_status] [int] NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[edit_sequence] [varchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[line_item_count] [int] NOT NULL ,
	[record_status_date] [datetime] NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[purchase_orders] WITH NOCHECK ADD 
	CONSTRAINT [DF_purchase_orders_po_type] DEFAULT ('PO') FOR [po_type],
	CONSTRAINT [DF_purchase_orders_po_status] DEFAULT (1) FOR [po_status],
	CONSTRAINT [DF_purchase_orders_line_item_count] DEFAULT (0) FOR [line_item_count],
	CONSTRAINT [DF_purchase_orders_record_status_date] DEFAULT (getdate()) FOR [record_status_date]

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[purchase_orders_archive]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[purchase_orders_archive] (
	[purchase_order_id] [int] NOT NULL ,
	[po_type] [varchar] (10) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[ref_number] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[vendor_id] [int] NULL ,
	[customer_id] [int] NULL ,
	[txn_id] [qb_list_id] NOT NULL ,
	[txn_number] [int] NULL ,
	[due_date] [datetime] NULL ,
	[po_status] [int] NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL ,
	[edit_sequence] [varchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[line_item_count] [int] NOT NULL ,
	[record_status_date] [datetime] NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[purchase_orders_archive] WITH NOCHECK ADD 
	CONSTRAINT [DF_purchase_orders_archive_po_type] DEFAULT ('PO') FOR [po_type],
	CONSTRAINT [DF_purchase_orders_archive_po_status] DEFAULT (1) FOR [po_status],
	CONSTRAINT [DF_purchase_orders_archive_line_item_count] DEFAULT (0) FOR [line_item_count]

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[reasons_adjustment]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[reasons_adjustment] (
	[reason_id] [int] IDENTITY (1, 1) NOT NULL ,
	[sort_order] [int] NULL ,
	[adjust_code] [varchar] (30) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[description] [varchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[calculation_method] [int] NOT NULL ,
	[company_id] [int] NOT NULL ,
	[record_status] [record_status_type] NOT NULL 
) ON [PRIMARY]

ALTER TABLE [dbo].[reasons_adjustment] WITH NOCHECK ADD 
	CONSTRAINT [PK_reasons_adjustment] PRIMARY KEY  CLUSTERED 
	(
		[reason_id]
	)  ON [PRIMARY] 

ALTER TABLE [dbo].[reasons_adjustment] WITH NOCHECK ADD 
	CONSTRAINT [DF_reasons_adjustment_calculation_method] DEFAULT (1) FOR [calculation_method]

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[record_status]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN

CREATE TABLE [dbo].[record_status] (
	[status_id] [smallint] NOT NULL ,
	[description] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]

insert into record_status (status_id,description) values (1,'Active');
insert into record_status (status_id,description) values (2,'Inactive');
insert into record_status (status_id,description) values (3,'Delete');
insert into record_status (status_id,description) values (4,'Pending');

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[report_filters]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[report_filters] (
	[rpt_id] [int] NOT NULL ,
	[rpt_filter_index] [int] NOT NULL ,
	[rpt_filter_name] [char] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[rpt_filter_name_show] [char] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]
END



if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[report_hidden_fields]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[report_hidden_fields] (
	[hidden_fields] [char] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]

insert into report_hidden_fields (hidden_fields) values ('action_type                                       ');
insert into report_hidden_fields (hidden_fields) values ('category_id                                       ');
insert into report_hidden_fields (hidden_fields) values ('Company_id                                        ');
insert into report_hidden_fields (hidden_fields) values ('Customer_id                                       ');
insert into report_hidden_fields (hidden_fields) values ('inventory_id                                      ');
insert into report_hidden_fields (hidden_fields) values ('item_id                                           ');
insert into report_hidden_fields (hidden_fields) values ('location_id                                       ');
insert into report_hidden_fields (hidden_fields) values ('manufacturer_id                                   ');
insert into report_hidden_fields (hidden_fields) values ('other_id                                          ');
insert into report_hidden_fields (hidden_fields) values ('phone_id                                          ');
insert into report_hidden_fields (hidden_fields) values ('record_source                                     ');
insert into report_hidden_fields (hidden_fields) values ('record_status                                     ');
insert into report_hidden_fields (hidden_fields) values ('record_type                                       ');
insert into report_hidden_fields (hidden_fields) values ('site_id                                           ');
insert into report_hidden_fields (hidden_fields) values ('supplier_id                                       ');
insert into report_hidden_fields (hidden_fields) values ('trans_type                                        ');
insert into report_hidden_fields (hidden_fields) values ('transaction_id                                    ');
insert into report_hidden_fields (hidden_fields) values ('update_user_id                                    ');
insert into report_hidden_fields (hidden_fields) values ('user_id                                           ');

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[report_label_types]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[report_label_types] (
	[type_id] [int] NULL ,
	[type_display_order] [int] NULL ,
	[type_name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[type_default_name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]

insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (1,4,'Item Reports','Item Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (2,5,'Inventory Reports','Inventory Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (3,6,'Location Reports','Location Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (4,7,'Customer Reports','Customer Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (5,8,'Check-out Reports','Check-out Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (6,9,'Transaction Reports','Transaction Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (7,2,'Invoice Pick Reports','Invoice Pick Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (8,3,'Item Receipt Reports','Item Receipt Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (10,11,'Other Reports','Other Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (11,10,'Audit Reports','Audit Reports');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (1001,1,'Labels','Labels');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (1002,2,'Tags','Tags');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (1003,-3,'Badges','Badges');
insert into report_label_types (type_id,type_display_order,type_name,type_default_name) values (1010,10,'Other Labels','Other Labels');

END



if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[report_labels]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[report_labels] (
	[rpt_id] [int] NULL ,
	[db_field_report] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[rpt_label] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[rpt_label2] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[form_id] [int] NULL ,
	[db_field] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[field] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]

insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (101,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (101,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (101,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (101,'avgcost',null,'Item',6,'avgcost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (101,'category_description',null,'Category',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (101,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (101,'manufacturer_name',null,'Manufacturer',6,'manufacturer',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (102,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (102,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (102,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (102,'avgcost',null,'Item',6,'avgcost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (102,'category_description',null,'Category',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (102,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (102,'manufacturer_name',null,'Manufacturer',6,'manufacturer',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (103,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'quantity',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'max_stock_level',null,'Item',6,'max_stock_level',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'min_stock_level',null,'vTotalInventorySummary',6,'min_stock_level',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'reorder_qty',null,'vTotalInventorySummary',6,'reorder_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (104,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (105,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (105,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'entry_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'moveto_site_name',null,'Move to',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (108,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (109,'quantity',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (105,'quantity',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (105,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (105,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'current_quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (106,'current_quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'max_stock_level',null,'Item',6,'max_stock_level',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'current_quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'max_stock_level',null,'Item',6,'max_stock_level',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (107,'current_quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (109,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (109,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'phone_number',null,'Customer',4,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'fax',null,'Customer',4,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'cfax',null,'Supplier',9,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'city',null,'Customer',4,'city',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'postal_code',null,'Customer',4,'postal_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'country',null,'Customer',4,'country',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'supplierStatus',null,'vSupplierBillingAddress',0,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'city',null,'Customer',4,'city',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (111,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (111,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (111,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (111,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (111,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (111,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'CheckedoutQty',null,'Item',6,'qty_checked_out',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (201,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (202,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (202,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (202,'description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (202,'quantity',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (202,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (202,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (202,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (203,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (203,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (203,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (203,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (203,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (203,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (203,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (112,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'remaining_quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (204,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'trans_date',null,'Inventory',90000,'adjust_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'current_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'first_name',null,'User',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'adjust_type',null,'Inventory',13,'adjust_type',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (205,'adjust_code',null,'Adjust Reason',21,'adjust_reason',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'po',null,'Inventory',11,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (206,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (207,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (207,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (207,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (207,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (207,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (207,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (208,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (208,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (208,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (208,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (208,'birth_date',null,'Birth',90000,'date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (208,'qty',null,'Inventory',90000,'received_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (208,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'qtyActive',null,'vInventoryAgingInfo',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'qtySlow',null,'vInventoryAgingInfo',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'qtyInActive',null,'vInventoryAgingInfo',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (209,'qtyObsolete',null,'vInventoryAgingInfo',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (210,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (210,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (210,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (210,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (210,'birth_date',null,'Birth',13,'date_acquired',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (210,'qty',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (112,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (211,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (211,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (211,'quantity',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (211,'min_stock_level',null,'vTotalInventorySummary',6,'min_stock_level',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (211,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (211,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (301,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'email',null,'Customer',4,'email',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'date_added',null,'Customer',4,'date_added',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'phone_number','Phone Number','Customer',4,null,'phone_number');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'extension',null,'Customer',4,'extension',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'fax','Fax','Customer',4,null,'fax');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'hphone','Home Phone','Customer',4,null,'Home Phone');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'ccell','Cell Phone','Customer',4,null,'Cell Phone');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'address1',null,'Customer',4,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'address2',null,'Customer',4,'address2',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'city',null,'Customer',4,'city',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'state',null,'Customer',4,'state',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'postal_code',null,'Customer',4,'postal_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (401,'country',null,'Customer',4,'country',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'email',null,'Customer',4,'email',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'date_added',null,'Customer',4,'date_added',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'phone_number','Phone Number','Customer',4,null,'phone_number');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'extension',null,'Customer',4,'extension',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'fax','Fax','Customer',4,null,'fax');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'hphone','Home Phone','Customer',4,null,'Home Number');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'ccell','Cell Phone','Customer',4,null,'Cell Number');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'address1',null,'Customer',4,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'address2',null,'Customer',4,'address2',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'city',null,'Customer',4,'city',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'state',null,'Customer',4,'state',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'postal_code',null,'Customer',4,'postal_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (402,'country',null,'Customer',4,'country',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'email',null,'Customer',4,'email',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'date_added',null,'Customer',4,'date_added',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'phone_number','Phone Number','Customer',4,null,'phone_number');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'extension',null,'Customer',4,'extension',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'fax','Fax','Customer',4,null,'fax');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'hphone','Home Phone','Customer',4,null,'Home Phone');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'ccell','Cell Phone','Customer',4,null,'Cell Phone');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'address1',null,'Customer',4,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'address2',null,'Customer',4,'address2',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'city',null,'Customer',4,'city',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'state',null,'Customer',4,'state',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'postal_code',null,'Customer',4,'postal_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (403,'country',null,'Customer',4,'country',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'email',null,'Customer',4,'email',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'date_added',null,'Customer',4,'date_added',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'phone_number',null,'Customer',4,null,'phone_number');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'extension',null,'Customer',4,'extension',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'fax',null,'Customer',4,null,'fax');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'hphone',null,'Customer',4,null,'Home Phone');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'ccell',null,'Customer',4,null,'Cell Phone');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'address1',null,'Customer',4,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'address2',null,'Customer',4,'address2',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'city',null,'Customer',4,'city',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'state',null,'Customer',4,'state',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'postal_code',null,'Customer',4,'postal_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (404,'country',null,'Customer',4,'country',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (405,'trans_date',null,'Inventory',90000,'remove_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (405,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (405,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (405,'customer_name',null,'Customer',4,'name0000',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (405,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (405,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (405,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (406,'item_des',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (406,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (406,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (406,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (406,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (406,'customer_name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'trans_date',null,'Inventory',90000,'out_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'date_acquired',null,'Inventory',90000,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'remaining_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (501,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (502,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (502,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (502,'trans_date',null,'Inventory',90000,'out_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (502,'date_acquired',null,'Inventory',90000,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (502,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (502,'remaining_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (502,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'trans_date',null,'Inventory',90000,'out_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'date_acquired',null,'Inventory',90000,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'remaining_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (503,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (504,'trans_date',null,'Inventory',90000,'out_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (504,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (504,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (504,'date_acquired',null,'Inventory',90000,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (504,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (504,'remaining_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (504,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'remaining_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'date_acquired',null,'Inventory',90000,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'trans_date',null,'Inventory',90000,'out_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (505,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (112,'avgcost',null,'Item',6,'avgcost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'date_acquired',null,'Inventory',90000,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'remaining_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (506,'trans_date',null,'Inventory',90000,'out_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'first_name',null,'User',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'last_name','Last Name','User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'po',null,'Inventory',11,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'date_acquired',null,'Inventory',13,'date_acquired',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'date_acquired',null,'Inventory',13,'date_acquired',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (601,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'first_name',null,'User',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'date_acquired',null,'Inventory',13,'date_acquired',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (602,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'trans_date',null,'Inventory',90000,'adjust_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'current_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'po',null,'Inventory',11,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'date_acquired',null,'Inventory',13,'date_acquired',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'first_name',null,'User',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (604,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'first_name',null,'User',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'date_acquired',null,'Inventory',13,'date_acquired',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (605,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'entry_date',null,'Inventory',90000,'move_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'moveto_location',null,'to',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'entry_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'entry_date',null,'Inventory',13,'trans_date000',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'customer_name',null,'Customer',4,'name0000',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (103,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (103,'reorder_qty',null,'vTotalInventorySummary',6,'reorder_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (103,'min_stock_level',null,'vTotalInventorySummary',6,'min_stock_level',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (103,'supplier_name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (103,'current_quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'trans_date',null,'Inventory',90000,'out_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'moveto_site_name',null,'Move to',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'entry_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'code',null,null,7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'site_name',null,null,8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (609,'moveto_location',null,'Move to',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'entry_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'moveto_site_name',null,'Move to',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'moveto_location',null,'Move to',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'code',null,null,7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (610,'site_name',null,null,8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'code',null,'from',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'site_name',null,'from',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'moveto_site_name',null,'to',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'quantity',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'customer_name',null,'Customer',4,'name0000',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'trans_date',null,'Inventory',90000,'remove_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (612,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (0,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'trans_date',null,'Inventory',90000,'remove_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (613,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'website',null,'Manufacturer',5,'website',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'ref_number',null,'Invoice Pick',1001,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'Bill_address1',null,'Bill',2,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (701,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'quantity',null,'Item',90000,'order_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'ref_number1','Invoice #','Invoice Pick',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'picked_quantity',null,'Invoice Pick',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'ref_number',null,'Invoice Pick',1001,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'qty',null,'Inventory',90000,'ship_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (702,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'picked_quantity',null,'Item',90000,'ship_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'ref_number',null,'Invoice Pick',1001,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'ref_number','Invoice #','Invoice Pick',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (703,'quantity',null,'Order',90000,'order_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (704,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (704,'ref_number',null,'Invoice Pick',1001,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (704,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (704,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (704,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (704,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (705,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (705,'ref_number',null,'Invoice Pick',1001,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (706,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (706,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (706,'customer_name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (707,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (707,'customer_name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (707,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'ref_number',null,'Invoice Pick',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'customer_number',null,'Customer',4,'customer_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'allow_shorting',null,'vInvoiceInfo',4,'allow_shorting',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (708,'due_date',null,'Invoice Pick',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (801,'quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (801,'due_date',null,'Item Receive',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (801,'description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (801,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (801,'ref_number',null,'Item Receive',1000,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'quantity',null,'Item',90000,'original_order_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'site_name1',null,'Item Receive',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'quantity_received1','Received Quantity','PO Receive',0,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'quantity_received2',null,'Item Receive',90000,'received_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'due_date1',null,'Item Receive',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'qty',null,'Inventory',90000,'received_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'ref_number',null,'PO Receive',1000,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (802,'location1',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (803,'quantity_received',null,'PO Receive',90000,'received_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (803,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (803,'ref_number',null,'Item Receive',1000,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (803,'due_date',null,'Item Receive',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (803,'description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (803,'quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (804,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (804,'quantity_received',null,'Item Receive',90000,'received_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (804,'ref_number',null,'Item Receive',15,'require_pos',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (804,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (806,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (806,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (806,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (806,'quantity_received',null,'Item Receive',90000,'received_quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (806,'po_type',null,'vPOinfo',22,'po_type',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (806,'ref_number',null,'Item Receive',1000,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'contact_name',null,'Supplier',9,'contact_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'cphone',null,'Supplier',9,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'mail_stop',null,'Supplier',9,'mail_stop',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'ccell',null,'Customer',4,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'address1',null,'Customer',4,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'state',null,'Customer',4,'state',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'supplierStatus',null,'vSupplierBillingAddress',0,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1004,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (611,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'address2',null,'Supplier',9,'address2',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'cextension','Cextension','Supplier',9,null,'Contact work phone extension');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'address1',null,'Supplier',9,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'phone_number',null,'Supplier',9,null,null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'cfax',null,'Supplier',9,null,'Contact Fax');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'ccell','Cell Phone','Supplier',9,null,'Contact Cell Phone');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'website',null,'Supplier',9,'website',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'email',null,'Supplier',9,'email',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'mail_stop',null,'Supplier',9,'mail_stop',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'contact_name',null,'Supplier',9,'contact_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'extension',null,'Supplier',9,null,'extension');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'country',null,'Supplier',9,'country',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'name',null,'Supplier',9,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'fax','Fax','Supplier',9,null,'fax');
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'postal_code',null,'Supplier',9,'postal_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'city',null,'Supplier',9,'city',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1002,'state',null,'Supplier',9,'state',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'cfax',null,'Supplier',9,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'address2',null,'Customer',4,'address2',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'mail_stop',null,'Supplier',9,'mail_stop',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1004,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'adjust_code',null,'Adjust Reason',21,'adjust_reason',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (608,'trans_date',null,'Inventory',90000,'checkout_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'trans_date',null,'Inventory',90000,'checkin_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (607,'quantity',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1101,'current_qty',null,'Inventory',13,'current_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'current_qty',null,'Inventory',13,'current_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1102,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1103,'current_qty',null,'Inventory',13,'current_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'current_qty',null,'Inventory',13,'current_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1104,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1105,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'current_qty',null,'Inventory',13,'current_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1107,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'location_description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'current_qty',null,'Inventory',13,'current_qty',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'date_code',null,'Inventory',11,'date_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'trans_date',null,'Inventory',13,'trans_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'site_description',null,'Site',8,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1108,'pallet',null,'Inventory',11,'pallet',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10007,'process_id',null,'import_QB_errors',90000,'error_type',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10007,'original_data',null,'import_QB_errors',90000,'id_reference',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10007,'error_number',null,'import_QB_errors',90000,'object_type',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10007,'error_description',null,'import_QB_errors',90000,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10008,'error_number',null,'import_export_errors',90000,'error_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10008,'process_id',null,'import_export_errors',90000,'process_type',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10008,'original_data',null,'import_export_errors',90000,'original_data',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10008,'error_description',null,'import_export_errors',90000,'error_description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10012,'ref_number',null,'Item Receipt',1000,'po',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10012,'due_date',null,'Item Receipt',22,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10012,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10012,'quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10012,'description',null,'Location',7,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (10012,'po_type',null,'vPOinfo',22,'po_type',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (212,'quantity',null,'Inventory',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (212,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (212,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (212,'avgcost',null,'Item',6,'avgcost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (212,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (212,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (614,'start_date',null,'SpActivityReport;1',90000,'start_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (614,'end_date',null,'SpActivityReport;1',90000,'end_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'name',null,'Customer',4,'name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'date_acquired',null,'Inventory',90000,'due_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'remaining_qty',null,'Inventory',90000,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (507,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'lot',null,'Inventory',11,'lot',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'serial_number',null,'Inventory',11,'serial_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (112,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (213,'remaining_quantity',null,'Item',6,'qty_available',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (112,'category_description',null,'Category',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (112,'supplier_name',null,'Supplier',6,'Supplier',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (112,'manufacturer_name',null,'Manufacturer',6,'manufacturer',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (113,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (113,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (113,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (113,'avgcost',null,'Item',6,'avgcost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (113,'category_description',null,'Category',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (113,'supplier_name',null,'Supplier',6,'Supplier',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (113,'manufacturer_name',null,'Manufacturer',6,'manufacturer',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (114,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (114,'description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (114,'cost',null,'Item',6,'cost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (114,'avgcost',null,'Item',6,'avgcost',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (114,'category_description',null,'Category',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (114,'supplier_name',null,'Supplier',6,'Supplier',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (114,'manufacturer_name',null,'Manufacturer',6,'manufacturer',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (110,'moveto_location',null,'Move to',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (109,'max_stock_level',null,'Item',6,'max_stock_level',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (108,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (108,'location',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (108,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (108,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (109,'item_description',null,'Item',6,'description',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (109,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (109,'supplier_number',null,'Supplier',9,'supplier_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'email',null,'Customer',4,'email',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'website',null,'Manufacturer',5,'website',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'cextension',null,'Supplier',9,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'ccell',null,'Customer',4,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'address1',null,'Customer',4,'address1',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'address2',null,'Customer',4,'address2',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1001,'state',null,'Customer',4,'state',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'email',null,'Customer',4,'email',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'website',null,'Manufacturer',5,'website',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'contact_name',null,'Supplier',9,'contact_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'phone_number',null,'Customer',4,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'fax',null,'Customer',4,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'cphone',null,'Supplier',9,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'cextension',null,'Supplier',9,'',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'postal_code',null,'Customer',4,'postal_code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1003,'country',null,'Customer',4,'country',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (1004,'user_logon',null,'User',90000,'login_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'item_number',null,'Item',6,'item_number',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'date_acquired',null,'Inventory',90000,'add_date',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'quantity',null,'Inventory',11,'quantity',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (603,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'code',null,'Location',7,'code',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'last_name',null,'User',90000,'last_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'first_name',null,'UserSecurity',90000,'first_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'site_name',null,'Site',8,'site_name',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'adjust_type',null,'Inventory',13,'adjust_type',null);
insert into report_labels (rpt_id,db_field_report,rpt_label,rpt_label2,form_id,db_field,field) values (606,'adjust_trans_code',null,'vAdjustInventory',13,'adjust_trans_code',null);

END


if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[report_names]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[report_names] (
	[rpt_id] [int] NULL ,
	[rpt_type] [int] NULL ,
	[rpt_display_order] [int] NULL ,
	[rpt_name] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[rpt_file_name] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[rpt_default_name] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[rpt_filter] [wtbool] NULL ,
	[rpt_show_dialog] [wtbool] NULL ,
	[rpt_tool_tips] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]

insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (103,1,3,'Item Reorder by Item Total Report','Item Reorder by Item Total Report','Item Reorder by Item Total Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (104,1,4,'Item Reorder by Location Report','Item Reorder by Location Report','Item Reorder by Location Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (105,1,5,'Item Summary Report','Item Summary Report','Item Summary Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (106,1,6,'Out of Stock Items Report','Out of Stock Items Report','Out of Stock Items Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (107,1,7,'Overstocked Items Report','Overstocked Items Report','Overstocked Items Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (201,2,1,'Inventory By Location Report','Inventory By Location Report','Inventory By Location Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (202,2,2,'Inventory Location Report','Inventory Location Report','Inventory Location Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (203,2,3,'Inventory Location Serial Number Report','Inventory Location Serial Number Report','Inventory Location Serial Number Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (301,3,1,'Location List Report','Location List Report','Location List Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (401,4,1,'Customer By ID Report','Customer By ID Report','Customer By ID Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (402,4,2,'Customer By Name Report','Customer By Name Report','Customer By Name Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (403,4,3,'Customer By Postal Code Report','Customer By Postal Code Report','Customer By Postal Code Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (404,4,4,'Customer By State Report','Customer By State Report','Customer By State Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (501,5,1,'Check-out By Customer Report','Check-out By Customer Report','Check-out By Customer Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (502,5,2,'Check-out By Due Date Report','Check-out By Due Date Report','Check-out By Due Date Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (503,5,3,'Check-out By Item Number Report','Check-out By Item Number Report','Check-out By Item Number Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (504,5,4,'Check-out By Out Date Report','Check-out By Out Date Report','Check-out By Out Date Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (505,5,5,'Check-out Due Today Report','Check-out Due Today Report','Check-out Due Today Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (506,5,6,'Check-out Past Due Report','Check-out Past Due Report','Check-out Past Due Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (507,5,7,'Check-out By Customer with Serial Number Report','Check-out By Customer with Serial Number Report','Check-out By Customer with Serial Number Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (603,6,3,'Transaction Add Report','Transaction Add Report','Transaction Add Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (606,6,6,'Transaction Adjust Report','Transaction Adjust Report','Transaction Adjust Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (607,6,7,'Transaction Check-in Report','Transaction Check-in Report','Transaction Check-in Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (608,6,8,'Transaction Check-out Report','Transaction Check-out Report','Transaction Check-out Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (609,6,9,'Transaction History (Archived) Report','Transaction History (Archived) Report','Transaction History (Archived) Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (610,6,10,'Transaction History Report','Transaction History Report','Transaction History Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (611,6,11,'Transaction Move Report','Transaction Move Report','Transaction Move Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (612,6,12,'Transaction Remove Report','Transaction Remove Report','Transaction Remove Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (701,7,-1,'Line Item Pick Ticket','Line Item Pick Ticket','Line Item Pick Ticket','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (702,7,2,'Line Item Post Pick Location Report','Line Item Pick Report','Line Item Post Pick Location Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (703,7,3,'Packing Slip','Packing Slip','Packing Slip','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (704,7,4,'Line Item Pick Location Report','Line Item Pick Location Report','Line Item Pick Location Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (705,7,5,'Pending Invoice Report','Pending Invoice Report','Pending Invoice Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (706,7,6,'Back Ordered Invoice Report','Back Ordered Invoice Report','Back Ordered Invoice Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (707,7,7,'Back Ordered Invoice By Customer Report','Back Ordered Invoice By Customer Report','Back Ordered Invoice By Customer Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (801,8,-1,'Item Receive Ticket','Item Receive Report','Item Receive Ticket','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (802,8,2,'Item Receipt Report','Item Receive Report','Item Receipt Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (803,8,3,'Item Receipt Report (with Barcodes)','Item Receive Barcode Report','Item Receipt Report (with Barcodes)','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (804,8,4,'Item Receipt Discrepancy Report','Item Receive Discrepancy Report','Item Receipt Discrepancy Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1004,10,4,'User Security Option Report','User Security Option Report','User Security Option Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10009,10000,null,'Line Item Pick Receipt','Line Item Pick Receipt','Line Item Pick Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10007,10000,null,'Import from QB Error Report','Import from QB Error Report','Import from QB Error Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1101,11,2,'Accepted Audit Discrepancies Report','Accepted Audit Discrepancies Report','Accepted Audit Discrepancies Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1102,11,3,'Accepted Audit Result Report','Accepted Audit Result Report','Accepted Audit Result Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1103,11,4,'Audit History By Audit Date Report','Audit History By Audit Date Report','Audit History By Audit Date Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1104,11,5,'Audit History By Item Number Report','Audit History By Item Number Report','Audit History By Item Number Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1105,11,6,'Not Counted Items Report','Not Counted Items Report','Not Counted Items Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1107,11,7,'Unreconciled Audit Discrepancies Report','Unreconciled Audit Discrepancies Report','Unreconciled Audit Discrepancies Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1108,11,8,'Unreconciled Audit Result Report','Unreconciled Audit Result Report','Unreconciled Audit Result Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10001,10000,null,'Inventory Adjust Receipt','Inventory Adjust Receipt','Inventory Adjust Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10002,10000,null,'Inventory Check-in Receipt','Inventory Check-in Receipt','Inventory Check-in Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10003,10000,null,'Inventory Check-out Receipt','Inventory Check-out Receipt','Inventory Check-out Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10004,10000,null,'Inventory Move Receipt','Inventory Move Receipt','Inventory Move Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10005,10000,null,'Inventory Add Receipt','Inventory Add Receipt','Inventory Add Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10006,10000,null,'Inventory Remove Receipt','Inventory Remove Receipt','Inventory Remove Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10008,10000,null,'Import-Export Error Report','Import-Export Error Report','Import-Export Error Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10010,10000,null,'Item Receipt','Item Receive Receipt','Item Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (805,8,-5,'Credit Memo','Item Receive Receipt (All)','Credit Memo','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (708,7,-8,'Line Item Pick Ticket','Line Item Pick Ticket with Bar Codes','Line Item Pick Ticket','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10011,10000,null,'Line Item Post Pick Report','Line Item Pick Receipt (All)','Line Item Post Pick Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (10012,10000,null,'Item Receipt','Item Receive Receipt (All)','Item Receipt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1001,10,1,'Vendor By Name Report','Supplier By Name Report','Vendor By Name Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1002,10,2,'Manufacturer By Name Report','Manufacturer By Name Report','Manufacturer By Name Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (204,2,4,'Negative Inventory By Serial Number Report','Negative Inventory By TrackBy Report','Negative Inventory By Serial Number Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (108,1,8,'Out of Stock Items By Location Report','Out of Stock Items By Location Report','Out of Stock Items By Location Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (109,1,9,'Overstocked Items By Location Report','Overstocked Items By Location Report','Overstocked Items By Location Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (205,2,5,'Inventory Adjust By Reason Report','Inventory Adjust By Reason Report','Inventory Adjust By Reason Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1005,10,5,'Browse...','Browse...','Browse...','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (806,8,6,'Active PO Report','Active PO Report','Active PO Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (110,1,10,'Item Transaction History Report','Item Transaction History Report','Item Transaction History Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (111,1,11,'Item Shipping History Summary Report','Item Shipping History Summary Report','Item Shipping History Summary Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (206,2,6,'Inventory Add History Summary Report','Inventory Add History Summary Report','Inventory Add History Summary Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (207,2,7,'Inventory Remove History Summary Report','Inventory Remove History Summary Report','Inventory Remove History Summary Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (208,2,8,'Inventory Status Report','Inventory Status Report','Inventory Status Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (209,2,9,'Inventory Aging Summary Report','Inventory Aging Summary Report','Inventory Aging Summary Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (210,2,10,'Inventory Detail Report','Inventory Detail Report','Inventory Detail Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (211,2,11,'Inventory Summary Report.rpt','Inventory Summary Report','Inventory Summary Report.rpt','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (405,4,5,'Customer Remove History Report','Customer Remove History Report','Customer Remove History Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (406,4,6,'All Customer Remove History Report','All Customer Remove History Report','All Customer Remove History Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (614,6,14,'Inventory Activity Report','Inventory Activity Report','Inventory Activity Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (1003,10,-3,'Vendor By Code Report','Supplier By Code Report','Vendor By Code Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (212,2,12,'Inventory Cost Report','Inventory Cost Report','Inventory Cost Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (213,2,13,'Inventory By Trackby Report','Inventory By Trackby Report','Inventory By Trackby Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (112,1,12,'Item By Category Report','Item By Category Report','Item By Category Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (113,1,13,'Item By Manufacturer Report','Item By Manufacturer Report','Item By Manufacturer Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (114,1,14,'Item By Supplier Report','Item By Supplier Report','Item By Supplier Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (601,6,1,'Transaction Add By PO Report','Transaction Add By PO Report','Transaction Add By PO Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (602,6,2,'Transaction Add By Supplier Report','Transaction Add By Supplier Report','Transaction Add By Supplier Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (604,6,4,'Transaction Add With PO Report','Transaction Add With PO Report','Transaction Add With PO Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (605,6,5,'Transaction Add With Supplier Report','Transaction Add With Supplier Report','Transaction Add With Supplier Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (613,6,13,'Transaction Remove By Customer Report','Transaction Remove By Customer Report','Transaction Remove By Customer Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11001,10000,-1,'Pick Ticket','Pick Ticket','Pick Ticket','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11002,10000,-2,'Packing Slip','Packing Slip','Packing Slip','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11003,10000,-3,'All Opened Requests Report','All Opened Requests Report','All Opened Requests Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11004,10000,-4,'All Shipped Requests Report','All Shipped Requests Report','All Shipped Requests Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11005,10000,-5,'All Cancelled Requests Report','All Cancelled Requests Report','All Cancelled Requests Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11006,10000,-6,'Pick Ticket with Item and Location Barcodes','Pick Ticket with Item and Location Barcodes','Pick Ticket with Item and Location Barcodes','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11007,10000,-7,'Inventory Request Summary Report','Inventory Request Summary Report','Inventory Request Summary Report','F','F',null);
insert into report_names (rpt_id,rpt_type,rpt_display_order,rpt_name,rpt_file_name,rpt_default_name,rpt_filter,rpt_show_dialog,rpt_tool_tips) values (11008,10000,-8,'Miscellaneous Request Summary Report','Miscellaneous Request Summary Report','Miscellaneous Request Summary Report','F','F',null);

END

	
if NOT EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[request_status]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[request_status] (
	[status_id] [int] NULL ,
	[code] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[label] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]
END

if  EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[FK_location_sites]') AND OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE [dbo].[location] DROP CONSTRAINT FK_location_sites
GO

IF  EXISTS (SELECT * FROM dbo.sysobjects  WHERE id = OBJECT_ID(N'[dbo].[FK_user_site_sites]') AND OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE [dbo].[user_site] DROP CONSTRAINT [FK_user_site_sites]

IF  EXISTS (SELECT * FROM dbo.sysindexes WHERE id = OBJECT_ID(N'[dbo].[sites]') AND name = N'PK_sites')
ALTER TABLE [dbo].[sites] DROP CONSTRAINT [PK_sites]

if NOT EXISTS (select * from dbo.syscolumns where name = 'usrdefdate1' 
	and id = object_id(N'[dbo].[sites]'))
BEGIN
	EXEC sp_rename 'sites', 'old_sites'

	CREATE TABLE [dbo].[sites] (
		[site_id] [int] IDENTITY (1, 1) NOT NULL ,
		[site_name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
		[description] [description_type] NULL ,
		[usrdefdate1] [datetime] NULL ,
		[usrdefdate2] [datetime] NULL ,
		[usrdefdate3] [datetime] NULL ,
		[usrdefdate4] [datetime] NULL ,
		[usrdefdate5] [datetime] NULL ,
		[usrdefnumber1] [decimal](15, 4) NULL ,
		[usrdefnumber2] [decimal](15, 4) NULL ,
		[usrdefnumber3] [decimal](15, 4) NULL ,
		[usrdefnumber4] [decimal](15, 4) NULL ,
		[usrdefnumber5] [decimal](15, 4) NULL ,
		[usrdeftext1] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext2] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext3] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext4] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext5] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext6] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext7] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext8] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext9] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[usrdeftext10] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
		[record_status] [record_status_type] NOT NULL ,
		[company_id] [int] NOT NULL ,
		[update_user_id] [int] NULL
	) ON [PRIMARY]

	SET IDENTITY_INSERT sites ON

	INSERT INTO SITES (site_id, site_name, description, company_id, record_status)
	SELECT site_id, description, description, company_id, 1 FROM OLD_SITES

	SET IDENTITY_INSERT sites OFF
	
	-- Now insert the related form_field_meta entries
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','description','description','&Description:','Enter a Description for this location.','T','F','T',255,'&Description:','Enter a Description for this location.','T','F',255,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','note_text','note_text','No&tes:','Notes about this location.','T','F','T',255,'No&tes:','Notes about this location.','T','F',255,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','site_id','site_id','location_id','**',null,null,'T',null,'location_id','**',null,null,null,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','site_name','site_name','&Site:','Pick the Site this location is in. ','T','T','T',50,'&Site:','Pick the Site this location is in. ','T','T',50,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefdate1','usrdefdate1','Custom &Date 1:','Enter a custom date.','F','F','T',20,'Custom &Date 1:','Enter a custom date.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefdate2','usrdefdate2','Custom D&ate 2:','Enter a custom date.','F','F','T',20,'Custom D&ate 2:','Enter a custom date.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefdate3','usrdefdate3','Custom Da&te 3:','Enter a custom date.','F','F','T',20,'Custom Da&te 3:','Enter a custom date.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefdate4','usrdefdate4','Custom Dat&e 4:','Enter a custom date.','F','F','T',20,'Custom Dat&e 4:','Enter a custom date.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefdate5','usrdefdate5','Custom Date &5:','Enter a custom date.','F','F','T',20,'Custom Date &5:','Enter a custom date.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefnumber1','usrdefnumber1','Custom &Number 1:','Enter a custom number.','F','F','T',20,'Custom &Number 1:','Enter a custom number.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefnumber2','usrdefnumber2','Custom N&umber 2:','Enter a custom number.','F','F','T',20,'Custom N&umber 2:','Enter a custom number.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefnumber3','usrdefnumber3','Custom Nu&mber 3:','Enter a custom number.','F','F','T',20,'Custom Nu&mber 3:','Enter a custom number.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefnumber4','usrdefnumber4','Custom Num&ber 4:','Enter a custom number.','F','F','T',20,'Custom Num&ber 4:','Enter a custom number.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdefnumber5','usrdefnumber5','Custom Numbe&r 5:','Enter a custom number.','F','F','T',20,'Custom Numbe&r 5:','Enter a custom number.','F','F',20,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext1','usrdeftext1','Custom Text &1:','Enter custom text.','F','F','T',100,'Custom Text &1:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext10','usrdeftext10','Custom Text 1&0:','Enter custom text.','F','F','T',100,'Custom Text 1&0:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext2','usrdeftext2','Custom Text &2:','Enter custom text.','F','F','T',100,'Custom Text &2:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext3','usrdeftext3','Custom Text &3:','Enter custom text.','F','F','T',100,'Custom Text &3:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext4','usrdeftext4','Custom Text &4:','Enter custom text.','F','F','T',100,'Custom Text &4:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext5','usrdeftext5','Custom Text &5:','Enter custom text.','F','F','T',100,'Custom Text &5:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext6','usrdeftext6','Custom Text &6:','Enter custom text.','F','F','T',100,'Custom Text &6:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext7','usrdeftext7','Custom Text &7:','Enter custom text.','F','F','T',100,'Custom Text &7:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext8','usrdeftext8','Custom Text &8:','Enter custom text.','F','F','T',100,'Custom Text &8:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (8,'Label','usrdeftext9','usrdeftext9','Custom Text &9:','Enter custom text.','F','F','T',100,'Custom Text &9:','Enter custom text.','F','F',100,null,null,null,1,1,'T','1','1');

END

ALTER TABLE [dbo].[sites] WITH NOCHECK ADD 
CONSTRAINT [PK_sites] PRIMARY KEY  CLUSTERED 
(
	[site_id]
)  ON [PRIMARY] 

ALTER TABLE [dbo].[location] WITH NOCHECK ADD 
CONSTRAINT [FK_location_sites] FOREIGN KEY 
(
	[site_id]
) REFERENCES [dbo].[sites] (
	[site_id]
)
	
if NOT EXISTS (select * from dbo.syscolumns where name = 'list_id' 
	and id = object_id(N'[dbo].[supplier]'))
BEGIN

ALTER TABLE [dbo].[supplier] ADD 
	[list_id] [qb_list_id] NULL 
	
CREATE  INDEX [IX_supplier_listid] ON [dbo].[supplier]([list_id]) ON [PRIMARY]

END


IF  EXISTS (SELECT * FROM dbo.sysindexes WHERE id = OBJECT_ID(N'[dbo].[users_mobile]') AND name = N'PK_users_mobile')
ALTER TABLE [dbo].[users_mobile] DROP CONSTRAINT [PK_users_mobile]

ALTER TABLE [dbo].[users_mobile] WITH NOCHECK ADD 
	CONSTRAINT [PK_users_mobile] PRIMARY KEY  CLUSTERED 
	(
		[type],
		[name]
	)  ON [PRIMARY] 
	


print '------'

print ''
print '------------------------------------'


if EXISTS (select * from dbo.syscolumns where name = 'address_type_id' and id = object_id(N'[dbo].[address]'))
BEGIN
   print '--  Address table is already up to date'
   print '------------------------------------'
END   
ELSE
BEGIN

   print '-- ..  Converting existing address table.'
   print '------------------------------------'

-- Step 2. Rename current address table to addressOld
USE [WaspTrackInventory]

if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[addressOld]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
EXEC sp_rename N'[dbo].[address]', N'addressOld', N'object'


-- Step 3. Create the new address table
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[address]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[address]


CREATE TABLE [dbo].[address] (
	[address_id] [int] NOT NULL ,
	[table_name] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[address_type_id] [int] NOT NULL ,
	[record_type] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[address1] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[address2] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[address3] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[address4] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[city] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[state] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[postal_code] [varchar] (10) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[country] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[mail_stop] [varchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[record_status] [record_status_type] NOT NULL 
) ON [PRIMARY]


-- Step 4. Insert data from the old address table to the new one with column handling
-- 4.1 Company Corporate
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'company_info', 1, 'Corporate Address', address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where record_type='Company Corporate'


-- 4.2 Company Receiving
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'company_info', 3, 'Receiving Address', address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where record_type='Company Receiving'


-- 4.3 Company Shipping
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'company_info', 2, 'Shipping Address', address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where record_type='Company Shipping'


-- 4.4 Customer Billing
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'customer', 1, 'Customer Billing', address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where record_type='Customer Billing'


-- 4.5 Customer other
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'customer', 100, LTRIM(REPLACE(record_type, 'customer', '')), address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where    record_type like 'Customer%' and record_type <> 'Customer Billing'


-- 4.6 supplier Billing
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'supplier', 1, 'Supplier Billing', address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where record_type='Supplier Billing'


-- 4.7 supplier other
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'supplier', 100, LTRIM(REPLACE(record_type, 'supplier', '')), address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where    record_type like 'Supplier%' and record_type <> 'Supplier Billing'


-- 4.8 manufacturer Billing
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'manufacturer', 1, 'Manufacturer Billing', address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where record_type='Manufacturer Billing'


-- 4.9 manufacturer other
INSERT INTO address (address_id, table_name, address_type_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status)

SELECT     address_id, 'manufacturer', 100, LTRIM(REPLACE(record_type, 'manufacturer', '')), address1, address2, address3, address4, city, state, postal_code, country, mail_stop, 
                      record_status
FROM         dbo.addressOld where    record_type like 'Manufacturer%' and record_type <> 'Manufacturer Billing'


END



print ''
print '------------------------------------'


if EXISTS (select * from dbo.syscolumns where name = 'phone_type_id' and id = object_id(N'[dbo].[phone]'))
BEGIN
   print '--  Phone table is already up to date'
   print '------------------------------------'
END   
ELSE
BEGIN

   print '-- ..  Converting existing Phone table.'
   print '------------------------------------'

-- Step 5. Rename current phone table to phoneOld
USE [WaspTrackInventory]
if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[phoneOld]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
EXEC sp_rename N'[dbo].[phone]', N'phoneOld', N'object'


-- Step 6. Create the new phone table
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[phone]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[phone]


CREATE TABLE [dbo].[phone] (
	[phone_id] [int] NOT NULL ,
	[table_name] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[phone_type_id] [int] NOT NULL ,
	[record_type] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[phone_number] [phone_type] NULL ,
	[extension] [varchar] (10) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[record_status] [record_status_type] NOT NULL 
) ON [PRIMARY]




-- Step 7. Insert data from the old phone table to the new one with column handling
-- 7.1 Company Phone
INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'company_info', 1, record_type, phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Company Phone'


-- 7.2 Company Fax
INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'company_info', 2, record_type, phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Company Fax'


-- 7.3 Customer
INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'customer', 1, 'Phone', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Customer Phone'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'customer', 2, 'Cell Phone', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Customer Cell Phone'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'customer', 3, 'Fax', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Customer Fax'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'customer', 4, 'Home Phone', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Customer Home Phone'


-- 7.4 Manufacturer
INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'manufacturer', 1, 'Phone', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Manufacturer Phone'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'manufacturer', 5, 'Fax', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Manufacturer Fax'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'manufacturer', 2, 'Contact Cell', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Manufacturer Contact Cell'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'manufacturer', 3, 'Contact Fax', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Manufacturer Contact Fax'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'manufacturer', 4, 'Contact Work', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Manufacturer Contact Work'


-- 7.5 Supplier
INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'supplier', 1, 'Phone', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Supplier Phone'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'supplier', 5, 'Fax', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Supplier Fax'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'supplier', 2, 'Contact Cell', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Supplier Contact Cell'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'supplier', 3, 'Contact Fax', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Supplier Contact Fax'


INSERT INTO phone (phone_id, table_name, phone_type_id, record_type, phone_number, extension, record_status)

SELECT     phone_id, 'supplier', 4, 'Contact Work', phone_number, extension, record_status
FROM         dbo.phoneOld where record_type='Supplier Contact Work'


END



GO



print ''
print '------------------------------------'
print '-- ..  Insert value in Tables    '
print '------------------------------------'

---- Insert value in tables

print '.. request_status'

if NOT EXISTS (select * from request_status where status_id=0)
BEGIN
   insert into [request_status](status_id, code, label) values (0, 'open', 'Opened')
END

if NOT EXISTS (select * from request_status where status_id=1)
BEGIN
   insert into [request_status](status_id, code, label) values (1, 'ship', 'Shipped')
END

if NOT EXISTS (select * from request_status where status_id=2)
BEGIN
   insert into [request_status](status_id, code, label) values (2, 'cancel', 'Cancelled')
END

print '.. app_options'

if EXISTS (select * from app_options where code=2)
BEGIN
	UPDATE app_options SET record_status = 2, company_id = 0 WHERE CODE = 2
END

if EXISTS (select * from app_options where code=4)
BEGIN
	UPDATE app_options SET record_status = 2 WHERE CODE = 4
END

if EXISTS (select * from app_options where code=5)
BEGIN
	UPDATE app_options SET description = 'Automatically open the New form when an entered identifier is not in the database.',
	tool_tip = 'Automatically open the New form when an entered identifier is not in the database.' WHERE CODE = 5
END

if EXISTS (select * from app_options where code=6)
BEGIN
	UPDATE app_options SET description = 'All numbers that can display decimal places will use this number to determine how many decimal places to display. Valid values: 0..4.' WHERE CODE = 6
END

/*
if EXISTS (select * from app_options where code=8)
BEGIN
	delete from app_options where code=8
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'8','bool','Edit Field Names','Allows administrators to control field name editing.','Allows administrators to control field name editing.','F','F','','Support',1,1);
END

if EXISTS (select * from app_options where code=9)
BEGIN
	delete from app_options where code=9
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'9','bool','Automatic Customer Number','Automatically generate a customer number when creating a new customer.','Automatically generate a customer number when creating a new customer','F','T','','Inventory',1,1);
END

if EXISTS (select * from app_options where code=10)
BEGIN
	delete from app_options where code=10
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'10','bool','Close New Form','Automatically close the New form each time a new record is created or duplicated.','Automatically close the New form each time a new record is created or duplicated.','T','T','','Support',1,1);
END
*/

if EXISTS (select * from app_options where code=100)
BEGIN
	delete from app_options where code=100
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'100','text','Version','Application Version',null,'F','F','3.40',null,2,0);
END


if NOT EXISTS (select * from app_options where code=204)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'204','bool','Backorder Processing','Turn this option on to always create backorders for short Invoices unless specified manually. Turn it off to never create backorders unless you tell it to.','Turn this option on to always create backorders for short Invoices unless specified manually. Turn it off to never create backorders unless you tell it to.','T','T',null,'QuickBooks',2,1);

if NOT EXISTS (select * from app_options where code=200)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'200','bool','Invoice Reference Number','Let QuickBooks calculate the reference number for back orders.','Turn this value on if you want QuickBooks to assign the reference number','T','T',null,'QuickBooks',2,1);

if NOT EXISTS (select * from app_options where code=201)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'201','text','Reference Delimiter','Delimiter used when MobileInventory creates the reference number.','Delimiter used when MobileInventory creates the reference number','F','T','-','QuickBooks',2,1);

if NOT EXISTS (select * from app_options where code=202)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'202','bool','Add Invoice Notes','When Invoices are Picked short and Backorder Invoices are created, add a note to the Backorder Invoice so that it can be traced to the original.','Turning this on causes a note to be added to the memo field when a Backorder is created','F','T',null,'QuickBooks',2,1);

if NOT EXISTS (select * from app_options where code=203)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'203','bool','Automatic Notification of Low Order Items','Automatic notification of items which are below the minimum stock level.','Automatic notification of items which are below the minimum stock level','F','T','','Inventory',1,1);

if NOT EXISTS (select * from app_options where code=11)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'11','bool','Previously Processed Mobile Data','Turn this option on to show previously processed transactions in downloaded mobile files.','Turn this option on to show previously processed transactions in downloaded mobile files','F','T',null,'Support',1,1);

if NOT EXISTS (select * from app_options where code=14)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'14','bool','Print Pick Tickets with Bar Codes','Print Pick Tickets with Bar Codes.','Print the Pick Tickets with Bar Codes','T','T','','Inventory',2,1);

if NOT EXISTS (select * from app_options where code=15)
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) values (null,'15','bool','Automatic Inventory Request Numbers','Automatically assign an inventory request number when creating a new inventory request.','Automatically assign an item number when creating a new or duplicating an existing item.','T','F','1000','Inventory',1,1);


if NOT EXISTS (select * from app_options where code=15)
BEGIN
	insert into app_options (user_id, code, type, name, description, tool_tip, flag, admin, option_value, option_section, record_status, company_id)
	VALUES (null, 15, 'bool', 'Automatic Inventory Request Numbers', 'Automatically assign an inventory request number when creating a new inventory request', 'Automatically assign an item number when creating a new or duplicating an existing item.', 'T', 'F', 1000, 'Inventory', 1, 1)
END

if NOT EXISTS (select * from app_options where code=20)
BEGIN
	insert into app_options (user_id,code,type,name,description,tool_tip,flag,admin,option_value,option_section,record_status,company_id) 
	values (null,'20','bool','Check For Software Updates','Turn this option on to automatically check for software update upon application startup. This check will be performed every 15 calendar days and must have internet connection for this to work. ','Turn this option on to automatically check for software update upon application startup. This check will be performed every 15 calendar days and must have internet connection for this to work. ','T','T',null,'Support',1,1);
END

print '.. form'

if EXISTS (select * from form where form_id = 8)
	UPDATE form SET company_id = 1 WHERE form_id = 8

if NOT EXISTS (select * from form where form_id = 22)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (22,'PurchaseOrder','T',2,1);
if NOT EXISTS (select * from form where form_id = 23)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (23,'Invoice','T',2,1);
if NOT EXISTS (select * from form where form_id = 24)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (24,'InvoiceLineItem','T',2,1);
if NOT EXISTS (select * from form where form_id = 25)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (25,'POLineItem','T',2,1);

if NOT EXISTS (select form_id from form where form_id=31)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (31,'Inventory Request','T',1,1)
END

if NOT EXISTS (select * from form where form_id = 200)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (200,'Qb_Main','F',1,1);
if NOT EXISTS (select * from form where form_id = 1006)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (1006,'PDA - Review Add','F',1,1);
if NOT EXISTS (select * from form where form_id = 1007)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (1007,'PDA - Review Remove','F',1,1);

if NOT EXISTS (select form_id from form where form_id=10200)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (10200,'WPA206 - Add','F',1,1)
END

if NOT EXISTS (select form_id from form where form_id=10201)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (10201,'WPA206 - Remove','F',1,1)
END

if NOT EXISTS (select form_id from form where form_id=10202)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (10202,'WPA206 - Move','F',1,1)
END

if NOT EXISTS (select form_id from form where form_id=10203)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (10203,'WPA206 - Adjust','F',1,1)
END

if NOT EXISTS (select form_id from form where form_id=10204)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (10204,'WPA206 - Details','F',1,1)
END

if NOT EXISTS (select form_id from form where form_id=10205)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (10205,'WPA206 - Audit','F',1,1)
END

if NOT EXISTS (select form_id from form where form_id=10206)
BEGIN
	insert into form (form_id, form_name, list_flag, record_status, company_id)
	VALUES (10206,'WPA206 - Stage','F',1,1)
END

if NOT EXISTS (select * from form where form_id = 90000)
	insert into form (form_id,form_name,list_flag,record_status,company_id) values (90000,'Crystal Report','F',1,1);

print '.. form_field_meta'

if NOT EXISTS (select visible from form_field_meta where form_id=1 and field='send_pc')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(1,'Label','send_pc','','Send Data to PC','Send Data to PC','T','T','T',30,'Send Data to PC','Send Data to PC','T','T',30,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id=1 and field='Stage')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(1,'Label','Stage','','Stage','Stage','T','T','F',30,'Stage','Stage','T','T',30,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id=6 and field='default_location')
BEGIN
	insert into form_field_meta 
	(form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values 
	(6,'Label','default_location','default_location_id','&Default Location:','To set a default location for the item. This is the line item location that will be printed on the pick ticket. This is a QuickBooks only feature.','T','F','T',null,'&Default Location:','To set a default location for the item. This is the line item location that will be printed on the pick ticket. This is a QuickBooks only feature.','T','F',null,null,null,null,1,1,'T','1','1');
END

UPDATE [form_field_meta] set label = 'Site', default_label = 'Site'
where [form_id]=8 and [control]='List Form Name' and [field]='site'

if NOT EXISTS (select visible from form_field_meta where form_id=11 and field='max_stock_level')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import)
	values (11,'Label','max_stock_level','max_stock_level','Max Stock Level','Enter the Maximum Stock Level for this item (maximum across all sites).','T','F','T',30,'Max Stock Level','Enter the Maximum Stock Level for this item (maximum across all sites).','T','F',30,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=11 and field='min_stock_level')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (11,'Label','min_stock_level','min_stock_level','Min Stock Level','Enter the Minimum Stock Level for this item (minimum across all sites).','T','F','T',30,'Min Stock Level','Enter the Minimum Stock Level for this item (minimum across all sites).','T','F',30,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=11 and field='newest')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (11,'Label','newest','date_acquired','Latest Date &Acquired:','Date the item was last acquired','T','F','T',null,'Latest Date &Acquired:','Date the item was last acquired','T','F',null,null,null,null,1,1,'F','1','0');
END

if NOT EXISTS (select visible from form_field_meta where form_id=11 and field='oldest')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (11,'Label','oldest','date_acquired','Oldest Date &Acquired:','Date the item was first acquired','T','F','T',null,'Oldest Date &Acquired:','Date the item was first acquired','T','F',null,null,null,null,1,1,'F','1','0');
END

if NOT EXISTS (select visible from form_field_meta where form_id=11 and field='reorder_qty')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (11,'Label','reorder_qty','reorder_qty','Reorder Qty','Enter the Reorder quantity for this item.','T','F','T',30,'Reorder Qty','Enter the Reorder quantity for this item.','T','F',30,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=11 and field='site_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (11,'Label','site_name','site_name','&Site:','**','T','T','T',null,'&Site:','**','T','T',null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=13 and field='adjust_code')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (13,'Label','adjust_code','adjust_code','Adjust Reason Code','Adjust Reason Code','T','T','T',null,'Adjust Reason Code','Adjust Reason Code','T','T',null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=13 and field='adjust_trans_code')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (13,'Label','adjust_trans_code','adjust_trans_code','&Transaction Code:','Enter the transaction code for the adjustment','T','F','T',25,'&Transaction Code:','Enter the transaction code for the adjustment','T','F',25,null,null,null,1,1,'F','0','0');
END

if NOT EXISTS (select visible from form_field_meta where form_id=13 and field='adjust_type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (13,'Label','adjust_type','adjust_type','Adjust Type','Adjust Type','T','T','T',null,'Adjust Type','Adjust Type','T','T',null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=13 and field='invoice')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (13,'Label','invoice','invoice','I&nvoice No.:','Invoice Number','T','T','T',null,'I&nvoice No.:','Invoice Number','T','T',null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=13 and field='other_site')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (13,'Label','other_site','other_site','To Site:','To Site','T','T','T',null,'To Site:','To Site','T','T',null,null,null,null,1,1,'F','0','0');
END

if NOT EXISTS (select visible from form_field_meta where form_id=13 and field='print_label_no')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (13,'Label','print_label_no','print_label_no','No. of Labels:','Enter the number of labels that you wish to print for the inventory.','T','F','T',25,'No. of Labels:','Enter the number of labels that you wish to print for the inventory.','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=13 and field='site_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (13,'Label','site_name','site_name','Site',null,null,null,'T',null,'Site',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=15 and field='note_text')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (15,'Label','note_text','note_text','&Notes:','Enter the notes for the receiving transaction of this PO','T','F','T',255,'&Notes:','Enter the notes for the receiving transaction of this PO','T','F',255,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=15 and field='print_label')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (15,'Label','print_label','print_label','No. of Labels:','Enter the number of labels that you wish to print for the inventory.','T','F','T',25,'No. of Labels:','Enter the number of labels that you wish to print for the inventory.','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=15 and field='require_packlist')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (15,'Label','require_packlist','require_packlist','&Pack List:','Is this item tracked by purchase order number?','T','F','T',25,'&Pack List:','Is this item tracked by purchase order number?','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=15 and field='require_suppliers')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (15,'Label','require_suppliers','track_suppliers','S&upplier Code:','Select the Supplier Code for this item.','T','F','T',30,'S&upplier Code:','Select the Supplier Code for this item.','T','F',30,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=15 and field='require_vendor')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import)
	values (15,'Label','require_vendor','track_suppliers','&Supplier:','Is this item tracked by supplier?','T','F','T',25,'&Supplier:','Is this item tracked by supplier?','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=16 and field='note_text')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (16,'Label','note_text','note_text','&Notes:','Enter the notes for the receiving transaction of this PO','T','F','T',255,'&Notes:','Enter the notes for the receiving transaction of this PO','T','F',255,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=16 and field='pick_ticket_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (16,'Label','pick_ticket_number','pick_ticket_number','&Pick Ticket No.:','Enter the Pick Ticket Number. You can pick from the list, enter the number through the keyboard or scan it in.','T','T','T',30,'&Pick Ticket No.:','Enter the Pick Ticket Number. You can pick from the list, enter the number through the keyboard or scan it in.','T','T',30,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=17 and field='note_text')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (17,'Label','note_text','note_text','No&tes:','Notes about this transaction..','T','F','T',255,'No&tes:','Notes about this transaction..','T','F',255,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=18 and field='note_text')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (18,'Label','note_text','note_text','No&tes:','Notes about this transaction..','T','F','T',255,'No&tes:','Notes about this transaction..','T','F',255,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=19 and field='note_text')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (19,'Label','note_text','note_text','No&tes:','Notes about this transaction..','T','F','T',255,'No&tes:','Notes about this transaction..','T','F',255,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=20 and field='adjust_trans_code')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (20,'Label','adjust_trans_code','adjust_trans_code','&Transaction Code:','Enter the transaction code for the audit','T','F','T',25,'&Transaction Code:','Enter the transaction code for the audit','T','F',25,null,null,null,1,1,'F','0','0');
END

if NOT EXISTS (select visible from form_field_meta where form_id=20 and field='note_text')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (20,'Label','note_text','note_text','No&tes:','Notes about this transaction..','T','F','T',255,'No&tes:','Notes about this transaction..','T','F',255,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=21 and field='absolute_adjust')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (21,'Label','absolute_adjust','absolute_adjust','By Counts','Pick a reason from the list for adjustment','T','F','T',25,'By Counts','Pick a reason from the list for adjustment','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=21 and field='adjust_reason')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (21,'Label','adjust_reason','adjust_reason','&Reason:','Pick a reason from the list for adjustment','T','F','T',25,'&Reason:','Pick a reason from the list for adjustment','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=21 and field='adjust_trans_code')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (21,'Label','adjust_trans_code','adjust_trans_code','&Transaction Code:','Enter the transaction code for the adjustment','T','F','T',25,'&Transaction Code:','Enter the transaction code for the adjustment','T','F',25,null,null,null,1,1,'F','0','0');
END

if NOT EXISTS (select visible from form_field_meta where form_id=21 and field='note_text')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (21,'Label','note_text','note_text','No&tes:','Notes about this transaction..','T','F','T',255,'No&tes:','Notes about this transaction..','T','F',255,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=21 and field='relative_adjust')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (21,'Label','relative_adjust','relative_adjust','By Difference','Pick a reason from the list for adjustment','T','F','T',25,'By Difference','Pick a reason from the list for adjustment','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='customer_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','customer_name','customer_name','Customer Name',null,null,null,'T',null,'Customer Name',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='customer_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','customer_number','customer_number','Customer No.',null,null,null,'T',null,'Customer No.',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='due_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','due_date','due_date','Due Date',null,null,null,'T',null,'Due Date',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='po_status')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','po_status','po_status','Status','',null,null,'T',null,'Status','',null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 22 and field='po_type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','po_type','po_type','Type',null,'F',null,'T',null,'Type',null,'F',null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='PurchaseOrder')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'List Form Name','PurchaseOrder','**','Purchase Order','**','T','F','T',0,'Purchase Order','**','T','F',0,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='record_status')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','record_status','record_status','Record Status',null,null,null,'T',null,'Record Status',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='ref_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','ref_number','ref_number','Number',null,null,null,'T',null,'Number',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='supplier_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','supplier_name','supplier_name','Supplier Name',null,null,null,'T',null,'Supplier Name',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=22 and field='supplier_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (22,'Label','supplier_number','supplier_number','Supplier No.',null,null,null,'T',null,'Supplier No.',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='child_bo')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','child_bo','child_bo','Backorder',null,null,null,'T',null,'Backorder',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='customer_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','customer_name','customer_name','Customer Name',null,null,null,'T',null,'Customer Name',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='customer_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','customer_number','customer_number','Customer No.',null,null,null,'T',null,'Customer No.',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='due_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','due_date','due_date','Due Date',null,null,null,'T',null,'Due Date',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='Invoice')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'List Form Name','Invoice',null,'Invoice','**','T','F','T',0,'Invoice','**','T','F',0,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 23 and field='invoice_status')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','invoice_status','invoice_status','Status',null,null,null,'T',null,'Status',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='invoice_type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','invoice_type','has_bo','Has B.O.?',null,null,null,'T',null,'Has B.O.?',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 23 and field='parent_bo')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','parent_bo','parent_bo','Backorder From',null,null,null,'T',null,'Backorder From',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='po_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','po_number','po_number','PO Number',null,null,null,'T',null,'PO Number',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='record_status')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','record_status','record_status','Record Status',null,null,null,'T',null,'Record Status',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=23 and field='ref_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (23,'Label','ref_number','ref_number','Number',null,null,null,'T',null,'Number',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=24 and field='picked_quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (24,'Label','picked_quantity',null,'Picked Qty',null,null,null,'T',null,'Picked Qty',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=24 and field='quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (24,'Label','quantity',null,'Quantity',null,null,null,'T',null,'Quantity',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=24 and field='quantity_received')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (24,'Label','quantity_received',null,'Recv''d Qty',null,null,null,'T',null,'Recv''d Qty',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=24 and field='shorted')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (24,'Label','shorted',null,'Shorted?',null,null,null,'T',null,'Shorted?',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 25 and field='quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (25,'Label','quantity',null,'Quantity',null,null,null,'T',null,'Quantity',null,null,null,null,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='backorder_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','backorder_number','backorder_number','Backorder Number:','','T','F','T',50,'Backorder Number:','','T','F',50,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='carrier')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','carrier','carrier','Carrier: ','Enter the carrier name for this request.','T','F','T',255,'Carrier: ','Enter the carrier name for this request.','T','F',255,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='cost')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','cost','cost','Unit Cost','The cost to you of this item per unit.','T','F','F',8,'Unit Cost','The cost to you of this item per unit.','T','F',8,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='creation_date')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','creation_date','creation_date','Created On: ','The date that this inventory request is created on.','T','F','T',30,'Created On: ','The date that this inventory request is created on.','T','F',30,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='customer_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','customer_number','customer_number','Customer Number: ','Select the customer that this inventory request is for.','T','F','T',30,'Customer Number: ','Select the customer that this inventory request is for.','T','F',30,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='due_date')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','due_date','due_date','Planned Ship Date: ','Enter the planned ship date that this inventory request is due to ship.','T','F','T',20,'Planned Ship Date: ','Enter the planned ship date that this inventory request is due to ship.','T','F',20,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','item_number','item_number','Item Number','Item Number','T','F','T',31,'Item Number','Item Number','T','F',31,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='label')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','label','label','Status: ','Status of this inventory request.','T','F','T',100,'Status: ','Status of this inventory request.','T','F',100,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='last_modified_date')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','last_modified_date','last_modified_date','Last Modified: ','The date that this inventory request is last modified.','T','F','T',30,'Last Modified: ','The date that this inventory request is last modified.','T','F',30,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='last_printed_date')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','last_printed_date','last_printed_date','Last Printed: ','The date that this inventory request is last printed.','T','F','T',30,'Last Printed: ','The date that this inventory request is last printed.','T','F',30,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='line_total')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','line_total','line_total','Line Total','The cost to you of this item per unit.','T','F','F',8,'Line Total','The cost to you of this item per unit.','T','F',8,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='List Form Name')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'List Form Name','List Form Name','','Inventory Request','**','T','F','F',30,'Inventory Request','**','T','F',30,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='order_qty')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','order_qty','order_qty','Requested Qty','Requested Qty','T','F','T',100,'Requested Qty','Requested Qty','T','F',100,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='pick_qty')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','pick_qty','pick_qty','Pick Qty','Pick Qty','T','F','T',100,'Pick Qty','Pick Qty','T','F',100,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='request_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','request_number','request_number','Request Number: ','Enter the inventory request number for this inventory request.','T','F','T',50,'Request Number: ','Enter the inventory request number for this inventory request.','T','F',50,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=31 and field='ship_date')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','ship_date','ship_date','Actual Ship Date: ','The actual date that this inventory request is shipped to the the customer.','T','F','T',10,'Actual Ship Date: ','The actual date that this inventory request is shipped to the the customer.','T','F',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id= 31 and field='staging_location')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','staging_location','staging_location','Staging Location: ','Staging location for this inventory request.','T','F','T',255,'Staging Location: ','Staging location for this inventory request.','T','F',255,NULL,NULL,NULL,1,1,'F')
END

if NOT EXISTS (select visible from form_field_meta where form_id= 31 and field='total_cost')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','total_cost','total_cost','Total Cost: ','Total item cost for this inventory request.','T','F','T',100,'Total Cost: ','Total item cost for this inventory request.','T','F',100,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id= 31 and field='tracking_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(31,'Label','tracking_number','tracking_number','Tracking Number: ','Enter the carrier tracking number.','T','F','T',255,'Tracking Number: ','Enter the carrier tracking number.','T','F',255,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1003 and field='trancode')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) 
	values (1003,'Label','trancode','trancode','TranCode:','Transaction Code',null,null,'T',null,'TranCode:','Transaction Code',null,null,null,null,null,5,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1004 and field='absolute_adjust')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1004,'Label','absolute_adjust','absolute_adjust','By Count','Pick a reason from the list for adjustment','T','F','T',25,'By Count','Pick a reason from the list for adjustment','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1004 and field='diff_type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1004,'Label','diff_type','diff_type','Adjust:','Adjust Type',null,null,'T',null,'Adjust:','Adjust Type',null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1004 and field='reason')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1004,'Label','reason','reason','Reason:','Reason',null,null,'T',null,'Reason:','Reason',null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1004 and field='relative_adjust')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1004,'Label','relative_adjust','relative_adjust','By Diff','Pick a reason from the list for adjustment','T','F','T',25,'By Diff','Pick a reason from the list for adjustment','T','F',25,null,null,null,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1004 and field='trancode')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1004,'Label','trancode','trancode','TranCode:','Transaction Code',null,null,'T',null,'TranCode:','Transaction Code',null,null,null,null,null,5,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='alt_item_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','alt_item_number','alt_item_number','Alt #:','Alt Item Number','T','T','T',30,'Alt #:','Alt Item Number','T','T',30,null,null,3,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='desc')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','desc','description','Desc:','Description','T','T','T',30,'Desc:','Description','T','T',30,null,null,2,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='item_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','item_number','item_number','Item #:','Item Number','T','T','T',30,'Item #:','Item Number','T','T',30,null,null,1,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='location')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','location','location','Location:','Location',null,null,'T',null,'Location:','Location',null,null,null,null,null,4,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='po')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','po','po','PO:','PO',null,null,'T',null,'PO:','PO',null,null,null,null,null,5,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','quantity','quantity','Add Qty:','Add Qty',null,null,'T',null,'Add Qty:','Add Qty',null,null,null,null,null,8,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='Review - Add')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Title','Review - Add','na','Review Receive','na','T','T','T',null,'Review Receive','na','T','T',null,null,null,0,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='serial_no')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','serial_no','serial_number','Serial #:','Serial Number',null,null,'T',null,'Serial #:','Serial Number',null,null,null,null,null,7,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1006 and field='supplier')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1006,'Label','supplier','supplier','Supplier:',null,null,null,'T',null,'Supplier:',null,null,null,null,null,null,6,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='alt_item_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Label','alt_item_number','alt_item_number','Alt #:','Alt Item Number','T','T','T',30,'Alt #:','Alt Item Number','T','T',30,null,null,3,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='customer')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Label','customer','customer','Customer:','Customer',null,null,'T',null,'Customer:','Customer',null,null,null,null,null,5,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='desc')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Label','desc','description','Desc:','Description','T','T','T',30,'Desc:','Description','T','T',30,null,null,2,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='item_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Label','item_number','item_number','Item #:','Item Number','T','T','T',30,'Item #:','Item Number','T','T',30,null,null,1,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='location')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Label','location','location','Location:','Location',null,null,'T',null,'Location:','Location',null,null,null,null,null,4,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Label','quantity','quantity','Qty:','Quantity',null,null,'T',null,'Qty:','Quantity',null,null,null,null,null,7,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='Review - Remove')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Title','Review - Remove','na','Review Pick','na','T','T','T',null,'Review Pick','na','T','T',null,null,null,0,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id= 1007 and field='serial_no')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (1007,'Label','serial_no','serial_number','Serial #:','Serial Number',null,null,'T',null,'Serial #:','Serial Number',null,null,null,null,null,6,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=10100 and field='stage')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10100,'','stage','','Stage','','','','T',10,'Stage','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10104 and field='trancode')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (10104,null,'trancode','trancode','TranCode','Transaction Code',null,null,'T',null,'TranCode','Transaction Code',null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=10106 and field='trancode')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (10106,null,'trancode','trancode','TranCode','Transaction Code',null,null,'T',null,'TranCode','Transaction Code',null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','date_code','','Date Code','','','','T',10,'Date Code','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='from')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','from','','From','','','','T',10,'From','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='item_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','item_no','','Item #','','','','T',10,'Item #','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','lot','','Lot','','','','T',10,'Lot','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='orderno')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','orderno','','Request Number','','','','T',10,'Request Number','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','pallet','','Pallet','','','','T',10,'Pallet','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','quantity','','Quantity','','','','T',10,'Quantity','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='sn')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','sn','','SN','','','','T',10,'SN','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='title')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','title','','Stage','','','','T',10,'Stage','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='to')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','to','','Stage Location','','','','T',10,'Stage Location','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10112 and field='transaction_count')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10112,'','transaction_count','','Transaction Count','','','','T',10,'Transaction Count','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','date_code','','Date Code:','','','','T',10,'Date Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','item_number','','Item #:','','','','T',10,'Item #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='location')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','location','','Location:','','','','T',10,'Location:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','lot','','Lot:','','','','T',10,'Lot:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','pallet','','Pallet:','','','','T',10,'Pallet:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='po')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','po','','PO:','','','','T',10,'PO:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','quantity','','Qty:','','','','T',10,'Qty:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='serial_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','serial_no','','Serial #:','','','','T',10,'Serial #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='site')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','site','','Site:','','','','T',10,'Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END	

if NOT EXISTS (select visible from form_field_meta where form_id=10200 and field='supplier')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10200,'','supplier','','Supplier:','','','','T',10,'Supplier:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='customer')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','customer','','Customer:','','','','T',10,'Customer:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','date_code','','Date Code:','Date Code','','','T',10,'Date Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','item_number','','Item #:','','','','T',10,'Item #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='location')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','location','','Location:','','','','T',10,'Location:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','lot','','Lot:','','','','T',10,'Lot:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','pallet','','Pallet:','','','','T',10,'Pallet:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','quantity','','Qty:','','','','T',10,'Qty:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='serial_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','serial_no','','Serial #:','','','','T',10,'Serial #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10201 and field='site')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10201,'','site','','Site:','','','','T',10,'Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','date_code','','Date Code:','','','','T',10,'Date Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='fromlocation')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','fromlocation','','From Loc:','','','','T',10,'From Loc:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='fromsite')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','fromsite','','From Site:','','','','T',10,'From Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','item_number','','Item #:','','','','T',10,'Item #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','lot','','Lot:','','','','T',10,'Lot:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','pallet','','Pallet:','','','','T',10,'Pallet:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','quantity','','Qty:','','','','T',10,'Qty:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='serial_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','serial_no','','Serial #:','','','','T',10,'Serial #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='tolocation')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','tolocation','','To Loc:','','','','T',10,'To Loc:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10202 and field='tosite')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10202,'','tosite','','To Site:','','','','T',10,'To Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','date_code','','Date Code:','','','','T',10,'Date Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','item_number','','Item #:','','','','T',10,'Item #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='location')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','location','','Location:','','','','T',10,'Location:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','lot','','Lot:','','','','T',10,'Lot:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','pallet','','Pallet:','','','','T',10,'Pallet:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','quantity','','Qty:','','','','T',10,'Qty:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='reason')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','reason','','Reason:','','','','T',10,'Reason:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='serial_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','serial_no','','Serial #:','','','','T',10,'Serial #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='site')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','site','','Site:','','','','T',10,'Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10203 and field='trancode')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10203,'','trancode','','Trans Code:','','','','T',10,'Trans Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','date_code','','Date Code:','','','','T',10,'Date Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','item_number','','Item #:','','','','T',10,'Item #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='location')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','location','','Location:','','','','T',10,'Location:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','lot','','Lot:','','','','T',10,'Lot:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','pallet','','Pallet:','','','','T',10,'Pallet:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','quantity','','Qty:','','','','T',10,'Qty:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='serial_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','serial_no','','Serial #:','','','','T',10,'Serial #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10204 and field='site')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10204,'','site','','Site:','','','','T',10,'Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END	

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','date_code','','Date Code:','','','','T',10,'Date Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','item_number','','Item #:','','','','T',10,'Item #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='location')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','location','','Location:','','','','T',10,'Location:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','lot','','Lot:','','','','T',10,'Lot:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','pallet','','Pallet:','','','','T',10,'Pallet:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','quantity','','Qty:','','','','T',10,'Qty:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='serial_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','serial_no','','Serial #:','','','','T',10,'Serial #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='site')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','site','','Site:','','','','T',10,'Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END	

if NOT EXISTS (select visible from form_field_meta where form_id=10205 and field='trancode')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10205,'','trancode','','Trans Code:','','','','T',10,'Trans Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='date_code')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','date_code','','Date Code:','','','','T',10,'Date Code:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='fromlocation')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','fromlocation','','From Loc:','','','','T',10,'From Loc:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='fromsite')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','fromsite','','From Site:','','','','T',10,'From Site:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='item_number')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','item_number','','Item #:','','','','T',10,'Item #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='lot')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','lot','','Lot:','','','','T',10,'Lot:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='orderno')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','orderno','','Request Number','','','','T',10,'Request Number','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='pallet')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','pallet','','Pallet:','','','','T',10,'Pallet:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','quantity','','Qty:','','','','T',10,'Qty:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='serial_no')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','serial_no','','Serial #:','','','','T',10,'Serial #:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='tolocation')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','tolocation','','To Loc:','','','','T',10,'To Loc:','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=10206 and field='tosite')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(10206,'','tosite','','Stage Site:','Stage Site','','','T',10,'Stage Site:','Stage Site','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='date_shipped')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(90000,'CR','date_shipped','date_shipped','Date Shipped','','','','T',10,'Date Shipped','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='item_description')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(90000,'CR','item_description','item_description','Item Number : Description','','','','T',10,'Item Number : Description','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='min_date')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(90000,'CR','min_date','min_date','1800','','','','T',10,'1800','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='quantity_picked')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(90000,'CR','quantity_picked','quantity_picked','Quantity Picked','','','','T',10,'Quantity Picked','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='shipped_quantity')
BEGIN
	INSERT into form_field_meta
	(form_id, control, field, db_field, label, tool_tip, visible, required, user_editable, field_length, default_label, default_tool_tip, default_visible, default_required, default_field_length, data_type, send_to_palm, sort_order, record_status, company_id, should_find)
	VALUES
	(90000,'CR','shipped_quantity','shipped_quantity','Shipped Quantity','','','','T',10,'Shipped Quantity','','','',10,NULL,NULL,NULL,1,1,'T')
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='accepted_qty')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','accepted_qty','accepted_qty','Accepted Qty',null,null,null,'T',null,'Accepted Qty',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='active')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','active','active','Active',null,null,null,'T',null,'Active',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='add_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','add_date','add_date','Add Date',null,'T','T','T',null,'Add Date',null,'T','T',null,62,null,1,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='add_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','add_total','add_total','Adds',null,null,null,'T',null,'Adds',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='adjust_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','adjust_date','adjust_date','Adjust Date',null,null,null,'T',null,'Adjust Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='adjustin_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','adjustin_total','adjustin_total','Adjusts In',null,null,null,'T',null,'Adjusts In',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='adjustout_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','adjustout_total','adjustout_total','Adjusts Out',null,null,null,'T',null,'Adjusts Out',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='audit_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','audit_date','audit_date','Audit Date',null,null,null,'T',null,'Audit Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='audited_qty')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','audited_qty','audited_qty','Audited Qty',null,null,null,'T',null,'Audited Qty',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='back_order')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','back_order','back_order','Back Order',null,null,null,'T',null,'Back Order',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='bill_to')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','bill_to','bill_to','BILL TO',null,null,null,'T',null,'BILL TO',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='checkin_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','checkin_date','checkin_date','Check-in Date',null,null,null,'T',null,'Check-in Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='checkout_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','checkout_date','checkout_date','Check-out Date',null,null,null,'T',null,'Check-out Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='current_qty')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','current_qty','current_qty','Current Qty',null,null,null,'T',null,'Current Qty',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='customer')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','customer','customer','Customer',null,null,null,'T',null,'Customer',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='customer_message')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','customer_message','customer_message','Customer Message',null,null,null,'T',null,'Customer Message',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='customer_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','customer_name','customer_name','Customer Name',null,null,null,'T',null,'Customer Name',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','date','date','Date','','T','T','T',null,'Date','','T','T',null,62,null,1,1,1,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='description')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','description','description','Description',null,null,null,'T',null,'Description',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='discrepancy')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','discrepancy','discrepancy','Discrepancy',null,null,null,'T',null,'Discrepancy',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='due_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','due_date','due_date','Due Date',null,null,null,'T',null,'Due Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='dvalue')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','dvalue','dvalue','Dvalue',null,null,null,'T',null,'Dvalue',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='end_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','end_date','end_date','End  Date',null,null,null,'T',null,'End  Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='end_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','end_total','end_total','Ending',null,null,null,'T',null,'Ending',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='error_description')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','error_description','error_description','Error Description',null,null,null,'T',null,'Error Description',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='error_number')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','error_number','error_number','Error Number',null,null,null,'T',null,'Error Number',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='error_type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','error_type','error_type','Error Type',null,null,null,'T',null,'Error Type',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='expected_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','expected_date','expected_date','Expected Date',null,null,null,'T',null,'Expected Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='first_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','first_name','first_name','First Name',null,null,null,'T',null,'First Name',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='grand_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','grand_total','grand_total','Grand Total',null,null,null,'T',null,'Grand Total',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='id_reference')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','id_reference','id_reference','ID/Reference',null,null,null,'T',null,'ID/Reference',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='inactive')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','inactive','inactive','Inactive',null,null,null,'T',null,'Inactive',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='internal_id')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','internal_id','internal_id','Internal ID',null,null,null,'T',null,'Internal ID',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='invoice_status')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','invoice_status','invoice_status','Invoice Status',null,null,null,'T',null,'Invoice Status',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='item')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','item','item','Item',null,null,null,'T',null,'Item',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='item_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','item_total','item_total','Item Total',null,null,null,'T',null,'Item Total',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='last_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','last_name','last_name','Last Name',null,null,null,'T',null,'Last Name',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='line_item_count')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','line_item_count','line_item_count','Line Item Count',null,null,null,'T',null,'Line Item Count',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='login_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','login_name','login_name','Login Name',null,null,null,'T',null,'Login Name',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='memo')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','memo','memo','Memo',null,null,null,'T',null,'Memo',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='move_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','move_date','move_date','Move Date',null,null,null,'T',null,'Move Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='move_to')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','move_to','move_to','Move To',null,null,null,'T',null,'Move To',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='notes')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','notes','notes','Notes',null,null,null,'T',null,'Notes',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='object_type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','object_type','object_type','Object Type',null,null,null,'T',null,'Object Type',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='obsolete')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','obsolete','obsolete','Obsolete',null,null,null,'T',null,'Obsolete',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='order_quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','order_quantity','order_quantity','Original Order Qty',null,null,null,'T',null,'Original Order Qty',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='original_data')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','original_data','original_data','Original Data',null,null,null,'T',null,'Original Data',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='original_qty')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','original_qty','original_qty','Original Qty',null,null,null,'T',null,'Original Qty',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='originating')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','originating','originating','Originating',null,null,null,'T',null,'Originating',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='out_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','out_date','out_date','Out Date',null,null,null,'T',null,'Out Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='parent')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','parent','parent','Parent',null,null,null,'T',null,'Parent',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='pick_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','pick_date','pick_date','Pick Date',null,null,null,'T',null,'Pick Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='po_status')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','po_status','po_status','PO Status',null,null,null,'T',null,'PO Status',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='process_type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','process_type','process_type','Process Type',null,null,null,'T',null,'Process Type',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='putaway_location')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','putaway_location','putaway_location','Put-away Location',null,null,null,'T',null,'Put-away Location',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='putaway_site')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','putaway_site','putaway_site','Put-away Site',null,null,null,'T',null,'Put-away Site',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','quantity','quantity','Quantity',null,null,null,'T',null,'Quantity',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='receive_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','receive_date','receive_date','Receive Date',null,null,null,'T',null,'Receive Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='received_by')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','received_by','received_by','Added By',null,null,null,'T',null,'Added By',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='received_quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','received_quantity','received_quantity','Received Qty',null,null,null,'T',null,'Received Qty',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='remove_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','remove_date','remove_date','Remove Date',null,null,null,'T',null,'Remove Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='remove_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','remove_total','remove_total','Removes',null,null,null,'T',null,'Removes',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='security_options')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','security_options','security_options','Security Options',null,null,null,'T',null,'Security Options',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='ship_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','ship_date','ship_date','Remove Date',null,null,null,'T',null,'Remove Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='ship_quantity')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','ship_quantity','ship_quantity','Ship Quantity',null,null,null,'T',null,'Ship Quantity',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='ship_to')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','ship_to','ship_to','SHIP TO',null,null,null,'T',null,'SHIP TO',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='shipped_by')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','shipped_by','shipped_by','Removed By',null,null,null,'T',null,'Removed By',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='shipped_to')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','shipped_to','shipped_to','Shipped To',null,null,null,'T',null,'Shipped To',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='shipped_value')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','shipped_value','shipped_vlaue','Removed Value',null,null,null,'T',null,'Removed Value',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='site_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','site_total','site_total','Site Total',null,null,null,'T',null,'Site Total',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='slow')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','slow','slow','Slow',null,null,null,'T',null,'Slow',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='start_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','start_date','start_date','Start Date',null,null,null,'T',null,'Start Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='start_total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','start_total','start_total','Beginning',null,null,null,'T',null,'Beginning',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='status')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','status','status','Status',null,null,null,'T',null,'Status',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='supplier')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','supplier','supplier','Supplier',null,null,null,'T',null,'Supplier',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='total')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','total','total','Total',null,null,null,'T',null,'Total',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='transaction_date')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','transaction_date','transaction_date','Transaction Date',null,null,null,'T',null,'Transaction Date',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='type')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','type','type','Type',null,null,null,'T',null,'Type',null,null,null,null,null,null,null,null,null,'T','1','1');
END

if NOT EXISTS (select visible from form_field_meta where form_id=90000 and field='user_name')
BEGIN
	insert into form_field_meta (form_id,control,field,db_field,label,tool_tip,visible,required,user_editable,field_length,default_label,default_tool_tip,default_visible,default_required,default_field_length,data_type,send_to_palm,sort_order,record_status,company_id,should_find,should_export,should_import) values (90000,'CR','user_name','user_name','User Name',null,null,null,'T',null,'User Name',null,null,null,null,null,null,null,null,null,'T','1','1');
END

print '.. security_privileges'

if NOT EXISTS (select * from security_privileges where security_code = 'add')
	insert into security_privileges (security_code,description,company_id) values ('add','Add Inventory',1);
else
	UPDATE security_privileges SET description = 'Add Inventory', company_id = 1 where (security_code = 'add')


if NOT EXISTS (select * from security_privileges where security_code = 'adjust')
	insert into security_privileges (security_code,description,company_id) values ('adjust','Adjust Inventory',1);
else
	UPDATE security_privileges SET description = 'Adjust Inventory', company_id = 1 where (security_code = 'adjust')


if NOT EXISTS (select * from security_privileges where security_code = 'admin')
	insert into security_privileges (security_code,description,company_id) values ('admin','Administration Privilege',1);
else
	UPDATE security_privileges SET description = 'Administration Privilege', company_id = 1 where (security_code = 'admin')


if NOT EXISTS (select * from security_privileges where security_code = 'audit')
	insert into security_privileges (security_code,description,company_id) values ('audit','Audit',1);
else
	UPDATE security_privileges SET description = 'Audit', company_id = 1 where (security_code = 'audit')


if NOT EXISTS (select * from security_privileges where security_code = 'backup')
	insert into security_privileges (security_code,description,company_id) values ('backup','Backup and Restore',1);
else
	UPDATE security_privileges SET description = 'Backup and Restore', company_id = 1 where (security_code = 'backup')


if NOT EXISTS (select * from security_privileges where security_code = 'checkin')
	insert into security_privileges (security_code,description,company_id) values ('checkin','Check In',1);
else
	UPDATE security_privileges SET description = 'Check In', company_id = 1 where (security_code = 'checkin')


if NOT EXISTS (select * from security_privileges where security_code = 'checkout')
	insert into security_privileges (security_code,description,company_id) values ('checkout','Check Out ',1);
else
	UPDATE security_privileges SET description = 'Check Out ', company_id = 1 where (security_code = 'checkout')


if NOT EXISTS (select * from security_privileges where security_code = 'delete')
	insert into security_privileges (security_code,description,company_id) values ('delete','Delete',1);
else
	UPDATE security_privileges SET description = 'Delete', company_id = 1 where (security_code = 'delete')


if EXISTS (select * from security_privileges where security_code = 'falcon')
BEGIN
	DELETE user_privileges WHERE     (security_code = 'falcon')
	DELETE security_privileges where (security_code = 'falcon')
END

if NOT EXISTS (select * from security_privileges where security_code = 'find')
	insert into security_privileges (security_code,description,company_id) values ('find','Find',-1);
else
	UPDATE security_privileges SET description = 'Find', company_id = -1 where (security_code = 'find')

if NOT EXISTS (select * from security_privileges where security_code = 'labels')
	insert into security_privileges (security_code,description,company_id) values ('labels','Labels',-1);
else
	UPDATE security_privileges SET description = 'Labels', company_id = -1 where (security_code = 'labels')


if NOT EXISTS (select * from security_privileges where security_code = 'lists')
	insert into security_privileges (security_code,description,company_id) values ('lists','Lists',-1);
else
	UPDATE security_privileges SET description = 'Lists', company_id = -1 where (security_code = 'lists')


if NOT EXISTS (select * from security_privileges where security_code = 'manageco')
	insert into security_privileges (security_code,description,company_id) values ('manageco','Manage Companies',-1);
else
	UPDATE security_privileges SET description = 'Manage Companies', company_id = -1 where (security_code = 'manageco')


if NOT EXISTS (select * from security_privileges where security_code = 'move')
	insert into security_privileges (security_code,description,company_id) values ('move','Move',1);
else
	UPDATE security_privileges SET description = 'Move', company_id = 1 where (security_code = 'move')


if NOT EXISTS (select * from security_privileges where security_code = 'new')
	insert into security_privileges (security_code,description,company_id) values ('new','New',-1);
else
	UPDATE security_privileges SET description = 'New', company_id = -1 where (security_code = 'new')


if NOT EXISTS (select * from security_privileges where security_code = 'pc')
	insert into security_privileges (security_code,description,company_id) values ('pc','Allow PC Login',1);
else
	UPDATE security_privileges SET description = 'Allow PC Login', company_id = 1 where (security_code = 'pc')

if NOT EXISTS (select * from security_privileges where security_code = 'pda')
	insert into security_privileges (security_code,description,company_id) values ('pda','PDA',1);
else
	UPDATE security_privileges SET description = 'PDA', company_id = 1 where (security_code = 'pda')

if NOT EXISTS (select * from security_privileges where security_code = 'pdt')
	insert into security_privileges (security_code,description,company_id) values ('pdt','PDT',-1);
else
	UPDATE security_privileges SET description = 'PDT', company_id = -1 where (security_code = 'pdt')


if NOT EXISTS (select * from security_privileges where security_code = 'pocketpc')
	insert into security_privileges (security_code,description,company_id) values ('pocketpc','Pocket PC',1);
else
	UPDATE security_privileges SET description = 'Pocket PC', company_id = 1 where (security_code = 'pocketpc')

if NOT EXISTS (select * from security_privileges where security_code = 'remove')
	insert into security_privileges (security_code,description,company_id) values ('remove','Remove Inventory',1);
else
	UPDATE security_privileges SET description = 'Remove Inventory', company_id = 1 where (security_code = 'remove')


if NOT EXISTS (select * from security_privileges where security_code = 'reports')
	insert into security_privileges (security_code,description,company_id) values ('reports','Reports',-1);
else
	UPDATE security_privileges SET description = 'Reports', company_id = -1 where (security_code = 'reports')


if NOT EXISTS (select * from security_privileges where security_code = 'stage')
	insert into security_privileges (security_code,description,company_id) values ('stage','Stage',1);
else
	UPDATE security_privileges SET description = 'Stage', company_id = 1 where (security_code = 'stage')


if NOT EXISTS (select * from security_privileges where security_code = 'upload')
	insert into security_privileges (security_code,description,company_id) values ('upload','Process Mobile Device Data',1);
else
	UPDATE security_privileges SET description = 'Process Mobile Device Data', company_id = 1 where (security_code = 'upload')


if NOT EXISTS (select * from security_privileges where security_code = 'WDT2200')
	insert into security_privileges (security_code,description,company_id) values ('WDT2200','WDT2200',1);
else
	UPDATE security_privileges SET description = 'WDT2200', company_id = 1 where (security_code = 'WDT2200')


print '.. user_privileges'

if NOT EXISTS (select * from user_privileges where security_code = 'pocketpc' and user_id = 1)
BEGIN
	INSERT into user_privileges
	(user_id, security_code, record_status)
	VALUES
	(1, 'pocketpc', 1)
END

/*
-- For v 3.2.5.1 database, we should add 'allow PC login for all existing users
INSERT INTO [user_privileges]
SELECT distinct [user_id], 'pc', 1 FROM [users] where 
[record_status]=1 and [company_id] = 1 and user_id not in (SELECT     user_id
FROM         user_privileges
WHERE     (security_code = 'pc')) and user_id > 0

INSERT INTO [user_privileges]
SELECT distinct [user_id], 'delete', 1 FROM [users] where 
[record_status]=1 and [company_id] = 1 and user_id not in (SELECT     user_id
FROM         user_privileges
WHERE     (security_code = 'delete')) and user_id > 0

INSERT INTO [user_privileges]
SELECT distinct [user_id], 'stage', 1 FROM [users] where 
[record_status]=1 and [company_id] = 1 and user_id not in (SELECT     user_id
FROM         user_privileges
WHERE     (security_code = 'stage')) and user_id > 0

--INSERT INTO [user_privileges]
--SELECT distinct [user_id], 'pocketpc', 1 FROM [users] where 
--[record_status]=1 and [company_id] = 1 and user_id not in (SELECT     user_id
--FROM         user_privileges
--WHERE     (security_code = 'pocketpc')) and user_id > 0

--INSERT INTO [user_privileges]
--SELECT distinct [user_id], 'WDT2200', 1 FROM [users] where 
--[record_status]=1 and [company_id] = 1 and user_id not in (SELECT     user_id
--FROM         user_privileges
--WHERE     (security_code = 'WDT2200')) and user_id > 0
*/

print '.. label_names'

if NOT EXISTS (select lbl_id from label_names where lbl_id=201)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (201,1002,1,'Location Tags','Location Tags','Location Tags',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=204)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (204,1002,4,'Serial Number Tags','Serial Number Tags','Serial Number Tags',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=202)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (202,1002,3,'Site Tags','Site Tags','Site Tags',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=301)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (301,1003,1,'Employee Badges','Employee Badges','Employee Badges',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=101)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (101,1001,-1,'Item Receive Labels','Item Receive Labels','Item Receive Labels',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=103)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (103,1001,3,'Shipping Labels','Shipping Labels','Shipping Labels',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=203)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (203,1002,3,'PO Number Tags','PO Number Tags','PO Number Tags',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=102)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (102,1001,2,'Item Bar Code Labels','Item Bar Code Labels','Item Bar Code Labels',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=1001)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (1001,1010,1,'New','New','New',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=1002)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (1002,1010,2,'Browse...','Browse...','Browse...',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=104)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (104,1001,-1,'Pending added items','AddTransactionItemLabel','Pending added items',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=105)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (105,1001,-1,'Load Ticket','LoadTicket','Load Ticket',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=401)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (401,1004,1,'Inventory Item','Inventory Item','Inventory Item',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=402)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (402,1004,2,'Inventory Lot','Inventory Lot','Inventory Lot',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=403)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (403,1004,3,'Inventory Pallet','Inventory Pallet','Inventory Pallet',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=404)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (404,1004,4,'Inventory DateCode','Inventory DateCode','Inventory DateCode',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=405)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (405,1004,5,'Inventory Location','Inventory Location','Inventory Location',null);
END

if NOT EXISTS (select lbl_id from label_names where lbl_id=406)
BEGIN
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (406,1004,6,'Inventory Serial Number','Inventory Serial Number','Inventory Serial Number',null);
END


print '.. reasons_adjustment'

SET IDENTITY_INSERT reasons_adjustment ON

if NOT EXISTS (select reason_id from reasons_adjustment where reason_id=1)
BEGIN
insert into reasons_adjustment (reason_id,sort_order,adjust_code,description,calculation_method,company_id,record_status) values (1,5,'Breakage',null,-1,1,1);
END

if NOT EXISTS (select reason_id from reasons_adjustment where reason_id=2)
BEGIN
insert into reasons_adjustment (reason_id,sort_order,adjust_code,description,calculation_method,company_id,record_status) values (2,6,'Lost',null,-1,1,1);
END

if NOT EXISTS (select reason_id from reasons_adjustment where reason_id=3)
BEGIN
insert into reasons_adjustment (reason_id,sort_order,adjust_code,description,calculation_method,company_id,record_status) values (3,4,'Negative',null,-1,1,1);
END

if NOT EXISTS (select reason_id from reasons_adjustment where reason_id=6)
BEGIN
insert into reasons_adjustment (reason_id,sort_order,adjust_code,description,calculation_method,company_id,record_status) values (6,2,'Found',null,1,1,1);
END

if NOT EXISTS (select reason_id from reasons_adjustment where reason_id=7)
BEGIN
insert into reasons_adjustment (reason_id,sort_order,adjust_code,description,calculation_method,company_id,record_status) values (7,3,'Return',null,1,1,1);
END

if NOT EXISTS (select reason_id from reasons_adjustment where reason_id=8)
BEGIN
insert into reasons_adjustment (reason_id,sort_order,adjust_code,description,calculation_method,company_id,record_status) values (8,1,'Positive',null,1,1,1);
END

if NOT EXISTS (select reason_id from reasons_adjustment where reason_id=11)
BEGIN
insert into reasons_adjustment (reason_id,sort_order,adjust_code,description,calculation_method,company_id,record_status) values (11,11,'Reversal','This Audit reverses a transaction',-1,1,2);
END

SET IDENTITY_INSERT reasons_adjustment OFF


print '.. report_names'

if NOT EXISTS (select rpt_id from report_names where rpt_id=11001)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11001, 10000, -1, 'Pick Ticket', 'Pick Ticket', 'Pick Ticket', 'F', 'F', null)
END
		
if NOT EXISTS (select rpt_id from report_names where rpt_id=11002)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11002, 10000, -2, 'Packing Slip', 'Packing Slip', 'Packing Slip', 'F', 'F', null)
END

if NOT EXISTS (select rpt_id from report_names where rpt_id=11003)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11003, 10000, -3, 'All Opened Requests Report', 'All Opened Requests Report', 'All Opened Requests Report', 'F', 'F', null)
END

if NOT EXISTS (select rpt_id from report_names where rpt_id=11004)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11004, 10000, -4, 'All Shipped Requests Report', 'All Shipped Requests Report', 'All Shipped Requests Report', 'F', 'F', null)
END

if NOT EXISTS (select rpt_id from report_names where rpt_id=11005)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11005, 10000, -5, 'All Cancelled Requests Report', 'All Cancelled Requests Report', 'All Cancelled Requests Report', 'F', 'F', null)
END

if NOT EXISTS (select rpt_id from report_names where rpt_id=11006)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11006, 10000, -6, 'Pick Ticket with Item and Location Barcodes', 'Pick Ticket with Item and Location Barcodes', 'Pick Ticket with Item and Location Barcodes', 'F', 'F', null)
END

if NOT EXISTS (select rpt_id from report_names where rpt_id=11007)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11007, 10000, -7, 'Inventory Request Summary Report', 'Inventory Request Summary Report', 'Inventory Request Summary Report', 'F', 'F', null)
END

if NOT EXISTS (select rpt_id from report_names where rpt_id=11008)
BEGIN
	insert into report_names (rpt_id, rpt_type, rpt_display_order, rpt_name, rpt_file_name, rpt_default_name, rpt_filter, rpt_show_dialog, rpt_tool_tips)
	VALUES (11008, 10000, -8, 'Miscellaneous Request Summary Report', 'Miscellaneous Request Summary Report', 'Miscellaneous Request Summary Report', 'F', 'F', null)
END





print ''
print '------------------------------------'
print '-- ..  Recreate Views and SPs    '
print '------------------------------------'


-- Now re-create all views and store procedures


print '....   Views'


if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventory3Qty]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventory3Qty]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemTrackBy1]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemTrackBy1]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vAddInventory]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vAddInventory]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventory]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventory]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vAdjustInventory]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vAdjustInventory]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCheckOutInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCheckOutInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCheckedOutQty]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCheckedOutQty]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRSummary]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRSummary]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRinfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRinfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventoryAgingInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventoryAgingInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventoryByTrackby]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventoryByTrackby]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemBarCodeLabel]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemBarCodeLabel]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemCostInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemCostInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemTrackBy]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemTrackBy]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLabelerDateCode]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLabelerDateCode]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLabelerLot]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLabelerLot]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLabelerPallet]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLabelerPallet]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLabelerSN]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLabelerSN]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLocationSerialNumber]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLocationSerialNumber]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vMoveFrom]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vMoveFrom]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vMoveTo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vMoveTo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPIckSumLocation]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPIckSumLocation]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPickReceiveSum]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPickReceiveSum]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPickReceiveSum4]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPickReceiveSum4]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPickReceiveSumLocation]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPickReceiveSumLocation]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPickSum]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPickSum]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vShippingReceivingInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vShippingReceivingInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vTotalInventoryDetail]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vTotalInventoryDetail]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vTransactionByPO]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vTransactionByPO]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vTransactionHistory]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vTransactionHistory]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRCombo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRCombo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventoryByLocSite]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventoryByLocSite]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventoryCost]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventoryCost]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventoryLocation]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventoryLocation]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemReorder]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemReorder]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemReorderByItemTotal]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemReorderByItemTotal]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemReorderByLocation]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemReorderByLocation]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemReorderBySite]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemReorderBySite]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemSummary]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemSummary]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPOinfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPOinfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPickTicketInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPickTicketInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vTotalInventorySummary]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vTotalInventorySummary]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vAuditInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vAuditInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCompanyInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCompanyInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCustomerBillShipAddresses]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCustomerBillShipAddresses]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIR]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIR]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRM]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRM]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInventoryRequest]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInventoryRequest]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInvoiceBillShipAddresses]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInvoiceBillShipAddresses]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInvoiceInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInvoiceInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vItemByCMS]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vItemByCMS]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLabelerItem]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLabelerItem]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLabelerLocation]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLabelerLocation]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLabels4CR]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLabels4CR]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLocationList]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLocationList]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLocationsAndNotes]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLocationsAndNotes]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vMoveToArchived]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vMoveToArchived]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vSiteLocation]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vSiteLocation]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vTransactionHistoryArchived]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vTransactionHistoryArchived]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vUserSecurityInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vUserSecurityInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vBackOrderInvoice]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vBackOrderInvoice]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCompanyAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCompanyAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCompanyFax]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCompanyFax]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCompanyPhone]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCompanyPhone]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCustomerBillingAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCustomerBillingAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCustomerMailingAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCustomerMailingAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vCustomerShippingAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vCustomerShippingAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRBillingShippingAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRBillingShippingAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRMnotes]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRMnotes]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRSummaryM]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRSummaryM]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vIRnotes]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vIRnotes]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInvoiceBillingAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInvoiceBillingAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vInvoiceShippingaddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vInvoiceShippingaddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vLocationAvailable]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vLocationAvailable]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vManufacturerBillingAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vManufacturerBillingAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vNotes]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vNotes]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vNotesInvenTrans]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vNotesInvenTrans]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vSitesAndNotes]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vSitesAndNotes]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vSupplierBillingAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vSupplierBillingAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vSupplierInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vSupplierInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vVendorAddress]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vVendorAddress]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vVendorInfo]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vVendorInfo]
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vBackOrderInvoice
AS
SELECT     dbo.customer.customer_number AS customer_number, dbo.customer.name AS customer_name, dbo.invoice_master.invoice_id, 
                      dbo.invoice_master.ref_number AS invoice_number, dbo.invoice_master.customer_id, dbo.invoice_master.is_pending, dbo.invoice_master.txn_id, 
                      dbo.invoice_master.txn_number, dbo.invoice_master.due_date, dbo.invoice_master.invoice_status, dbo.invoice_master.company_id, 
                      dbo.invoice_master.record_status, dbo.invoice_master.edit_sequence, dbo.invoice_master.line_item_count, dbo.invoice_master.parent_id, 
                      dbo.invoice_master.backorder_id, dbo.invoice_master.po_number, dbo.invoice_master.is_printed, dbo.invoice_master.date_printed, 
                      dbo.invoice_master.has_error, dbo.invoice_master.record_status_date, invoice_master_1.ref_number AS parent_invoice_number, 
                      invoice_master_2.ref_number AS back_order_invoice_number
FROM         dbo.customer INNER JOIN
                      dbo.invoice_master ON dbo.customer.customer_id = dbo.invoice_master.customer_id LEFT OUTER JOIN
                      dbo.invoice_master invoice_master_2 ON dbo.invoice_master.backorder_id = invoice_master_2.invoice_id LEFT OUTER JOIN
                      dbo.invoice_master invoice_master_1 ON dbo.invoice_master.parent_id = invoice_master_1.invoice_id
WHERE     (dbo.invoice_master.parent_id <> 0) OR
                      (dbo.invoice_master.backorder_id <> 0)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vCompanyAddress
AS
SELECT     dbo.company_info.company_id, dbo.company_info.company, dbo.company_info.email, dbo.company_info.website, dbo.company_info.record_status, 
                      dbo.address.record_type, dbo.address.address1, dbo.address.address2, dbo.address.city, dbo.address.state, dbo.address.postal_code, 
                      dbo.address.country, dbo.address.mail_stop
FROM         dbo.address INNER JOIN
                      dbo.company_info ON dbo.address.address_id = dbo.company_info.company_id
WHERE     (dbo.address.table_name = N'Company_info') AND (dbo.address.address_type_id = 1)




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vCompanyFax
AS
SELECT     dbo.company_info.company_id, dbo.phone.phone_number AS [Company Fax]
FROM         dbo.company_info INNER JOIN
                      dbo.phone ON dbo.company_info.company_id = dbo.phone.phone_id
WHERE     (dbo.phone.table_name = N'Company_info') AND (dbo.phone.phone_type_id = 2)




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vCompanyPhone
AS
SELECT     dbo.phone.phone_number AS [Compnay Phone], dbo.company_info.company_id
FROM         dbo.company_info INNER JOIN
                      dbo.phone ON dbo.company_info.company_id = dbo.phone.phone_id
WHERE     (dbo.phone.table_name = N'Company_info') AND (dbo.phone.phone_type_id = 1)




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vCustomerBillingAddress
AS
SELECT     dbo.customer.customer_id, dbo.address.address1, dbo.address.address2, dbo.address.city, dbo.address.state, dbo.address.postal_code, 
                      dbo.address.country, dbo.customer.company_id, dbo.customer.record_status AS customerStatus, dbo.address.record_status, dbo.address.mail_stop, 
                      dbo.customer.customer_number, dbo.customer.name, dbo.address.address3, dbo.address.address4
FROM         dbo.customer LEFT OUTER JOIN
                      dbo.address ON dbo.customer.customer_id = dbo.address.address_id  
WHERE     (dbo.customer.customer_id > 0) AND (dbo.address.table_name = N'Customer') AND (dbo.address.address_type_id = 1)




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO









CREATE VIEW dbo.vCustomerMailingAddress
AS
SELECT     dbo.customer.customer_id, dbo.address.address1, dbo.address.address2, dbo.address.city, dbo.address.state, dbo.address.postal_code, 
                      dbo.address.country, dbo.address.record_status, dbo.customer.record_status AS Expr1, dbo.customer.company_id
FROM         dbo.address INNER JOIN
                      dbo.customer ON dbo.address.address_id = dbo.customer.customer_id AND dbo.address.record_type = 'Customer Mailing'
WHERE     (dbo.customer.customer_id > 0)















GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vCustomerShippingAddress
AS
SELECT     dbo.customer.customer_id, dbo.address.address1, dbo.address.address2, dbo.address.city, dbo.address.state, dbo.address.postal_code, 
                      dbo.address.country, dbo.address.record_status, dbo.customer.record_status AS Expr1, dbo.customer.company_id, dbo.customer.customer_number, 
                      dbo.customer.name, dbo.customer.company_name, dbo.address.address3, dbo.address.address4
FROM         dbo.address INNER JOIN
                      dbo.customer ON dbo.address.address_id = dbo.customer.customer_id AND dbo.address.record_type = 'Customer Shipping'
WHERE     (dbo.customer.customer_id > 0)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vIRMnotes
AS
SELECT     dbo.inventory_request_manual_line.inventory_request_id, dbo.notes.note_text, dbo.inventory_request_manual_line.manual_line_id
FROM         dbo.inventory_request_manual_line INNER JOIN
                      dbo.notes ON dbo.inventory_request_manual_line.manual_line_id = dbo.notes.note_id
WHERE     (dbo.notes.table_name = 'inventory_request_manual_line') AND (dbo.notes.note_text <> '""')



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vIRSummaryM
AS
SELECT     dbo.customer.customer_number, dbo.customer.name AS customer_name, dbo.customer.company_name, dbo.inventory_request.creation_date, 
                      dbo.inventory_request.request_number, dbo.inventory_request.ship_date, dbo.inventory_request_manual_line.item_number, 
                      dbo.inventory_request_manual_line.description, dbo.inventory_request_manual_line.date_acquired, dbo.inventory_request_manual_line.cost, 
                      dbo.inventory_request_manual_line.quantity, dbo.inventory_request_manual_line.picked_quantity, 
                      dbo.inventory_request_manual_line.shipped_quantity
FROM         dbo.inventory_request RIGHT OUTER JOIN
                      dbo.inventory_request_manual_line ON 
                      dbo.inventory_request.inventory_request_id = dbo.inventory_request_manual_line.inventory_request_id LEFT OUTER JOIN
                      dbo.customer ON dbo.inventory_request.customer_id = dbo.customer.customer_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO





CREATE VIEW dbo.vIRnotes
AS
SELECT     dbo.inventory_request_line_item.inventory_request_id, dbo.notes.note_text, dbo.inventory_request_line_item.line_item_id
FROM         dbo.notes INNER JOIN
                      dbo.inventory_request_line_item ON dbo.notes.note_id = dbo.inventory_request_line_item.line_item_id
WHERE     (dbo.notes.table_name = 'inventory_request') AND (dbo.notes.note_text <> '""')




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vInvoiceBillingAddress
AS
SELECT     address_id, record_type, address1, address2, address3, address4, city, state, postal_code, mail_stop, record_status, country
FROM         dbo.address
WHERE     (record_type = 'Invoice Billing')



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vInvoiceShippingaddress
AS
SELECT     address_id, record_type, address1, address2, address3, address4, city, state, postal_code, country, mail_stop, record_status
FROM         dbo.address
WHERE     (record_type = 'Invoice Shipping')



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vLocationAvailable
AS
SELECT     TOP 100 PERCENT dbo.inventory_request_detail.site AS pick_site, dbo.inventory_request_detail.location AS pick_location, 
                      dbo.inventory_request.company_id, dbo.inventory_request.record_status, dbo.inventory_request.inventory_request_id, 
                      dbo.inventory_request_line_item.line_item_id, dbo.inventory_request_detail.is_selected
FROM         dbo.inventory_request INNER JOIN
                      dbo.inventory_request_line_item ON 
                      dbo.inventory_request.inventory_request_id = dbo.inventory_request_line_item.inventory_request_id RIGHT OUTER JOIN
                      dbo.inventory_request_detail ON dbo.inventory_request_line_item.line_item_id = dbo.inventory_request_detail.inventory_request_line_item_id
ORDER BY dbo.inventory_request_detail.is_selected DESC



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO















CREATE VIEW dbo.vManufacturerBillingAddress
AS
SELECT     dbo.manufacturer.manufacturer_id, dbo.address.address1, dbo.address.address2, dbo.address.city, dbo.address.state, dbo.address.postal_code, 
                      dbo.address.country, dbo.address.mail_stop, dbo.address.record_status, dbo.manufacturer.record_status AS manufacturerStauts, 
                      dbo.manufacturer.company_id
FROM         dbo.manufacturer LEFT OUTER JOIN
                      dbo.address ON dbo.manufacturer.manufacturer_id = dbo.address.address_id  
WHERE     (dbo.manufacturer.manufacturer_id > 0)  AND (dbo.address.table_name = N'manufacturer') AND (dbo.address.address_type_id = 1)















GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vNotes
AS
SELECT     note_text, record_status, note_date, note_user_id, table_name, note_id AS other_id
FROM         dbo.notes



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vSupplierBillingAddress
AS
SELECT     dbo.supplier.supplier_id, dbo.address.address1, dbo.address.address2, dbo.address.city, dbo.address.state, dbo.address.postal_code, 
                      dbo.address.country, dbo.address.mail_stop, dbo.address.record_status AS addressStatus, dbo.supplier.record_status AS supplierStatus, 
                      dbo.supplier.company_id
FROM         dbo.supplier LEFT OUTER JOIN
                      dbo.address ON dbo.supplier.supplier_id = dbo.address.address_id  
WHERE     (dbo.supplier.supplier_id > 0) AND (dbo.supplier.record_status = 1) AND (dbo.address.table_name = N'Supplier')  and (dbo.address.address_type_id = 1)  



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vSupplierInfo
AS
SELECT     dbo.supplier.supplier_id, dbo.address.address1 AS supplier_address1, dbo.address.address2 AS supplier_address2, 
                      dbo.address.city AS supplier_city, dbo.address.state AS supplier_state, dbo.address.postal_code AS supplier_postal_code, 
                      dbo.address.country AS supplier_country, dbo.address.record_status AS addressStatus, dbo.supplier.record_status AS supplierStatus, 
                      dbo.supplier.company_id, dbo.phone.phone_number AS supplier_phone_number, dbo.supplier.supplier_number, dbo.supplier.name AS supplier_name,
                       dbo.supplier.email AS supplier_email, dbo.supplier.website AS supplier_website, dbo.supplier.contact_name AS supplier_contact_name
FROM         dbo.supplier LEFT OUTER JOIN
                      dbo.phone ON dbo.supplier.supplier_id = dbo.phone.phone_id LEFT OUTER JOIN
                      dbo.address ON dbo.supplier.supplier_id = dbo.address.address_id  
WHERE     (dbo.supplier.supplier_id > 0)  AND (dbo.address.table_name = N'Supplier') AND (dbo.phone.table_name = N'Supplier') AND 
                      (dbo.address.address_type_id = 1) AND (dbo.phone.phone_type_id = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vVendorInfo
AS
SELECT     dbo.supplier.supplier_id, dbo.address.address1 AS supplier_address1, dbo.address.address2 AS supplier_address2, 
                      dbo.address.city AS supplier_city, dbo.address.state AS supplier_state, dbo.address.postal_code AS supplier_postal_code, 
                      dbo.address.country AS supplier_country, dbo.address.record_status AS addressStatus, dbo.supplier.record_status AS supplierStatus, 
                      dbo.supplier.company_id, dbo.phone.phone_number AS supplier_phone_number, dbo.supplier.supplier_number, dbo.supplier.name AS supplier_name,
                       dbo.supplier.email AS supplier_email, dbo.supplier.website AS supplier_website, dbo.supplier.contact_name AS supplier_contact_name, 
                      dbo.purchase_orders.purchase_order_id, dbo.purchase_orders.vendor_id, dbo.address.address3 AS supplier_address3, 
                      dbo.address.address4 AS supplier_address4, dbo.address.record_type
FROM         dbo.address RIGHT OUTER JOIN
                      dbo.purchase_orders ON dbo.address.address_id = dbo.purchase_orders.purchase_order_id LEFT OUTER JOIN
                      dbo.supplier INNER JOIN
                      dbo.phone ON dbo.supplier.supplier_id = dbo.phone.phone_id ON dbo.purchase_orders.vendor_id = dbo.supplier.supplier_id
WHERE     (dbo.supplier.supplier_id > 0) AND (dbo.address.table_name = N'Supplier') AND (dbo.phone.table_name = N'Supplier') AND 
                      (dbo.address.address_type_id = 1) AND (dbo.phone.phone_type_id = 1)





GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vAuditInfo
AS
SELECT     dbo.audit_transactions.transaction_id, dbo.audit_transactions.trans_type, dbo.audit_transactions.action_type, dbo.audit_transactions.entry_date, 
                      dbo.audit_transactions.trans_date, dbo.audit_transactions.date_acquired, dbo.audit_transactions.quantity, dbo.audit_transactions.current_qty, 
                      dbo.audit_transactions.remaining_qty, dbo.audit_transactions.cost, dbo.audit_transactions.serial_number, dbo.audit_transactions.date_code, 
                      dbo.audit_transactions.pallet, dbo.audit_transactions.lot, dbo.audit_transactions.record_status, dbo.audit_transactions.record_source, 
                      dbo.audit_transactions.company_id, dbo.item.item_number, dbo.item.description AS item_description, dbo.location.description AS location_description, 
                      dbo.location.code, dbo.sites.description AS site_description, dbo.users.last_name, dbo.users.first_name, dbo.sites.site_name, 
                      dbo.audit_transactions.adjust_trans_code
FROM         dbo.item INNER JOIN
                      dbo.audit_transactions ON dbo.item.item_id = dbo.audit_transactions.item_id INNER JOIN
                      dbo.location ON dbo.audit_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.users ON dbo.audit_transactions.user_id = dbo.users.user_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vCompanyInfo
AS
SELECT     dbo.company_info.company_id, dbo.company_info.company, dbo.company_info.email, dbo.company_info.website, dbo.company_info.record_status, 
                      dbo.address.address1 AS Company_address1, dbo.address.address2 AS Company_address2, dbo.address.city AS Company_city, 
                      dbo.address.state AS Company_state, dbo.address.postal_code AS Company_postal_code, dbo.address.country AS Company_country, 
                      dbo.address.mail_stop AS Company_mail_stop, dbo.vCompanyFax.[Company Fax], dbo.vCompanyPhone.[Compnay Phone]
FROM         dbo.company_info LEFT OUTER JOIN
                      dbo.vCompanyFax ON dbo.company_info.company_id = dbo.vCompanyFax.company_id LEFT OUTER JOIN
                      dbo.vCompanyPhone ON dbo.company_info.company_id = dbo.vCompanyPhone.company_id LEFT OUTER JOIN
                      dbo.address ON dbo.company_info.company_id = dbo.address.address_id
WHERE     (dbo.address.table_name = N'Company_info') AND (dbo.address.address_type_id = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO






CREATE VIEW dbo.vCustomerBillShipAddresses
AS
SELECT     dbo.customer.customer_id, dbo.customer.customer_number, dbo.customer.name, dbo.customer.company_name, dbo.customer.email, 
                      dbo.customer.department, dbo.customer.allow_shorting, dbo.customer.date_added, dbo.customer.company_id, dbo.customer.record_status, 
                      dbo.customer.update_user_id, dbo.customer.list_id, dbo.vCustomerBillingAddress.address1 AS Bill_address1, 
                      dbo.vCustomerBillingAddress.address2 AS Bill_address2, dbo.vCustomerBillingAddress.city AS Bill_city, 
                      dbo.vCustomerBillingAddress.state AS Bill_state, dbo.vCustomerBillingAddress.postal_code AS Bill_postal_code, 
                      dbo.vCustomerBillingAddress.country AS Bill_country, dbo.vCustomerBillingAddress.mail_stop AS Bill_mail_stop, 
                      dbo.vCustomerShippingAddress.address1 AS Ship_address1, dbo.vCustomerShippingAddress.address2 AS Ship_address2, 
                      dbo.vCustomerShippingAddress.city AS Ship_city, dbo.vCustomerShippingAddress.state AS Ship_state, 
                      dbo.vCustomerShippingAddress.postal_code AS Ship_postal_code, dbo.vCustomerShippingAddress.country AS Ship_country, 
                      dbo.phone.phone_number, dbo.phone.extension, dbo.phone.record_type, dbo.vCustomerShippingAddress.address3 AS cShip_address3, 
                      dbo.vCustomerShippingAddress.address4 AS cShip_address4, dbo.vCustomerBillingAddress.address3 AS cBill_address3, 
                      dbo.vCustomerBillingAddress.address4 AS cBill_address4
FROM         dbo.customer LEFT OUTER JOIN
                      dbo.phone ON dbo.customer.customer_id = dbo.phone.phone_id LEFT OUTER JOIN
                      dbo.vCustomerShippingAddress ON dbo.customer.customer_id = dbo.vCustomerShippingAddress.customer_id LEFT OUTER JOIN
                      dbo.vCustomerBillingAddress ON dbo.customer.customer_id = dbo.vCustomerBillingAddress.customer_id
WHERE      (dbo.phone.table_name = N'Customer') AND (dbo.phone.phone_type_id = 1)





GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO






CREATE VIEW dbo.vIR
AS
SELECT     dbo.inventory_request.inventory_request_id, dbo.item.item_number, dbo.item.description, dbo.inventory_request_line_item.request_quantity, 
                      dbo.vIRnotes.note_text, dbo.inventory_request_line_item.picked_quantity, dbo.inventory_request_line_item.shipped_quantity, 
                      dbo.inventory_request_line_item.line_item_id, dbo.item.avgcost AS cost
FROM         dbo.inventory_request INNER JOIN
                      dbo.inventory_request_line_item ON dbo.inventory_request.inventory_request_id = dbo.inventory_request_line_item.inventory_request_id INNER JOIN
                      dbo.item ON dbo.inventory_request_line_item.item_id = dbo.item.item_id LEFT OUTER JOIN
                      dbo.vIRnotes ON dbo.inventory_request_line_item.line_item_id = dbo.vIRnotes.line_item_id




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vIRBillingShippingAddress
AS
SELECT     dbo.phone.phone_number, dbo.phone.extension, dbo.phone.record_type, dbo.vCustomerShippingAddress.address1 AS cShip_address1, 
                      dbo.vCustomerShippingAddress.address2 AS cShip_address2, dbo.vCustomerShippingAddress.city AS cShip_city, 
                      dbo.vCustomerShippingAddress.state AS cShip_state, dbo.vCustomerShippingAddress.postal_code AS cShip_postal_code, 
                      dbo.vCustomerShippingAddress.country AS cShip_country, dbo.vCustomerBillingAddress.address1 AS cBill_address1, 
                      dbo.vCustomerBillingAddress.address2 AS cBill_address2, dbo.vCustomerBillingAddress.city AS cBill_city, 
                      dbo.vCustomerBillingAddress.state AS cBill_state, dbo.vCustomerBillingAddress.postal_code AS cBill_postal_code, 
                      dbo.vCustomerBillingAddress.country AS cBill_country, dbo.vCustomerShippingAddress.address3 AS cShip_address3, 
                      dbo.vCustomerShippingAddress.address4 AS cShip_address4, dbo.vCustomerBillingAddress.address3 AS cBill_address3, 
                      dbo.vCustomerBillingAddress.address4 AS cBill_address4, dbo.inventory_request.inventory_request_id, dbo.customer.customer_number, 
                      dbo.customer.name AS customer_name, dbo.customer.company_name, dbo.customer.email, dbo.customer.department
FROM         dbo.inventory_request LEFT OUTER JOIN
                      dbo.phone RIGHT OUTER JOIN
                      dbo.vCustomerShippingAddress RIGHT OUTER JOIN
                      dbo.customer ON dbo.vCustomerShippingAddress.customer_id = dbo.customer.customer_id LEFT OUTER JOIN
                      dbo.vCustomerBillingAddress ON dbo.customer.customer_id = dbo.vCustomerBillingAddress.customer_id ON 
                      dbo.phone.phone_id = dbo.customer.customer_id ON dbo.inventory_request.customer_id = dbo.customer.customer_id
WHERE     (dbo.phone.table_name = N'Customer') AND (dbo.phone.phone_type_id = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO





CREATE VIEW dbo.vIRM
AS
SELECT     dbo.inventory_request.inventory_request_id, dbo.inventory_request_manual_line.item_number, dbo.inventory_request_manual_line.description, 
                      dbo.inventory_request_manual_line.quantity AS request_quantity, dbo.vIRMnotes.note_text, dbo.inventory_request_manual_line.picked_quantity, 
                      dbo.inventory_request_manual_line.shipped_quantity, 0 AS line_item_id, dbo.inventory_request_manual_line.cost
FROM         dbo.inventory_request INNER JOIN
                      dbo.inventory_request_manual_line ON 
                      dbo.inventory_request.inventory_request_id = dbo.inventory_request_manual_line.inventory_request_id INNER JOIN
                      dbo.vIRMnotes ON dbo.inventory_request_manual_line.manual_line_id = dbo.vIRMnotes.manual_line_id







GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vInventoryRequest
AS
SELECT     dbo.inventory_request.request_number, dbo.inventory_request.creation_date, dbo.inventory_request.last_modified_date, 
                      dbo.inventory_request.due_date, dbo.inventory_request.ship_date, dbo.inventory_request.request_status, dbo.inventory_request.carrier, 
                      dbo.inventory_request.tracking_number, dbo.inventory_request.is_canceled, dbo.inventory_request.company_id, 
                      dbo.inventory_request.record_status, dbo.inventory_request.line_item_count, dbo.customer.customer_number, 
                      dbo.customer.name AS customer_name, dbo.location.code AS location, dbo.sites.site_name, 
                      inventory_request_1.request_number AS back_order_number, dbo.inventory_request.inventory_request_id, dbo.inventory_request.customer_id, 
                      dbo.customer.company_name, dbo.customer.email, dbo.customer.department
FROM         dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id RIGHT OUTER JOIN
                      dbo.inventory_request INNER JOIN
                      dbo.inventory_request inventory_request_1 ON dbo.inventory_request.backorder_id = inventory_request_1.inventory_request_id ON 
                      dbo.location.location_id = dbo.inventory_request.staging_location_id LEFT OUTER JOIN
                      dbo.customer ON dbo.inventory_request.customer_id = dbo.customer.customer_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE VIEW dbo.vInvoiceBillShipAddresses
AS
SELECT     dbo.customer.customer_id, dbo.customer.customer_number, dbo.customer.name, dbo.customer.company_name, dbo.customer.email, 
                      dbo.customer.department, dbo.customer.allow_shorting, dbo.customer.date_added, dbo.customer.company_id, dbo.customer.record_status, 
                      dbo.customer.update_user_id, dbo.customer.list_id, dbo.vInvoiceBillingAddress.address1 AS Bill_address1, 
                      dbo.vInvoiceBillingAddress.address2 AS Bill_address2, dbo.vInvoiceBillingAddress.city AS Bill_city, dbo.vInvoiceBillingAddress.state AS Bill_state, 
                      dbo.vInvoiceBillingAddress.postal_code AS Bill_postal_code, dbo.vInvoiceBillingAddress.country AS Bill_country, 
                      dbo.vInvoiceBillingAddress.mail_stop AS Bill_mail_stop, dbo.vInvoiceShippingaddress.address1 AS Ship_address1, 
                      dbo.vInvoiceShippingaddress.address2 AS Ship_address2, dbo.vInvoiceShippingaddress.city AS Ship_city, 
                      dbo.vInvoiceShippingaddress.state AS Ship_state, dbo.vInvoiceShippingaddress.postal_code AS Ship_postal_code, 
                      dbo.vInvoiceShippingaddress.country AS Ship_country, dbo.phone.phone_number, dbo.phone.extension, dbo.phone.record_type, 
                      dbo.vCustomerShippingAddress.address1 AS cShip_address1, dbo.vCustomerShippingAddress.address2 AS cShip_address2, 
                      dbo.vCustomerShippingAddress.city AS cShip_city, dbo.vCustomerShippingAddress.state AS cShip_state, 
                      dbo.vCustomerShippingAddress.postal_code AS cShip_postal_code, dbo.vCustomerShippingAddress.country AS cShip_country, 
                      dbo.vCustomerBillingAddress.address1 AS cBill_address1, dbo.vCustomerBillingAddress.address2 AS cBill_address2, 
                      dbo.vCustomerBillingAddress.city AS cBill_city, dbo.vCustomerBillingAddress.state AS cBill_state, 
                      dbo.vCustomerBillingAddress.postal_code AS cBill_postal_code, dbo.vCustomerBillingAddress.country AS cBill_country, 
                      dbo.invoice_master.invoice_id, dbo.vInvoiceShippingaddress.address3 AS Ship_address3, dbo.vInvoiceShippingaddress.address4 AS Ship_address4,
                       dbo.vInvoiceBillingAddress.address3 AS Bill_address3, dbo.vInvoiceBillingAddress.address4 AS Bill_address4, 
                      dbo.vCustomerShippingAddress.address3 AS cShip_address3, dbo.vCustomerShippingAddress.address4 AS cShip_address4, 
                      dbo.vCustomerBillingAddress.address3 AS cBill_address3, dbo.vCustomerBillingAddress.address4 AS cBill_address4
FROM         dbo.vInvoiceBillingAddress RIGHT OUTER JOIN
                      dbo.invoice_master ON dbo.vInvoiceBillingAddress.address_id = dbo.invoice_master.invoice_id LEFT OUTER JOIN
                      dbo.vInvoiceShippingaddress ON dbo.invoice_master.invoice_id = dbo.vInvoiceShippingaddress.address_id LEFT OUTER JOIN
                      dbo.customer ON dbo.invoice_master.customer_id = dbo.customer.customer_id LEFT OUTER JOIN
                      dbo.vCustomerShippingAddress ON dbo.customer.customer_id = dbo.vCustomerShippingAddress.customer_id LEFT OUTER JOIN
                      dbo.vCustomerBillingAddress ON dbo.customer.customer_id = dbo.vCustomerBillingAddress.customer_id LEFT OUTER JOIN
                      dbo.phone ON dbo.customer.customer_id = dbo.phone.phone_id
WHERE     (dbo.phone.table_name = N'Customer') AND (dbo.phone.phone_type_id = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vInvoiceInfo
AS
SELECT     dbo.invoice_master.invoice_id, dbo.invoice_master.ref_number, dbo.invoice_master.customer_id, dbo.invoice_master.is_pending, 
                      dbo.invoice_master.txn_id, dbo.invoice_master.txn_number, dbo.invoice_master.due_date, dbo.invoice_master.company_id, 
                      dbo.invoice_master.record_status, dbo.invoice_master.edit_sequence, dbo.invoice_master.line_item_count, dbo.invoice_line_items.line_item_id, 
                      dbo.invoice_line_items.txn_line_id, dbo.invoice_line_items.item_id, dbo.invoice_line_items.quantity, dbo.invoice_line_items.picked_quantity, 
                      dbo.item.item_number, dbo.item.description, dbo.item.default_location_id, dbo.item.unit_of_measure, dbo.location.code, dbo.sites.site_name, 
                      dbo.company_info.company, dbo.company_info.website, dbo.customer.customer_number, dbo.customer.name, dbo.customer.company_name, 
                      dbo.customer.email, dbo.invoice_master.invoice_status, dbo.invoice_master.backorder_id, dbo.invoice_master.po_number, 
                      dbo.invoice_master.is_printed, dbo.invoice_master.date_printed, dbo.invoice_master.has_error, dbo.invoice_master.record_status_date, 
                      dbo.customer.allow_shorting
FROM         dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id INNER JOIN
                      dbo.invoice_master INNER JOIN
                      dbo.invoice_line_items ON dbo.invoice_master.invoice_id = dbo.invoice_line_items.invoice_id INNER JOIN
                      dbo.item ON dbo.invoice_line_items.item_id = dbo.item.item_id INNER JOIN
                      dbo.customer ON dbo.invoice_master.customer_id = dbo.customer.customer_id INNER JOIN
                      dbo.company_info ON dbo.invoice_master.company_id = dbo.company_info.company_id ON dbo.location.location_id = dbo.item.default_location_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vItemByCMS
AS
SELECT     dbo.item.item_number, dbo.item.description, dbo.item.cost, dbo.item.avgcost, dbo.category.description AS category_description, 
                      dbo.supplier.name AS supplier_name, dbo.manufacturer.name AS manufacturer_name, dbo.item.record_status, dbo.item.company_id
FROM         dbo.item INNER JOIN
                      dbo.supplier ON dbo.item.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.category ON dbo.item.category_id = dbo.category.category_id INNER JOIN
                      dbo.manufacturer ON dbo.item.manufacturer_id = dbo.manufacturer.manufacturer_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO






CREATE VIEW dbo.vLabelerItem
AS
SELECT     dbo.item.item_number, dbo.item.description, dbo.manufacturer.name
FROM         dbo.item INNER JOIN
                      dbo.manufacturer ON dbo.item.manufacturer_id = dbo.manufacturer.manufacturer_id
WHERE     (dbo.item.record_status = 1)





GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vLabelerLocation
AS
SELECT     dbo.location.code, dbo.location.description AS locationDes, dbo.sites.site_name
FROM         dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id
WHERE     (dbo.location.location_id > 0) AND (dbo.location.record_status = 1)





GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO














CREATE VIEW dbo.vLabels4CR
AS
SELECT     form_id, field, label, company_id
FROM         dbo.form_field_meta














GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vLocationList
AS
SELECT     dbo.sites.site_id, dbo.sites.site_name, dbo.sites.description AS site_description, dbo.sites.record_status AS site_record_status, 
                      dbo.sites.company_id AS site_company_id, dbo.sites.update_user_id AS site_update_user_id, dbo.location.location_id, 
                      dbo.location.description AS location_description, dbo.location.code, dbo.location.default_location, 
                      dbo.location.record_status AS location_record_status, dbo.location.company_id AS location_company_id, 
                      dbo.location.update_user_id AS location_update_user_id
FROM         dbo.location RIGHT OUTER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.location.location_id > 0) AND (dbo.sites.site_id > 0)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vMoveToArchived
AS
SELECT     dbo.history_transactions.transaction_id, dbo.sites.description AS moveto_site_description, dbo.location.description AS moveto_location_description, 
                      dbo.location.code AS moveto_location, dbo.sites.site_name AS moveto_site_name
FROM         dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id INNER JOIN
                      dbo.history_transactions INNER JOIN
                      dbo.item ON dbo.history_transactions.item_id = dbo.item.item_id ON dbo.location.location_id = dbo.history_transactions.other_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vSiteLocation
AS
SELECT     dbo.location.description AS Location_Description, dbo.location.code AS Location, dbo.sites.site_name, dbo.sites.description AS Site_Description
FROM         dbo.location INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.location.record_status = 1) AND (dbo.sites.record_status = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vTransactionHistoryArchived
AS
SELECT     dbo.history_transactions.transaction_id, dbo.item.item_number, dbo.item.description AS item_description, dbo.history_transactions.trans_date, 
                      dbo.history_transactions.trans_type, dbo.history_transactions.quantity, dbo.history_transactions.current_qty, dbo.history_transactions.remaining_qty, 
                      dbo.history_transactions.record_status, dbo.history_transactions.entry_date, dbo.history_transactions.date_acquired, dbo.history_transactions.cost, 
                      dbo.history_transactions.serial_number, dbo.history_transactions.date_code, dbo.history_transactions.pallet, dbo.history_transactions.lot, 
                      dbo.history_transactions.record_source, dbo.history_transactions.company_id, dbo.location.description AS location_description, dbo.location.code, 
                      dbo.sites.description AS site_description, dbo.sites.site_name
FROM         dbo.history_transactions INNER JOIN
                      dbo.item ON dbo.history_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.history_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.item.record_status = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vUserSecurityInfo
AS
SELECT     dbo.users.last_name, dbo.users.first_name, dbo.users.title, dbo.users.department, dbo.users.manager, dbo.users.user_logon, 
                      dbo.user_privileges.security_code, dbo.users.user_id, dbo.users.record_status AS userStatus, dbo.user_privileges.record_status AS optionStatus, 
                      dbo.users.company_id, dbo.security_privileges.description
FROM         dbo.security_privileges INNER JOIN
                      dbo.user_privileges ON dbo.security_privileges.security_code = dbo.user_privileges.security_code LEFT OUTER JOIN
                      dbo.users ON dbo.user_privileges.user_id = dbo.users.user_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vIRCombo
AS
SELECT     *
FROM         dbo.vIR

UNION ALL
SELECT     *
FROM         dbo.vIRM




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vInventory
AS
SELECT     dbo.item.item_number AS Expr1, dbo.item.description AS Expr2, dbo.item.cost AS Expr3, dbo.item.avgcost AS Expr4, 
                      dbo.item.manufacturer_id AS Expr5, dbo.item.category_id AS Expr6, dbo.item.unit_of_measure AS Expr7, dbo.item.reorder_qty AS Expr8, 
                      dbo.item.alt_item_number AS Expr9, dbo.item.linked_file AS Expr10, dbo.item.list_price AS Expr11, dbo.item.sale_price AS Expr12, 
                      dbo.item.supplier_id AS Expr13, dbo.item.max_stock_level AS Expr14, dbo.item.min_stock_level AS Expr15, dbo.item.track_serial_numbers AS Expr16,
                       dbo.item.track_lots AS Expr17, dbo.item.track_date_codes AS Expr18, dbo.item.track_pallets AS Expr19, dbo.item.track_pos AS Expr20, 
                      dbo.item.track_suppliers AS Expr21, dbo.item.track_customers AS Expr22, dbo.item.manager AS Expr23, dbo.item.checkout_duration AS Expr24, 
                      dbo.item.width AS Expr25, dbo.item.height AS Expr26, dbo.item.length AS Expr27, dbo.item.dimension_unit AS Expr28, dbo.item.weight AS Expr29, 
                      dbo.item.weight_unit AS Expr30, dbo.location.site_id AS Expr31, dbo.location.description AS loc_desc, dbo.location.code AS Expr32, 
                      dbo.location.default_location AS Expr33, dbo.location.update_user_id AS Expr34
FROM         dbo.inventory INNER JOIN
                      dbo.item ON dbo.inventory.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id


GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vInventoryByLocSite
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_description, dbo.location.description AS location_description, dbo.location.code, 
                      dbo.sites.description AS site_description, dbo.inventory.quantity, dbo.inventory.record_status, dbo.inventory.company_id, dbo.inventory.item_id, 
                      dbo.inventory.location_id, dbo.sites.site_name
FROM         dbo.inventory INNER JOIN
                      dbo.item ON dbo.inventory.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vInventoryCost
AS
SELECT     dbo.inventory.inventory_id, dbo.inventory.quantity, dbo.inventory.record_status, dbo.inventory.company_id, dbo.item.item_number, 
                      dbo.item.description, dbo.item.cost, dbo.item.avgcost, dbo.location.code, dbo.sites.description AS siteDes, dbo.sites.site_name
FROM         dbo.item INNER JOIN
                      dbo.inventory ON dbo.item.item_id = dbo.inventory.item_id INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.inventory.quantity > 0)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vInventoryLocation
AS
SELECT     dbo.inventory.inventory_id, dbo.item.item_number, dbo.item.description AS item_description, dbo.location.description, dbo.inventory.quantity, 
                      dbo.sites.description AS site_description, dbo.location.code, dbo.inventory.company_id, dbo.inventory.record_status, dbo.sites.site_name
FROM         dbo.inventory INNER JOIN
                      dbo.item ON dbo.inventory.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO










CREATE VIEW dbo.vItemReorder
AS
SELECT     dbo.item.item_number, dbo.item.description AS itemDes, dbo.item.reorder_qty, dbo.item.min_stock_level, dbo.supplier.name AS supplierName, 
                      dbo.item.record_status, dbo.item.company_id, dbo.inventory.quantity, dbo.location.description AS locationDes, dbo.location.code, 
                      dbo.sites.description AS siteDes, dbo.item.max_stock_level
FROM         dbo.item INNER JOIN
                      dbo.inventory ON dbo.item.item_id = dbo.inventory.item_id INNER JOIN
                      dbo.supplier ON dbo.item.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id










GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vItemReorderByItemTotal
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_description, dbo.item.reorder_qty, dbo.item.min_stock_level, 
                      dbo.supplier.name AS supplier_name, dbo.item.record_status, dbo.item.company_id, dbo.item.max_stock_level, SUM(dbo.inventory.quantity) 
                      AS current_quantity
FROM         dbo.item INNER JOIN
                      dbo.inventory ON dbo.item.item_id = dbo.inventory.item_id INNER JOIN
                      dbo.supplier ON dbo.item.supplier_id = dbo.supplier.supplier_id
GROUP BY dbo.item.item_number, dbo.item.description, dbo.item.reorder_qty, dbo.item.min_stock_level, dbo.supplier.name, dbo.item.record_status, 
                      dbo.item.company_id, dbo.item.max_stock_level



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vItemReorderByLocation
AS
SELECT     dbo.inventory.inventory_id, dbo.inventory.item_id, dbo.inventory.location_id, dbo.inventory.quantity, dbo.inventory.max_stock_level, 
                      dbo.inventory.min_stock_level, dbo.inventory.reorder_qty, dbo.inventory.company_id, dbo.inventory.record_status, dbo.item.item_number, 
                      dbo.item.description AS item_description, dbo.location.description AS location_description, dbo.location.code AS location, dbo.sites.site_name, 
                      dbo.sites.description AS site_description, dbo.supplier.supplier_number, dbo.supplier.name AS supplier_name
FROM         dbo.inventory INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id INNER JOIN
                      dbo.item ON dbo.inventory.item_id = dbo.item.item_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.supplier ON dbo.item.supplier_id = dbo.supplier.supplier_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO







CREATE VIEW dbo.vItemReorderBySite
AS
SELECT     dbo.item.item_number, dbo.item.description AS itemDes, dbo.item.reorder_qty, dbo.item.min_stock_level, dbo.supplier.name AS supplierName, 
                      dbo.item.record_status, dbo.item.company_id, dbo.sites.description AS siteDes, dbo.item.max_stock_level, SUM(dbo.inventory.quantity) 
                      AS CurrentQty
FROM         dbo.item INNER JOIN
                      dbo.inventory ON dbo.item.item_id = dbo.inventory.item_id INNER JOIN
                      dbo.supplier ON dbo.item.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
GROUP BY dbo.item.item_number, dbo.item.description, dbo.item.reorder_qty, dbo.item.min_stock_level, dbo.supplier.name, dbo.item.record_status, 
                      dbo.item.company_id, dbo.sites.description, dbo.item.max_stock_level







GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vItemSummary
AS
SELECT     dbo.item.item_number, dbo.item.description, dbo.item.cost, dbo.item.avgcost, dbo.category.description AS catagory, 
                      dbo.manufacturer.name AS manufacturer, dbo.supplier.name AS supplier, dbo.item.min_stock_level, dbo.item.reorder_qty, 
                      dbo.item.record_status AS item_status, dbo.item.company_id, dbo.inventory.quantity, dbo.inventory.record_status AS inventory_status, 
                      dbo.location.code, dbo.sites.description AS site_description, dbo.location.description AS location_description, dbo.sites.site_name, 
                      dbo.item.item_id
FROM         dbo.location INNER JOIN
                      dbo.inventory ON dbo.location.location_id = dbo.inventory.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id RIGHT OUTER JOIN
                      dbo.item INNER JOIN
                      dbo.category ON dbo.item.category_id = dbo.category.category_id INNER JOIN
                      dbo.manufacturer ON dbo.item.manufacturer_id = dbo.manufacturer.manufacturer_id INNER JOIN
                      dbo.supplier ON dbo.item.supplier_id = dbo.supplier.supplier_id ON dbo.inventory.item_id = dbo.item.item_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vPOinfo
AS
SELECT     dbo.item.item_number, dbo.item.description, dbo.po_line_item.quantity, dbo.po_line_item.quantity_received, dbo.purchase_orders.po_type, 
                      dbo.purchase_orders.ref_number, dbo.purchase_orders.due_date, dbo.purchase_orders.record_status, dbo.purchase_orders.company_id, 
                      dbo.vCompanyInfo.company, dbo.vCompanyInfo.email, dbo.vCompanyInfo.website, dbo.vCompanyInfo.Company_address1, 
                      dbo.vCompanyInfo.Company_address2, dbo.vCompanyInfo.Company_city, dbo.vCompanyInfo.Company_state, 
                      dbo.vCompanyInfo.Company_postal_code, dbo.vCompanyInfo.Company_country, dbo.vCompanyInfo.[Company Fax], 
                      dbo.vCompanyInfo.[Compnay Phone], dbo.vVendorInfo.supplier_address1, dbo.vVendorInfo.supplier_address2, dbo.vVendorInfo.supplier_city, 
                      dbo.vVendorInfo.supplier_state, dbo.vVendorInfo.supplier_postal_code, dbo.vVendorInfo.supplier_country, dbo.vVendorInfo.supplier_phone_number, 
                      dbo.vVendorInfo.supplier_number, dbo.vVendorInfo.supplier_name, dbo.vVendorInfo.supplier_email, dbo.vVendorInfo.supplier_website, 
                      dbo.vVendorInfo.supplier_contact_name, dbo.po_line_item.line_item_id, dbo.purchase_orders.purchase_order_id, 
                      dbo.location.description AS location_description, dbo.location.code AS location, dbo.sites.site_name, dbo.sites.description AS site_description, 
                      dbo.vVendorInfo.supplier_address3, dbo.vVendorInfo.supplier_address4, dbo.customer.customer_number, dbo.customer.name AS customer_name, 
                      dbo.purchase_orders.po_status
FROM         dbo.vVendorInfo RIGHT OUTER JOIN
                      dbo.item INNER JOIN
                      dbo.po_line_item INNER JOIN
                      dbo.purchase_orders ON dbo.po_line_item.purchase_order_id = dbo.purchase_orders.purchase_order_id ON 
                      dbo.item.item_id = dbo.po_line_item.item_id INNER JOIN
                      dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id ON dbo.item.default_location_id = dbo.location.location_id LEFT OUTER JOIN
                      dbo.customer ON dbo.purchase_orders.customer_id = dbo.customer.customer_id ON 
                      dbo.vVendorInfo.purchase_order_id = dbo.purchase_orders.purchase_order_id LEFT OUTER JOIN
                      dbo.vCompanyInfo ON dbo.purchase_orders.company_id = dbo.vCompanyInfo.company_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vPickTicketInfo
AS
SELECT     dbo.vInvoiceInfo.ref_number, dbo.vCustomerBillingAddress.customer_id, dbo.vCompanyInfo.company_id
FROM         dbo.vInvoiceInfo LEFT OUTER JOIN
                      dbo.vCompanyInfo ON dbo.vInvoiceInfo.company_id = dbo.vCompanyInfo.company_id LEFT OUTER JOIN
                      dbo.vCustomerBillingAddress ON dbo.vInvoiceInfo.customer_id = dbo.vCustomerBillingAddress.customer_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vTotalInventorySummary
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_des, dbo.inventory.quantity, dbo.inventory.max_stock_level, dbo.inventory.min_stock_level, 
                      dbo.inventory.reorder_qty, dbo.inventory.company_id, dbo.sites.site_name, dbo.sites.description AS site_des, dbo.location.code AS location, 
                      dbo.location.description AS location_des, dbo.item.cost, dbo.item.avgcost, dbo.item.record_status
FROM         dbo.inventory INNER JOIN
                      dbo.item ON dbo.inventory.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vAddInventory
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.item.item_number, dbo.item.description AS item_description, 
                      dbo.location.description AS location_description, dbo.inventory_transactions.trans_date, dbo.inventory_transactions.date_acquired, 
                      dbo.inventory_transactions.quantity, dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, 
                      dbo.inventory_transactions.pallet, dbo.inventory_transactions.lot, dbo.location.code, dbo.inventory_transactions.company_id, 
                      dbo.sites.description AS site_description, dbo.inventory_transactions.trans_type, dbo.supplier.name AS supplier_name, 
                      dbo.inventory_transactions.action_type, dbo.inventory_transactions.entry_date, dbo.inventory_transactions.current_qty, 
                      dbo.inventory_transactions.remaining_qty, dbo.inventory_transactions.cost, dbo.inventory_transactions.record_status, 
                      dbo.inventory_transactions.record_source, dbo.inventory_transactions.user_id, dbo.users.last_name, dbo.users.first_name, 
                      dbo.customer.name AS customer_name, dbo.customer.customer_number, dbo.sites.site_name, dbo.inventory_transactions.line_item_id, 
                      dbo.inventory_transactions.po
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.supplier ON dbo.inventory_transactions.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.users ON dbo.inventory_transactions.user_id = dbo.users.user_id INNER JOIN
                      dbo.customer ON dbo.inventory_transactions.customer_id = dbo.customer.customer_id
WHERE     (dbo.item.record_status = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vAdjustInventory
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.item.item_number, dbo.item.description AS item_description, 
                      dbo.location.description AS location_description, dbo.inventory_transactions.trans_date, dbo.inventory_transactions.date_acquired, 
                      dbo.inventory_transactions.quantity, dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, 
                      dbo.inventory_transactions.pallet, dbo.inventory_transactions.lot, dbo.location.code, dbo.inventory_transactions.company_id, 
                      dbo.sites.description AS site_description, dbo.inventory_transactions.trans_type, dbo.supplier.name AS supplier_name, 
                      dbo.inventory_transactions.action_type, dbo.inventory_transactions.entry_date, dbo.inventory_transactions.current_qty, 
                      dbo.inventory_transactions.remaining_qty, dbo.inventory_transactions.cost, dbo.inventory_transactions.record_status, 
                      dbo.inventory_transactions.record_source, dbo.inventory_transactions.user_id, dbo.users.last_name, dbo.users.first_name, 
                      dbo.customer.name AS customer_name, dbo.customer.customer_number, dbo.sites.site_name, dbo.reasons_adjustment.adjust_code, 
                      dbo.reasons_adjustment.description AS adjust_reason_description, dbo.reasons_adjustment.calculation_method, 
                      dbo.inventory_transactions.adjust_type, dbo.inventory_transactions.adjust_reason_id, dbo.inventory_transactions.adjust_trans_code
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.supplier ON dbo.inventory_transactions.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.users ON dbo.inventory_transactions.user_id = dbo.users.user_id INNER JOIN
                      dbo.customer ON dbo.inventory_transactions.customer_id = dbo.customer.customer_id LEFT OUTER JOIN
                      dbo.reasons_adjustment ON dbo.inventory_transactions.adjust_reason_id = dbo.reasons_adjustment.reason_id
WHERE     (dbo.item.record_status = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vCheckOutInfo
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.item.item_number, dbo.item.description AS item_description, 
                      dbo.location.description AS location_description, dbo.customer.name, dbo.inventory_transactions.trans_date, 
                      dbo.inventory_transactions.date_acquired, dbo.inventory_transactions.quantity, dbo.inventory_transactions.serial_number, 
                      dbo.inventory_transactions.date_code, dbo.inventory_transactions.pallet, dbo.inventory_transactions.lot, dbo.location.code, 
                      dbo.inventory_transactions.company_id, dbo.sites.description AS site_description, dbo.inventory_transactions.record_status, 
                      dbo.inventory_transactions.user_id, dbo.inventory_transactions.trans_type, dbo.inventory_transactions.entry_date, 
                      dbo.inventory_transactions.current_qty, dbo.inventory_transactions.remaining_qty, dbo.inventory_transactions.cost, 
                      dbo.inventory_transactions.record_source, dbo.inventory_transactions.action_type, dbo.supplier.name AS supplier_name, dbo.sites.site_name, 
                      dbo.customer.customer_number
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.customer ON dbo.inventory_transactions.customer_id = dbo.customer.customer_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.supplier ON dbo.inventory_transactions.supplier_id = dbo.supplier.supplier_id
WHERE     (dbo.customer.customer_id > 0)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vCheckedOutQty
AS
SELECT     item_id, SUM(remaining_qty) AS CheckedoutQty, company_id, location_id
FROM         dbo.inventory_transactions
WHERE     (trans_type = 350) AND (record_status = 1)
GROUP BY item_id, company_id, location_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vIRSummary
AS
SELECT     dbo.customer.customer_number, dbo.customer.name AS customer_name, dbo.customer.company_name, dbo.inventory_request.creation_date, 
                      dbo.inventory_request.request_number, dbo.inventory_request.ship_date, dbo.vIRCombo.item_number, dbo.vIRCombo.description, 
                      dbo.vIRCombo.request_quantity, dbo.vIRCombo.note_text, dbo.vIRCombo.picked_quantity, dbo.vIRCombo.shipped_quantity, 
                      dbo.vIRCombo.line_item_id, dbo.vIRCombo.cost
FROM         dbo.vIRCombo INNER JOIN
                      dbo.inventory_request ON dbo.vIRCombo.inventory_request_id = dbo.inventory_request.inventory_request_id LEFT OUTER JOIN
                      dbo.customer ON dbo.inventory_request.customer_id = dbo.customer.customer_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vIRinfo
AS
SELECT     dbo.inventory_request.inventory_request_id, dbo.inventory_request.request_number, dbo.inventory_request.creation_date, 
                      dbo.inventory_request.last_modified_date, dbo.inventory_request.due_date, dbo.inventory_request.ship_date, dbo.inventory_request.request_status, 
                      dbo.inventory_request.customer_id, dbo.inventory_request.carrier, dbo.inventory_request.tracking_number, dbo.inventory_request.is_canceled, 
                      dbo.inventory_request.record_status, dbo.inventory_request.line_item_count, dbo.inventory_request.parent_id, dbo.inventory_request.backorder_id, 
                      dbo.inventory_request.is_printed, location_1.code AS stage_location, sites_1.site_name AS stage_site, dbo.vIRCombo.item_number, 
                      dbo.vIRCombo.description, dbo.vIRCombo.request_quantity, dbo.vIRCombo.note_text, dbo.vIRCombo.picked_quantity, 
                      dbo.vIRCombo.shipped_quantity, dbo.vIRCombo.line_item_id, dbo.vIRCombo.cost
FROM         dbo.vIRCombo INNER JOIN
                      dbo.inventory_request ON dbo.vIRCombo.inventory_request_id = dbo.inventory_request.inventory_request_id LEFT OUTER JOIN
                      dbo.location location_1 INNER JOIN
                      dbo.sites sites_1 ON location_1.site_id = sites_1.site_id ON dbo.inventory_request.staging_location_id = location_1.location_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vInventoryAgingInfo
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_des, dbo.sites.site_name, dbo.sites.description AS site_des, dbo.location.code AS location, 
                      dbo.location.description AS location_des, dbo.inventory_transactions.record_status, dbo.inventory_transactions.company_id, 
                      isnull(SUM(CASE WHEN datediff([d], dbo.inventory_transactions.trans_date, GETDATE()) <= 30 THEN dbo.inventory_transactions.remaining_qty END) ,0)
                      AS qtyActive, isnull(SUM(CASE WHEN datediff([d], dbo.inventory_transactions.trans_date, GETDATE()) > 30 AND datediff([d], 
                      dbo.inventory_transactions.trans_date, GETDATE()) <= 60 THEN dbo.inventory_transactions.remaining_qty END),0) AS qtySlow, 
                      isnull(SUM(CASE WHEN datediff([d], dbo.inventory_transactions.trans_date, GETDATE()) > 60 AND datediff([d], dbo.inventory_transactions.trans_date, 
                      GETDATE()) <= 120 THEN dbo.inventory_transactions.remaining_qty END),0) AS qtyInActive, isnull(SUM(CASE WHEN datediff([d], 
                      dbo.inventory_transactions.trans_date, GETDATE()) > 120 THEN dbo.inventory_transactions.remaining_qty END),0) AS qtyObsolete
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.inventory_transactions.record_status = 1) AND (dbo.inventory_transactions.trans_type IN (100, 200, 400, 500))
GROUP BY dbo.item.item_number, dbo.item.description, dbo.sites.site_name, dbo.sites.description, dbo.location.code, dbo.location.description, 
                      dbo.inventory_transactions.record_status, dbo.inventory_transactions.company_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vInventoryByTrackby
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_description, dbo.location.description AS location_description, dbo.inventory_transactions.lot, 
                      dbo.inventory_transactions.pallet, dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, dbo.location.code, 
                      dbo.inventory_transactions.company_id, dbo.inventory_transactions.record_status, dbo.sites.description AS site_description, 
                      SUM(dbo.inventory_transactions.remaining_qty) AS remaining_quantity, dbo.sites.site_name
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.inventory_transactions.trans_type <> 350)
GROUP BY dbo.item.item_number, dbo.item.description, dbo.location.description, dbo.inventory_transactions.lot, dbo.inventory_transactions.pallet, 
                      dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, dbo.location.code, dbo.inventory_transactions.company_id, 
                      dbo.inventory_transactions.record_status, dbo.sites.description, dbo.sites.site_name



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vItemBarCodeLabel
AS
SELECT     dbo.item.item_number, dbo.location.code, dbo.sites.site_name, dbo.item.description, dbo.inventory_transactions.print_label_no
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.po_line_item ON dbo.inventory_transactions.line_item_id = dbo.po_line_item.line_item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.purchase_orders ON dbo.po_line_item.purchase_order_id = dbo.purchase_orders.purchase_order_id INNER JOIN
                      dbo.item ON dbo.po_line_item.item_id = dbo.item.item_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE VIEW dbo.vItemCostInfo
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.item.item_number, dbo.inventory_transactions.trans_date, dbo.inventory_transactions.cost, 
                      dbo.item.description, dbo.inventory_transactions.record_status, dbo.item.record_status AS Expr1, dbo.inventory_transactions.company_id, 
                      dbo.inventory_transactions.entry_date, dbo.inventory_transactions.date_acquired, dbo.inventory_transactions.quantity
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id AND dbo.inventory_transactions.trans_type = 100
WHERE     (dbo.inventory_transactions.cost > 0) AND (dbo.item.record_status = 1)




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO









CREATE VIEW dbo.vItemTrackBy
AS
SELECT     item_id, location_id, user_id, serial_number, date_code, pallet, lot, company_id
FROM         dbo.inventory_transactions
GROUP BY item_id, location_id, user_id, serial_number, date_code, pallet, lot, company_id









GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO






CREATE VIEW dbo.vLabelerDateCode
AS
SELECT DISTINCT date_code
FROM         dbo.inventory_transactions
WHERE     (date_code <> '')






GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO






CREATE VIEW dbo.vLabelerLot
AS
SELECT DISTINCT lot
FROM         dbo.inventory_transactions
WHERE     (lot <> '')






GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO






CREATE VIEW dbo.vLabelerPallet
AS
SELECT DISTINCT pallet
FROM         dbo.inventory_transactions
WHERE     (pallet <> '')






GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO






CREATE VIEW dbo.vLabelerSN
AS
SELECT DISTINCT item_id, serial_number
FROM         dbo.inventory_transactions
WHERE     (serial_number <> '') AND (trans_type=100 and record_status=1)





GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vLocationSerialNumber
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.item.item_number, dbo.item.description AS item_description, 
                      dbo.inventory_transactions.serial_number, dbo.location.description AS location_description, dbo.location.code, 
                      dbo.sites.description AS site_description, dbo.inventory_transactions.record_status, dbo.inventory_transactions.company_id, 
                      dbo.inventory_transactions.trans_type, dbo.sites.site_name, dbo.inventory_transactions.remaining_qty
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.inventory_transactions.serial_number <> '')



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vMoveFrom
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.item.item_number, dbo.item.description, dbo.inventory_transactions.entry_date, 
                      dbo.inventory_transactions.trans_date, dbo.inventory_transactions.date_acquired, dbo.inventory_transactions.quantity, 
                      dbo.inventory_transactions.current_qty, dbo.inventory_transactions.remaining_qty, dbo.inventory_transactions.cost, 
                      dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, dbo.inventory_transactions.pallet, dbo.inventory_transactions.lot, 
                      dbo.inventory_transactions.trans_type, dbo.sites.description AS site_description, dbo.location.description AS location_description, dbo.location.code, 
                      dbo.inventory_transactions.action_type, dbo.inventory_transactions.record_status, dbo.inventory_transactions.record_source, 
                      dbo.inventory_transactions.company_id, dbo.inventory_transactions.user_id, dbo.users.last_name, dbo.users.first_name, dbo.sites.site_name
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.users ON dbo.inventory_transactions.user_id = dbo.users.user_id
WHERE     (dbo.item.record_status = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vMoveTo
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.sites.description AS moveto_site_description, dbo.location.description AS moveto_location_description,
                       dbo.location.code AS moveto_location, dbo.sites.site_name AS moveto_site_name
FROM         dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id INNER JOIN
                      dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id ON dbo.location.location_id = dbo.inventory_transactions.other_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vPIckSumLocation
AS
SELECT     SUM(dbo.inventory_transactions.quantity) AS qty, dbo.inventory_transactions.line_item_id, dbo.inventory_transactions.trans_type, 
                      dbo.inventory_transactions.action_type, dbo.inventory_transactions.customer_id, dbo.inventory_transactions.po_id, 
                      dbo.inventory_transactions.invoice_id, dbo.inventory_transactions.company_id, dbo.inventory_transactions.user_id, 
                      dbo.inventory_transactions.location_id, dbo.sites.site_name, dbo.location.code AS location
FROM         dbo.location INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.inventory_transactions ON dbo.location.location_id = dbo.inventory_transactions.location_id
WHERE     (dbo.inventory_transactions.record_status = 1 OR
                      dbo.inventory_transactions.record_status = 2) AND (dbo.inventory_transactions.adjust_reason_id <> 11)
GROUP BY dbo.inventory_transactions.line_item_id, dbo.inventory_transactions.trans_type, dbo.inventory_transactions.action_type, 
                      dbo.inventory_transactions.customer_id, dbo.inventory_transactions.date_code, dbo.inventory_transactions.po_id, 
                      dbo.inventory_transactions.invoice_id, dbo.inventory_transactions.company_id, dbo.inventory_transactions.user_id, 
                      dbo.inventory_transactions.location_id, dbo.sites.site_name, dbo.location.code




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vPickReceiveSum
AS
SELECT     SUM(quantity) AS qty, line_item_id, trans_type, action_type, customer_id, po_id, invoice_id, company_id, CONVERT(char(20), trans_date, 101) 
                      AS transaction_date
FROM         dbo.inventory_transactions
WHERE     (record_status = 1 OR
                      record_status = 2) AND (adjust_reason_id <> 11)
GROUP BY line_item_id, trans_type, action_type, customer_id, date_code, po_id, invoice_id, company_id, CONVERT(char(20), trans_date, 101)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vPickReceiveSum4
AS
SELECT     SUM(quantity) AS qty, line_item_id, trans_type, action_type, customer_id, supplier_id, po_id, invoice_id, company_id, CONVERT(char(20), trans_date, 
                      101) AS transaction_date
FROM         dbo.inventory_transactions
WHERE     (record_status = 4)
GROUP BY line_item_id, trans_type, action_type, customer_id, supplier_id, date_code, po_id, invoice_id, company_id, CONVERT(char(20), trans_date, 101)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vPickReceiveSumLocation
AS
SELECT     SUM(dbo.inventory_transactions.quantity) AS qty, dbo.inventory_transactions.line_item_id, dbo.inventory_transactions.trans_type, 
                      dbo.inventory_transactions.action_type, dbo.inventory_transactions.customer_id, dbo.inventory_transactions.po_id, 
                      dbo.inventory_transactions.invoice_id, dbo.inventory_transactions.company_id, CONVERT(char(20), dbo.inventory_transactions.trans_date, 101) 
                      AS transaction_date, dbo.inventory_transactions.location_id, dbo.inventory_transactions.user_id, dbo.sites.site_name, 
                      dbo.location.code AS location
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.inventory_transactions.record_status = 1 OR
                      dbo.inventory_transactions.record_status = 2) AND (dbo.inventory_transactions.adjust_reason_id <> 11)
GROUP BY dbo.inventory_transactions.line_item_id, dbo.inventory_transactions.trans_type, dbo.inventory_transactions.action_type, 
                      dbo.inventory_transactions.customer_id, dbo.inventory_transactions.date_code, dbo.inventory_transactions.po_id, 
                      dbo.inventory_transactions.invoice_id, dbo.inventory_transactions.company_id, CONVERT(char(20), dbo.inventory_transactions.trans_date, 101), 
                      dbo.inventory_transactions.location_id, dbo.inventory_transactions.user_id, dbo.sites.site_name, dbo.location.code



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vPickSum
AS
SELECT     SUM(quantity) AS qty, line_item_id, trans_type, action_type, customer_id, po_id, invoice_id, company_id
FROM         dbo.inventory_transactions
WHERE     (record_status = 1 OR
                      record_status = 2) AND (adjust_reason_id <> 11)
GROUP BY line_item_id, trans_type, action_type, customer_id, date_code, po_id, invoice_id, company_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vShippingReceivingInfo
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_des, dbo.supplier.supplier_number, dbo.supplier.name AS supplier_name, 
                      dbo.inventory_transactions.trans_type, dbo.inventory_transactions.action_type, dbo.inventory_transactions.entry_date, 
                      dbo.inventory_transactions.trans_date, dbo.inventory_transactions.date_acquired, dbo.inventory_transactions.adjust_type, 
                      dbo.inventory_transactions.quantity, dbo.inventory_transactions.current_qty, dbo.inventory_transactions.remaining_qty, 
                      dbo.inventory_transactions.cost, dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, dbo.inventory_transactions.po, 
                      dbo.inventory_transactions.lot, dbo.inventory_transactions.pallet, dbo.inventory_transactions.adjust_trans_code, 
                      dbo.inventory_transactions.record_status, dbo.inventory_transactions.record_source, dbo.inventory_transactions.company_id, dbo.users.last_name, 
                      dbo.users.first_name, dbo.customer.customer_number, dbo.customer.name AS customer_name, dbo.item.avgcost
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.supplier ON dbo.inventory_transactions.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.users ON dbo.inventory_transactions.user_id = dbo.users.user_id INNER JOIN
                      dbo.customer ON dbo.inventory_transactions.customer_id = dbo.customer.customer_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vTotalInventoryDetail
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_des, dbo.sites.site_name, dbo.sites.description AS site_des, dbo.location.code AS location, 
                      dbo.location.description AS location_des, CONVERT(char(20), dbo.inventory_transactions.date_acquired, 101) AS birth_date, 
                      SUM(dbo.inventory_transactions.remaining_qty) AS qty, dbo.inventory_transactions.cost, dbo.inventory_transactions.record_status, 
                      dbo.inventory_transactions.company_id, dbo.inventory_transactions.trans_type, dbo.inventory_transactions.entry_date, 
                      dbo.inventory_transactions.trans_date, dbo.inventory_transactions.date_acquired, dbo.inventory_transactions.adjust_type, 
                      dbo.inventory_transactions.quantity, dbo.inventory_transactions.current_qty, dbo.inventory_transactions.remaining_qty, 
                      dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, dbo.inventory_transactions.po, dbo.inventory_transactions.lot, 
                      dbo.inventory_transactions.pallet, dbo.inventory_transactions.po_id, dbo.inventory_transactions.adjust_trans_code, 
                      dbo.inventory_transactions.record_source, dbo.inventory_transactions.action_type, dbo.item.avgcost
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.inventory_transactions.trans_type IN (100, 200, 400, 500, 150)) AND (dbo.inventory_transactions.record_status = 1)
GROUP BY dbo.item.item_number, dbo.item.description, dbo.sites.site_name, dbo.sites.description, dbo.location.code, dbo.location.description, 
                      CONVERT(char(20), dbo.inventory_transactions.date_acquired, 101), dbo.inventory_transactions.cost, dbo.inventory_transactions.record_status, 
                      dbo.inventory_transactions.company_id, dbo.inventory_transactions.trans_type, dbo.inventory_transactions.entry_date, 
                      dbo.inventory_transactions.trans_date, dbo.inventory_transactions.date_acquired, dbo.inventory_transactions.adjust_type, 
                      dbo.inventory_transactions.quantity, dbo.inventory_transactions.current_qty, dbo.inventory_transactions.remaining_qty, 
                      dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, dbo.inventory_transactions.po, dbo.inventory_transactions.lot, 
                      dbo.inventory_transactions.pallet, dbo.inventory_transactions.po_id, dbo.inventory_transactions.adjust_trans_code, 
                      dbo.inventory_transactions.record_source, dbo.inventory_transactions.action_type, dbo.item.avgcost



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vTransactionByPO
AS
SELECT     dbo.item.item_number, dbo.item.description AS item_description, dbo.location.description AS location_description, dbo.location.code, 
                      dbo.inventory_transactions.company_id, dbo.inventory_transactions.record_status, dbo.sites.description AS site_description, 
                      dbo.inventory_transactions.quantity, dbo.inventory_transactions.trans_date, dbo.supplier.name AS supplier_name, dbo.users.last_name, 
                      dbo.users.first_name, dbo.supplier.supplier_number, dbo.inventory_transactions.transaction_id, dbo.inventory_transactions.date_acquired, 
                      dbo.sites.site_name, dbo.inventory_transactions.po
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id INNER JOIN
                      dbo.supplier ON dbo.inventory_transactions.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.users ON dbo.inventory_transactions.user_id = dbo.users.user_id
WHERE     (dbo.inventory_transactions.trans_type = 100) AND (dbo.item.record_status = 1) OR
                      (dbo.inventory_transactions.trans_type = 100) AND (dbo.item.record_status = 1) AND (dbo.supplier.name <> '')



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vTransactionHistory
AS
SELECT     dbo.inventory_transactions.transaction_id, dbo.item.item_number, dbo.item.description AS item_description, dbo.inventory_transactions.trans_date, 
                      dbo.inventory_transactions.trans_type, dbo.inventory_transactions.quantity, dbo.inventory_transactions.current_qty, 
                      dbo.inventory_transactions.remaining_qty, dbo.inventory_transactions.record_status, dbo.inventory_transactions.entry_date, 
                      dbo.inventory_transactions.date_acquired, dbo.inventory_transactions.cost, dbo.inventory_transactions.serial_number, 
                      dbo.inventory_transactions.date_code, dbo.inventory_transactions.pallet, dbo.inventory_transactions.lot, dbo.inventory_transactions.record_source, 
                      dbo.inventory_transactions.company_id, dbo.location.description AS location_description, dbo.location.code, dbo.sites.description AS site_description, 
                      dbo.sites.site_name
FROM         dbo.inventory_transactions INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id INNER JOIN
                      dbo.location ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.sites ON dbo.location.site_id = dbo.sites.site_id
WHERE     (dbo.item.record_status = 1)



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE VIEW dbo.vInventory3Qty
AS
SELECT     dbo.vInventoryByLocSite.item_number, dbo.vInventoryByLocSite.item_description, dbo.vInventoryByLocSite.location_description, 
                      dbo.vInventoryByLocSite.code, dbo.vInventoryByLocSite.site_description, dbo.vInventoryByLocSite.quantity, dbo.vInventoryByLocSite.record_status, 
                      dbo.vInventoryByLocSite.company_id, dbo.vCheckedOutQty.CheckedoutQty, dbo.vInventoryByLocSite.site_name
FROM         dbo.vInventoryByLocSite LEFT OUTER JOIN
                      dbo.vCheckedOutQty ON dbo.vInventoryByLocSite.item_id = dbo.vCheckedOutQty.item_id AND 
                      dbo.vInventoryByLocSite.location_id = dbo.vCheckedOutQty.location_id AND dbo.vInventoryByLocSite.company_id = dbo.vCheckedOutQty.company_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO









CREATE VIEW dbo.vItemTrackBy1
AS
SELECT     dbo.item.item_number, dbo.item.description AS itemDes, dbo.location.description AS locationDes, dbo.location.code, dbo.sites.description AS siteDes, 
                      dbo.item.company_id, dbo.vItemTrackBy.serial_number, dbo.vItemTrackBy.date_code, dbo.vItemTrackBy.pallet, dbo.vItemTrackBy.lot, 
                      dbo.item.record_status
FROM         dbo.item INNER JOIN
                      dbo.vItemTrackBy ON dbo.item.item_id = dbo.vItemTrackBy.item_id INNER JOIN
                      dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id ON dbo.vItemTrackBy.location_id = dbo.location.location_id









GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO


print '....   Store Procedures '

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpActivityReport]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpActivityReport]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpArchiveInventoryTransactions]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpArchiveInventoryTransactions]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpAuditResults]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpAuditResults]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpBackOrderTracking]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpBackOrderTracking]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpCleanDatabaseToStartPoint]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpCleanDatabaseToStartPoint]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpCleanUpOrphanedRecords]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpCleanUpOrphanedRecords]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpCustomerInfo]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpCustomerInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpDeleteCustomer]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpDeleteCustomer]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpDeleteItem]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpDeleteItem]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpDeleteLocation]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpDeleteLocation]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpDeleteManufacturer]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpDeleteManufacturer]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpDeleteSite]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpDeleteSite]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpDeleteSupplier]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpDeleteSupplier]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpGetNextId]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpGetNextId]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpGetNextSN]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpGetNextSN]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpGetPendingAdjusts]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpGetPendingAdjusts]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpInactivateInvoice]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpInactivateInvoice]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpInactivatePo]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpInactivatePo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpInsertImage]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpInsertImage]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpInventoryTempDataSet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpInventoryTempDataSet]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpItemSummary]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpItemSummary]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpManufacturerInfo]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpManufacturerInfo]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpNotCountedItems]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpNotCountedItems]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSetupWaspReader]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSetupWaspReader]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Audits]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Audits]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Customers]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Customers]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Inventories]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Inventories]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Items]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Items]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Locations]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Locations]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Manufacturers]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Manufacturers]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Sites]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Sites]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSumNotes4Vendors]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSumNotes4Vendors]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SpSupplierInfo]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SpSupplierInfo]
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO




CREATE PROCEDURE SpActivityReport 
	(@pStartDate datetime,  
	 @pEndDate datetime,
	 @pCompanyId int = 1) 
AS

/*
declare @pStartDate datetime
declare @pEndDate datetime

select @pStartDate = '06/01/2004'
select @pEndDate = '06/30/2004'
*/
--------------------------------------------------
-- Variable use for calucation
--------------------------------------------------
declare @vItemId 			int
declare @vAddTotal 			decimal
declare @vRemoveTotal 		decimal
declare @vAdjustInTotal		decimal
declare @vAdjustOutTotal	decimal
declare @vStartTotal 		decimal
declare @vEndTotal 			decimal

--------------------------------------------------
-- Create the temporary table for storing balances
--------------------------------------------------
CREATE TABLE [#TEMP_TOTALS] (
	[item_id] 			[int] 			NOT NULL ,
	[start_date] 		[datetime] 			NULL ,
	[start_total] 		[decimal](18, 4) 	NULL ,
	[add_total] 		[decimal](18, 4) 	NULL ,
	[remove_total] 		[decimal](18, 4) 	NULL ,
	[adjust_out_total] 	[decimal](18, 4)	NULL ,
	[adjust_in_total] 	[decimal](18, 4)	NULL ,
	[end_total] 		[decimal](18, 4)	NULL ,
	[end_date] 			[datetime] 			NULL
) ON [PRIMARY]


------------------------------------------------------
-- Set the end date to the first day of the next month
------------------------------------------------------
select @pEndDate = @pEndDate + 1;

--------------------------------------------------
-- Select unique list of ids to process
--------------------------------------------------

DECLARE MyCursor CURSOR
   FOR
   SELECT DISTINCT item_id FROM inventory_transactions 
		WHERE trans_date >= @pStartDate 
				and trans_date <= @pEndDate
				and record_status in (1,2)
				and company_id = @pCompanyId
				and trans_type not in (200,250,300,350)

OPEN MyCursor

FETCH NEXT FROM MyCursor INTO @vItemId
WHILE (@@FETCH_STATUS <> -1)
BEGIN
		
	--------------------------------------------------
	-- Transaction Types
	--------------------------------------------------
	--		Add			= 100						 
	--		Remove		= 150
	--		MoveIn		= 200
	--		MoveOut		= 250			
	--		CheckIn		= 300
	--		CheckOut	= 350
	--		AdjustIn	= 400
	--		AdjustOut	= 450			
	--		AuditIn		= 500
	--		Audit		= 550
	--------------------------------------------------
	
	--------------------------------------------------
	-- Get the totals for transactions after the end
	-- date so we can back them out of the total.
	--------------------------------------------------
	select @vAddTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type = 100 and trans_date >= @pEndDate and record_status in (1,2)
 	
	select @vRemoveTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type = 150 and trans_date >= @pEndDate and record_status in (1,2)
	
	select @vAdjustInTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type in (400,500) and trans_date >= @pEndDate and record_status in (1,2)

	select @vAdjustOutTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type in (450,550) and trans_date >= @pEndDate and record_status in (1,2)

	--------------------------------------------------
	-- Calculate the ending Total
	--------------------------------------------------
	select @vEndTotal = sum(quantity) - @vAddTotal + @vRemoveTotal - @vAdjustInTotal + @vAdjustOutTotal 
		from inventory 
			where item_id = @vItemId

	print '****** Total After End Date ********'
	print '@vItemId..........' + convert(varchar,@vItemId)
	print '@vAddTotal........' + convert(varchar,@vAddTotal)
	print '@vRemoveTotal.....' + convert(varchar,@vRemoveTotal)
	print '@vAdjustInTotal...' + convert(varchar,@vAdjustInTotal)
	print '@vAdjustOutTotal..' + convert(varchar,@vAdjustOutTotal)
	print '@vEndTotal........' + convert(varchar,@vEndTotal)

	--------------------------------------------------
	-- Get the totals for transactions between
	-- then start and end dates
	--------------------------------------------------
	select @vAddTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type = 100 
				and trans_date < @pEndDate 
				and trans_date >= @pStartDate 
				and record_status in (1,2)
 	
	select @vRemoveTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type = 150 
				and trans_date < @pEndDate 
				and trans_date >= @pStartDate 
				and record_status in (1,2)
	
	select @vAdjustInTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type in (400,500) 
				and trans_date < @pEndDate 
				and trans_date >= @pStartDate 
				and record_status in (1,2)

	select @vAdjustOutTotal = isnull(sum(quantity),0) from inventory_transactions 
		where item_id = @vItemId and trans_type in (450,550) 
				and trans_date < @pEndDate 
				and trans_date >= @pStartDate 
				and record_status in (1,2)

	--------------------------------------------------
	-- Calculate the beginning total
	--------------------------------------------------
	select @vStartTotal = @vEndTotal - @vAddTotal + @vRemoveTotal - @vAdjustInTotal + @vAdjustOutTotal 
	
	print '****** Between Totals'
	print '@vItemId..........' + convert(varchar,@vItemId)
	print '@vAddTotal........' + convert(varchar,@vAddTotal)
	print '@vRemoveTotal.....' + convert(varchar,@vRemoveTotal)
	print '@vAdjustInTotal...' + convert(varchar,@vAdjustInTotal)
	print '@vAdjustOutTotal..' + convert(varchar,@vAdjustOutTotal)
	print '@vStartTotal......' + convert(varchar,@vStartTotal)

	insert into #TEMP_TOTALS (	item_id, 
								start_date, 
								start_total,
								end_date,
								end_total,
								add_total,
								remove_total,
								adjust_out_total,
								adjust_in_total)
		values
							(	@vItemId,
								@pStartDate,
								@vStartTotal,
								@pEndDate - 1,
								@vEndTotal,
								@vAddTotal,
								@vRemoveTotal,
								@vAdjustOutTotal,
								@vAdjustInTotal)

	FETCH NEXT FROM MyCursor INTO @vItemId
END

DEALLOCATE MyCursor

--------------------------------------------------
-- Return the temp table to the call routing
--------------------------------------------------
select 	i.item_number, 
		i.description, 
		t.start_date, 
		t.start_total,
		t.add_total,
		t.remove_total,
		t.adjust_in_total,
		t.adjust_out_total,
		t.end_total,
		t.end_date
	from #TEMP_TOTALS t, ITEM i 
	where i.item_id = t.item_id

--------------------------------------------------
-- Delete the temporary table
--------------------------------------------------
drop table [#TEMP_TOTALS]

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE PROCEDURE dbo.SpArchiveInventoryTransactions
(@pItemId int, @pEarlyDate datetime)
AS

declare @vEntryDate 	datetime
declare @vTransDate 	datetime
declare @vAcquiredDate 	datetime
declare @vRecordCount   int

/****************************************/
/* Set Default value                    */
/****************************************/
/* Test values
Select @pEarlyDate = getdate()
select @pItemId = 462
*/

select @vRecordCount = 0


print '************ Step 0 **************'
/*
select invoice_id from inventory_transactions where invoice_id <> 0 and item_id = @pItemId
select po_id from inventory_transactions where po_id <> 0 and item_id = @pItemId
*/
/***************************************************************************** 
 * Get the earliest posible date base on the transactions for this item_id 
 * only
 *****************************************************************************/
print '--------------------------------------------'
print @pEarlyDate
print 'Step 1'
print '--------------------------------------------'
/*
select item_id, invoice_id, po_id, entry_date, trans_date, date_acquired from inventory_transactions where record_status not in (2,3) and item_id = @pItemId
*/

DECLARE cActiveTrans CURSOR FOR select entry_date, trans_date, date_acquired from inventory_transactions where record_status not in (2,3) and item_id = @pItemId
OPEN cActiveTrans

FETCH NEXT FROM cActiveTrans INTO  @vEntryDate, @vTransDate, @vAcquiredDate
WHILE (@@fetch_status <> -1)
BEGIN
	IF (@@fetch_status <> -2)
	BEGIN

		/* Check the entry date */
		if (@vEntryDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vEntryDate
		end

		/* Check the trans date */
		if (@vTransDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vTransDate
		end

		/* Check the acquired date */
		if (@vAcquiredDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vAcquiredDate
		end
	
   	END

	FETCH NEXT FROM cActiveTrans INTO  @vEntryDate, @vTransDate, @vAcquiredDate

END

DEALLOCATE cActiveTrans

print '--------------------------------------------'
print @pEarlyDate

/***************************************************************************** 
 * Get the earliest posible date based on the invoice transactions 
 * associated with the item id.  For example:  if item 55 is the item we are
 * working on and item 88 is on an invoice with 55 we would use the earliest
 * date of the two.  We do this in order to keep all the transactions for an
 * invoice together.
 *****************************************************************************/

print 'Step 2'
print '--------------------------------------------'

/*
	select item_id, invoice_id, entry_date, trans_date, date_acquired 
		from inventory_transactions 
		where record_status not in (2,3) and 
			  invoice_id in (select invoice_id from inventory_transactions where invoice_id <> 0 and item_id = @pItemId)
*/

DECLARE cActiveTransInv CURSOR FOR 
	select entry_date, trans_date, date_acquired 
		from inventory_transactions 
		where record_status not in (2,3) and 
			  invoice_id in (select invoice_id from inventory_transactions where invoice_id <> 0 and item_id = @pItemId)

OPEN cActiveTransInv

FETCH NEXT FROM cActiveTransInv INTO  @vEntryDate, @vTransDate, @vAcquiredDate
WHILE (@@fetch_status <> -1)
BEGIN
	IF (@@fetch_status <> -2)
	BEGIN

		/* Check the entry date */
		if (@vEntryDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vEntryDate
		end

		/* Check the trans date */
		if (@vTransDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vTransDate
		end

		/* Check the acquired date */
		if (@vAcquiredDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vAcquiredDate
		end
	
   	END

	FETCH NEXT FROM cActiveTransInv INTO  @vEntryDate, @vTransDate, @vAcquiredDate

END

DEALLOCATE cActiveTransInv

print '--------------------------------------------'
print @pEarlyDate



/***************************************************************************** 
 * Get the earliest posible date based on the po transactions 
 * associated with the item id.  For example:  if item 55 is the item we are
 * working on and item 88 is on an po with 55 we would use the earliest
 * date of the two.  We do this in order to keep all the transactions for an
 * po together.
 *****************************************************************************/

print 'Step 3'
print '--------------------------------------------'
/*
	select item_id, po_id, entry_date, trans_date, date_acquired 
		from inventory_transactions 
		where record_status not in (2,3) and 
			  po_id in (select po_id from inventory_transactions where po_id <> 0 and item_id = @pItemId)
*/

DECLARE cActiveTransPo CURSOR FOR 
	select entry_date, trans_date, date_acquired 
		from inventory_transactions 
		where record_status not in (2,3) and 
			  po_id in (select po_id from inventory_transactions where po_id <> 0 and item_id = @pItemId)

OPEN cActiveTransPo

FETCH NEXT FROM cActiveTransPo INTO  @vEntryDate, @vTransDate, @vAcquiredDate
WHILE (@@fetch_status <> -1)
BEGIN
	IF (@@fetch_status <> -2)
	BEGIN

		/* Check the entry date */
		if (@vEntryDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vEntryDate
		end

		/* Check the trans date */
		if (@vTransDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vTransDate
		end

		/* Check the acquired date */
		if (@vAcquiredDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vAcquiredDate
		end
	
   	END

	FETCH NEXT FROM cActiveTransPo INTO  @vEntryDate, @vTransDate, @vAcquiredDate

END

DEALLOCATE cActiveTransPo

print '--------------------------------------------'
print @pEarlyDate

/***************************************************************************** 
 * Get the earliest possible date based on the invoice_master record_status  
 * date.  if an inventory_transaction for an item is inactive and the 
 * invoice_master record_status is still have we do not want to archive the
 * inventory_transaction
 *****************************************************************************/

print 'Step 4'
print '--------------------------------------------'
/*
	select invoice_id, record_status_date, record_status
		from invoice_master
		where record_status not in (2,3) and 
			  invoice_id in (select invoice_id from inventory_transactions where invoice_id <> 0 and item_id = @pItemId)
*/
DECLARE cActiveInvoices CURSOR FOR 
	select record_status_date
		from invoice_master
		where record_status not in (2,3) and 
			  invoice_id in (select invoice_id from inventory_transactions where invoice_id <> 0 and item_id = @pItemId)

OPEN cActiveInvoices

FETCH NEXT FROM cActiveInvoices INTO  @vEntryDate
WHILE (@@fetch_status <> -1)
BEGIN
	IF (@@fetch_status <> -2)
	BEGIN

		/* Check the entry date */
		if (@vEntryDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vEntryDate
		end

   	END


	FETCH NEXT FROM cActiveInvoices INTO  @vEntryDate

END

DEALLOCATE cActiveInvoices

print '--------------------------------------------'
print @pEarlyDate

/***************************************************************************** 
 * Get the earliest possible date based on the purchase_orders record_status  
 * date.  if an inventory_transaction for an item is inactive and the 
 * invoice_master record_status is still have we do not want to archive the
 * inventory_transaction
 *****************************************************************************/

print 'Step 5'
print '--------------------------------------------'
/*
	select purchase_order_id, record_status_date, record_status
		from purchase_orders
		where record_status not in (2,3) and 
			  purchase_order_id in (select po_id as purchase_order_id from inventory_transactions where po_id <> 0 and item_id = @pItemId)
*/
DECLARE cActivePos CURSOR FOR 
	select record_status_date
		from purchase_orders
		where record_status not in (2,3) and 
			  purchase_order_id in (select po_id as purchase_order_id from inventory_transactions where po_id <> 0 and item_id = @pItemId)

OPEN cActivePos

FETCH NEXT FROM cActivePos INTO  @vEntryDate
WHILE (@@fetch_status <> -1)
BEGIN
	IF (@@fetch_status <> -2)
	BEGIN

		/* Check the entry date */
		if (@vEntryDate < @pEarlyDate)
		begin
			select @pEarlyDate = @vEntryDate
		end

   	END


	FETCH NEXT FROM cActivePos INTO  @vEntryDate

END

DEALLOCATE cActivePos

print '--------------------------------------------'
print 'Date Used'
print @pEarlyDate
print '--------------------------------------------'

/*****************************************************************************
 * move the records to there counter part archive tables
 *****************************************************************************/

begin transaction

--	copy the old records into the history_transactions table

insert into history_transactions 
select *
	from inventory_transactions 
	where 	record_status in (2,3) and 
			item_id = @pItemId  and
			(entry_date < @pEarlyDate or entry_date is null) and
			(trans_date < @pEarlyDate or trans_date is null) and
			(date_acquired < @pEarlyDate or date_acquired is null)

--	delete the transactions from the inventory transactions table

delete
	from inventory_transactions 
	where 	record_status in (2,3) and 
			item_id = @pItemId  and
			(entry_date < @pEarlyDate or entry_date is null) and
			(trans_date < @pEarlyDate or trans_date is null) and
			(date_acquired < @pEarlyDate or date_acquired is null)

-- Add to the total number of record processed
select @vRecordCount = @vRecordCount + @@rowcount

-----------------------------------------------------------------------------
-- Invoices Invoices Invoices Invoices Invoices Invoices Invoices Invoices 
-----------------------------------------------------------------------------
-- Move invoice_master records
-----------------------------------------------------------------------------
print 'Moving Invoice Master Records'
insert into invoice_master_archive
select *
	from  invoice_master
	where record_status in (2,3) and
		  record_status_date < @pEarlyDate and
		  invoice_id in (select invoice_id from inventory_transactions where invoice_id <> 0 and item_id = @pItemId)		  

-----------------------------------------------------------------------------
-- Move invoice line item records
-----------------------------------------------------------------------------
print 'Moving Invoice Line Items'
insert into invoice_line_items_archive
select *
	from  invoice_line_items
    where invoice_id in (select invoice_id from invoice_master_archive)

-----------------------------------------------------------------------------
-- Delete invoice line item records
-----------------------------------------------------------------------------

delete from invoice_line_items
    where invoice_id in (select invoice_id from invoice_master_archive)

select @vRecordCount = @vRecordCount + @@rowcount
-----------------------------------------------------------------------------
-- Delete invoice_maseter records
-----------------------------------------------------------------------------

delete from invoice_master
    where invoice_id in (select invoice_id from invoice_master_archive)

select @vRecordCount = @vRecordCount + @@rowcount
-----------------------------------------------------------------------------
-- POs POs POs POs POs POs POs POs POs POs POs POs POs POs POs POs POs POs
-----------------------------------------------------------------------------
-- Move purhcase_orders records
-----------------------------------------------------------------------------
print 'Moving Purchase Orders'
insert into purchase_orders_archive
select *
	from  purchase_orders
	where record_status in (2,3) and
		  record_status_date < @pEarlyDate and
		  purchase_order_id in (select po_id as purchase_order_id from inventory_transactions where po_id <> 0 and item_id = @pItemId)		  

-----------------------------------------------------------------------------
-- Move po_line_item records
-----------------------------------------------------------------------------
print 'Moving Purchase Orders Line Items'
insert into po_line_item_archive
select *
	from  po_line_item
    where purchase_order_id in (select purchase_order_id from purchase_orders_archive)

-----------------------------------------------------------------------------
-- Delete po_line_item records
-----------------------------------------------------------------------------

delete from po_line_item
    where purchase_order_id in (select purchase_order_id from purchase_orders_archive)


select @vRecordCount = @vRecordCount + @@rowcount
-----------------------------------------------------------------------------
-- Delete purhcase_orders records
-----------------------------------------------------------------------------

delete from purchase_orders
    where purchase_order_id in (select purchase_order_id from purchase_orders_archive)

select @vRecordCount = @vRecordCount + @@rowcount

-----------------------------------------------------------------------------
-- Return the number of records deleted 
-----------------------------------------------------------------------------

select @vRecordCount as records_moved

print '----------------------------------------'
print @vRecordCount
print '----------------------------------------'

commit transaction

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO









CREATE PROCEDURE SpAuditResults 
 
AS
SET NOCOUNT ON

declare @start_date  datetime 
declare @end_date datetime 

SELECT      top 1  @start_date  =  start_date, @end_date  =end_date
FROM         dbo.inv_audit
order by start_date desc

 
if @end_date is null

SELECT  * from dbo.vAuditInfo   
where  trans_date >= @start_date
 order by trans_date desc 

else

SELECT  * from dbo.vAuditInfo   
where trans_date  between @start_date and @end_date
order by trans_date desc







GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO


CREATE PROCEDURE [dbo].[SpBackOrderTracking] AS
 
SET NOCOUNT ON

SELECT     dbo.customer.customer_number, dbo.customer.name AS customer_name, 
		dbo.invoice_master.invoice_id, dbo.invoice_master.ref_number AS invoice_number, 
                      dbo.invoice_master.due_date, dbo.invoice_master.line_item_count, 
		invoice_master_1.ref_number AS parent_invoice_number, 
                      invoice_master_3.ref_number AS back_order_invoice_number

 
FROM         dbo.invoice_master invoice_master_2 INNER JOIN
                      dbo.invoice_master ON invoice_master_2.invoice_id = dbo.invoice_master.backorder_id LEFT OUTER JOIN
                      dbo.invoice_master invoice_master_3 ON dbo.invoice_master.backorder_id = invoice_master_3.invoice_id LEFT OUTER JOIN
                      dbo.invoice_master invoice_master_1 ON dbo.invoice_master.parent_id = invoice_master_1.invoice_id LEFT OUTER JOIN
                      dbo.customer ON dbo.invoice_master.customer_id = dbo.customer.customer_id

union


SELECT     dbo.customer.customer_number, dbo.customer.name AS customer_name, 
		dbo.invoice_master.invoice_id, dbo.invoice_master.ref_number AS invoice_number, 
                      dbo.invoice_master.due_date, dbo.invoice_master.line_item_count, 
		invoice_master_1.ref_number AS parent_invoice_number, 
                      invoice_master_3.ref_number AS back_order_invoice_number 

FROM         dbo.invoice_master invoice_master_2 INNER JOIN
                      dbo.invoice_master ON invoice_master_2.invoice_id = dbo.invoice_master.parent_id LEFT OUTER JOIN
                      dbo.invoice_master invoice_master_3 ON dbo.invoice_master.backorder_id = invoice_master_3.invoice_id LEFT OUTER JOIN
                      dbo.invoice_master invoice_master_1 ON dbo.invoice_master.parent_id = invoice_master_1.invoice_id LEFT OUTER JOIN
                      dbo.customer ON dbo.invoice_master.customer_id = dbo.customer.customer_id
WHERE     (dbo.invoice_master.backorder_id = 0)

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpCleanDatabaseToStartPoint
 
AS


delete from address
delete from auto_numbers
delete from company_info where company_id > 1
delete from find_meta
delete from import_export_errors
delete from inventory_transactions
delete from audit_transactions
delete from history_transactions
delete from customer where customer_id > 0
delete from inv_audit
delete from inventory
delete from item
delete from location where location_id > 0
delete from lookup
delete from manufacturer where manufacturer_id > 0
delete from notes
delete from phone
delete from sites where site_id > 0
delete from supplier where supplier_id > 0
delete from category where category_id > 0
delete from recent_values

insert into address (address_id, record_type, record_status) values	(1,'Company Corporate', 1)
insert into address (address_id, record_type, record_status) values (1,'Company Receiving', 1)
insert into address (address_id, record_type, record_status) values	(1,'Company Shipping', 1)

insert into phone (phone_id, record_type, record_status) values (1,'Company Fax', 1)
insert into phone (phone_id, record_type, record_status) values (1,'Company Phone', 1)

/* 
	Reset the company info record 
	The should only be 1 record in the company info table at this point
*/
print 'Updating Company Info...'
update company_info set company = '', email = '', website = ''

/* 
	reset the meta data to the default values 
*/
print 'Resetting default values...'
update form_field_meta 
	set 
	label = default_label,
	tool_tip = default_tool_tip,
	visible = default_visible,
	required = default_required,
	field_length = default_field_length




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpCleanUpOrphanedRecords (@pCompanyId int) AS

if (select count(*) from customer 
    where 
	customer_id not in (select distinct phone_id from phone where table_name = 'customer' and record_status = 1) and 
	record_status = 1 and 
	company_id = @pCompanyId) > 0
begin
	update address
	set record_status = 2
	where address_id in (select distinct customer_id from customer 
				where customer_id not in (select distinct phone_id from phone 
						       		where table_name = 'customer' and 
						             			record_status = 1) and 
 	  			  	record_status = 1 and 
					company_id = @pCompanyId) and 
	table_name='customer';
	
	update notes
	set record_status = 2
	where note_id in (select distinct customer_id from customer where 
			customer_id not in (select distinct phone_id from phone 
					    where table_name = 'customer' and 
						  record_status = 1) and 
			record_status = 1 and 
			company_id =@pCompanyId)
	and table_name ='customer';

	update customer 
	set record_status = 2
	where customer_id in (select distinct customer_id from customer where 
		customer_id not in (select distinct phone_id from phone where table_name = 'customer' and record_status = 1) and 
		record_status = 1 and 
		company_id = @pCompanyId)
	and company_id = @pCompanyId;	
end

if (select count(*) from supplier where 
	supplier_id not in (select distinct phone_id from phone where table_name = 'supplier' and record_status = 1) and 
	record_status = 1 and 
	company_id = @pCompanyId) > 0
begin
	update address
	set record_status = 2
	where address_id in (select distinct supplier_id from supplier where 
			supplier_id not in (select distinct phone_id from phone where table_name = 'supplier' and record_status = 1) and 
			record_status = 1 and 
			company_id = @pCompanyId)
	and table_name='supplier';
	
	update notes
	set record_status = 2
	where note_id in (select distinct supplier_id from supplier where 
			supplier_id not in (select distinct phone_id from phone where table_name = 'supplier' and record_status = 1) and 
			record_status = 1 and 
			company_id =@pCompanyId)
	and table_name ='supplier';

	update supplier 
	set record_status = 2
	where supplier_id in (select distinct supplier_id from supplier where 
		supplier_id not in (select distinct phone_id from phone where table_name = 'supplier' and record_status = 1) and 
		record_status = 1 and 
		company_id = @pCompanyId)
	and company_id = @pCompanyId;	
end

if (select count(*) from manufacturer where 
	manufacturer_id not in (select distinct phone_id from phone where table_name = 'manufacturer' and record_status = 1) and 
	record_status = 1 and 
	company_id = @pCompanyId) > 0
begin
	update address
	set record_status = 2
	where address_id in (select distinct manufacturer_id from manufacturer where 
			manufacturer_id not in (select distinct phone_id from phone where table_name = 'manufacturer' and record_status = 1) and 
			record_status = 1 and 
			company_id = @pCompanyId)
	and table_name='manufacturer';
	
	update notes
	set record_status = 2
	where note_id in (select distinct manufacturer_id from manufacturer where 
			manufacturer_id not in (select distinct phone_id from phone where table_name = 'manufacturer' and record_status = 1) and 
			record_status = 1 and 
			company_id = @pCompanyId)
	and table_name ='manufacturer';

	update manufacturer 
	set record_status = 2
	where manufacturer_id in (select distinct manufacturer_id from manufacturer where 
		manufacturer_id not in (select distinct phone_id from phone where table_name = 'manufacturer' and record_status = 1) and 
		record_status = 1 and 
		company_id = @pCompanyId)
	and company_id = @pCompanyId;	
end

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO










CREATE PROCEDURE SpCustomerInfo


AS
SET NOCOUNT ON

SELECT     
customer_id, 
customer_number, 
dbo.customer.name, 
company_name, 
email, 
department, 
date_added, 
record_status,
company_id

into #t1
FROM         dbo.customer

select  Customer_id, phone_number, extension
into #t2
FROM         dbo.Customer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Customer.Customer_id AND dbo.phone.table_name = 'Customer' and dbo.phone.phone_type_id=1

select  Customer_id,phone_number as 'Fax'
into #t3
FROM         dbo.Customer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Customer.Customer_id AND dbo.phone.table_name = 'Customer' and dbo.phone.phone_type_id=3

select Customer_id,phone_number as 'hPhone' 
into #t4
FROM         dbo.Customer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Customer.Customer_id AND dbo.phone.table_name = 'Customer' and dbo.phone.phone_type_id=2

select Customer_id,phone_number as 'cCell' 
into #t5
FROM         dbo.Customer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Customer.Customer_id AND  dbo.phone.table_name = 'Customer' and dbo.phone.phone_type_id=2



SET NOCOUNT OFF

SELECT     
#t1.Customer_id, 
customer_number,
#t1.name, 
company_name, 
email, 
department, 
date_added, 
record_status,
company_id,
phone_number, 
extension,
fax,
hphone,
ccell


from #t1 inner join #t2 on #t1.Customer_id = #t2.Customer_id
inner join #t3 on #t3.Customer_id = #t2.Customer_id
inner join #t4 on #t4.Customer_id = #t2.Customer_id
inner join #t5 on #t5.Customer_id = #t2.Customer_id
where #t1.Customer_id >0

drop table #t1
drop table #t2
drop table #t3
drop table #t4
drop table #t5

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpDeleteCustomer (@pStatus int, @pCustomerId int, @pCompanyId int) AS

update customer set record_status = @pStatus  where customer_id = @pCustomerId and company_id = @pCompanyId
update address set record_status = @pStatus  where address_id = @pCustomerId and table_name = 'customer'
update phone set record_status = @pStatus  where phone_id = @pCustomerId and table_name = 'customer'

UPDATE    notes
SET              record_status = @pStatus
WHERE     (note_id  = @pCustomerId) AND (table_name = 'customer')

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpDeleteItem (@pStatus int, @pItemId int, @pCompanyId int) AS

update item set record_status = @pStatus  where item_id = @pItemId and company_id = @pCompanyId
UPDATE    notes
SET              record_status = @pStatus
WHERE     (note_id  = @pItemId) AND (table_name = 'item')

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpDeleteLocation (@pStatus int, @pLocationId int, @pCompanyId int) AS

update location set record_status = @pStatus  where location_id = @pLocationId and company_id = @pCompanyId

UPDATE    notes
SET              record_status = @pStatus
WHERE     (note_id  = @pLocationId) AND (table_name = 'location')

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpDeleteManufacturer (@pStatus int, @pManufacturerId int, @pCompanyId int) AS

update manufacturer set record_status = @pStatus  where manufacturer_id = @pManufacturerId and company_id = @pCompanyId

update phone set record_status = @pStatus  where phone_id = @pManufacturerId and table_name = 'manufacturer'

UPDATE    notes
SET              record_status = @pStatus
WHERE     (note_id  = @pManufacturerId) AND (table_name = 'manufacturer')

update address set record_status = @pStatus  where address_id = @pManufacturerId and table_name = 'manufacturer'

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpDeleteSite (@pStatus int, @pSiteId int, @pCompanyId int) AS

update sites set record_status = @pStatus  where site_id = @pSiteId and company_id = @pCompanyId

UPDATE    notes
SET              record_status = @pStatus
WHERE     (note_id = @pSiteId) AND (table_name = 'sites')

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpDeleteSupplier (@pStatus int, @pSupplierId int, @pCompanyId int) AS

update supplier set record_status = @pStatus  where supplier_id = @pSupplierId and company_id = @pCompanyId
update phone set record_status = @pStatus  where phone_id = @pSupplierId and table_name = 'supplier'

UPDATE    notes
SET              record_status = @pStatus
WHERE     (note_id = @pSupplierId) AND (table_name = 'supplier')

update address set record_status = @pStatus  where address_id = @pSupplierId and table_name = 'Supplier'

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpGetNextId (@pObjectType varchar(50), @pCompanyId int) AS

declare @vNextId numeric(30,0)

begin transaction

if (SELECT count(*) FROM auto_numbers  WHERE object_type = @pObjectType and company_id = @pCompanyId) =  0
begin
	select @vNextId = 0
	insert into auto_numbers(object_type, company_id, next_id) values (@pObjectType, @pCompanyId, @vNextId + 1)
end
else
begin
	select @vNextId = next_id  from auto_numbers  with (holdlock) where object_type = @pObjectType and company_id = @pCompanyId
	update auto_numbers set next_id = @vNextId + 1 where object_type = @pObjectType and company_id = @pCompanyId
end
commit transaction

select @vNextId as next_id



GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE SpGetNextSN (@pItemId int) AS

declare @vNextId numeric(30,0)

begin transaction

begin
	select @vNextId = auto_sn_value  from item  with (holdlock) where item_id = @pItemId
	if (@vNextId = 0)
	begin
		select @vNextId = 1
	end 
	update item set auto_sn_value = @vNextId + 1 where item_id = @pItemId
end

commit transaction

select @vNextId as next_id


GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO


CREATE   PROCEDURE dbo.SpGetPendingAdjusts (@pUserId int, @pCompanyId int, @pDecimalPlace int, @pMachineName varchar(30))AS

select transaction_id, quantity, serial_number,
adjust_type_text = CASE adjust_type WHEN 'a' THEN 'absolute_adjust' WHEN 'r' THEN 'relative_adjust' END,
lot, date_code, pallet, adjust_trans_code, adjust_reason_id, inventory_id, record_status, company_id, user_id,
trans_type, record_source  INTO #tt1 from inventory_transactions;

IF (@pDecimalPlace = 0)
BEGIN
SELECT t.transaction_id,  i.item_number, i.description, s.site_name,l.code,
CONVERT(decimal(18, 0), t.quantity) AS quantity,
t.serial_number, f.label as adjust_type, r.adjust_code, t.lot, t.date_code, t.pallet,
t.adjust_trans_code
FROM   #tt1  t INNER JOIN
reasons_adjustment r ON t.adjust_reason_id = r.reason_id
INNER JOIN inventory inv ON t .inventory_id = inv.inventory_id INNER JOIN
item i ON inv.item_id = i.item_id INNER JOIN location l ON inv.location_id = l.location_id
inner join sites s on s.site_id = l.site_id cross JOIN   form_field_meta f
WHERE     (t.record_status = 4) AND (t.company_id = @pCompanyId) AND (t.user_id = @pUserId) AND
(t.trans_type = 450) AND (f.form_id = 21) and (t.adjust_type_text=f.field) and (t.record_source = @pMachineName)
END
ELSE
IF (@pDecimalPlace = 1)
BEGIN
SELECT t.transaction_id,  i.item_number, i.description, s.site_name,l.code,
CONVERT(decimal(18, 1), t.quantity) AS quantity,
t.serial_number, f.label as adjust_type, r.adjust_code, t.lot, t.date_code, t.pallet,
t.adjust_trans_code
FROM   #tt1  t INNER JOIN
reasons_adjustment r ON t.adjust_reason_id = r.reason_id
INNER JOIN inventory inv ON t .inventory_id = inv.inventory_id INNER JOIN
item i ON inv.item_id = i.item_id INNER JOIN location l ON inv.location_id = l.location_id
inner join sites s on s.site_id = l.site_id cross JOIN   form_field_meta f
WHERE     (t.record_status = 4) AND (t.company_id = @pCompanyId) AND (t.user_id = @pUserId) AND
(t.trans_type = 450) AND (f.form_id = 21) and (t.adjust_type_text=f.field) and (t.record_source = @pMachineName)
END
ELSE
IF (@pDecimalPlace = 2)
BEGIN
SELECT t.transaction_id,  i.item_number, i.description, s.site_name,l.code,
CONVERT(decimal(18, 2), t.quantity) AS quantity,
t.serial_number, f.label as adjust_type, r.adjust_code, t.lot, t.date_code, t.pallet,
t.adjust_trans_code
FROM   #tt1  t INNER JOIN
reasons_adjustment r ON t.adjust_reason_id = r.reason_id
INNER JOIN inventory inv ON t .inventory_id = inv.inventory_id INNER JOIN
item i ON inv.item_id = i.item_id INNER JOIN location l ON inv.location_id = l.location_id
inner join sites s on s.site_id = l.site_id cross JOIN   form_field_meta f
WHERE     (t.record_status = 4) AND (t.company_id = @pCompanyId) AND (t.user_id = @pUserId) AND
(t.trans_type = 450) AND (f.form_id = 21) and (t.adjust_type_text=f.field) and (t.record_source = @pMachineName)
END
ELSE
IF (@pDecimalPlace = 3)
BEGIN
SELECT t.transaction_id,  i.item_number, i.description, s.site_name,l.code,
CONVERT(decimal(18, 3), t.quantity) AS quantity,
t.serial_number, f.label as adjust_type, r.adjust_code, t.lot, t.date_code, t.pallet,
t.adjust_trans_code
FROM   #tt1  t INNER JOIN
reasons_adjustment r ON t.adjust_reason_id = r.reason_id
INNER JOIN inventory inv ON t .inventory_id = inv.inventory_id INNER JOIN
item i ON inv.item_id = i.item_id INNER JOIN location l ON inv.location_id = l.location_id
inner join sites s on s.site_id = l.site_id cross JOIN   form_field_meta f
WHERE     (t.record_status = 4) AND (t.company_id = @pCompanyId) AND (t.user_id = @pUserId) AND
(t.trans_type = 450) AND (f.form_id = 21) and (t.adjust_type_text=f.field) and (t.record_source = @pMachineName)
END
ELSE
BEGIN
SELECT t.transaction_id,  i.item_number, i.description, s.site_name,l.code,
CONVERT(decimal(18, 4), t.quantity) AS quantity,
t.serial_number, f.label as adjust_type, r.adjust_code, t.lot, t.date_code, t.pallet,
t.adjust_trans_code
FROM   #tt1  t INNER JOIN
reasons_adjustment r ON t.adjust_reason_id = r.reason_id
INNER JOIN inventory inv ON t .inventory_id = inv.inventory_id INNER JOIN
item i ON inv.item_id = i.item_id INNER JOIN location l ON inv.location_id = l.location_id
inner join sites s on s.site_id = l.site_id cross JOIN   form_field_meta f
WHERE     (t.record_status = 4) AND (t.company_id = @pCompanyId) AND (t.user_id = @pUserId) AND
(t.trans_type = 450) AND (f.form_id = 21) and (t.adjust_type_text=f.field) and (t.record_source = @pMachineName)
END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO


CREATE PROCEDURE SpInactivateInvoice 
(@pInvoiceId int)
AS
/*******************************************************************************************************/
/* Update the record status on the invoice and its line items to inactive                           */
/******************************************************************************************************/
begin transaction

	update invoice_master set record_status = 2,
				  record_status_date =  getdate()
						where invoice_id = @pInvoiceId

	update invoice_line_items set record_status = 2 where invoice_id = @pInvoiceId

commit transaction

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO


CREATE PROCEDURE SpInactivatePo
(@pPoId int)
AS
/*******************************************************************************************************/
/* Update the record status on the invoice and its line items to inactive                           */
/******************************************************************************************************/
begin transaction

	update purchase_orders set record_status = 2,
				  record_status_date =  getdate()
						where purchase_order_id = @pPoId

	update po_line_item set record_status = 2 where purchase_order_id = @pPoId

commit transaction

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO


CREATE PROCEDURE dbo.SpInsertImage (@image_id int, @image_label text, @image binary) AS
INSERT INTO image
                      (image_id, image_label, image)
VALUES     (@image_id, @image_label, @image)

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpInventoryTempDataSet  AS

IF EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES
      WHERE TABLE_NAME = 'inventory_temp')
   DROP TABLE   inventory_temp;


CREATE TABLE dbo.inventory_temp
(
item_number varchar(30), 
item_desc varchar(255), 
site_name  varchar(30), 
code varchar(30), 
pallet varchar(30), 
lot  varchar(30), 
po varchar(30), 
date_code varchar(30), 
serial_number varchar(30), 
quantity decimal,
supplier_number varchar(30),
date_acquired datetime,
min_stock_level decimal,
max_stock_level decimal,
reorder_qty decimal
)

INSERT  dbo.Inventory_Temp
SELECT    item.item_number, item.description AS item_desc, sites.site_name, location.code, trn.pallet, trn.lot, trn.po, trn.date_code, 
                      trn.serial_number, SUM(trn.remaining_qty) AS quantity, supplier.supplier_number, trn.date_acquired, 
inv.min_stock_level,
inv.max_stock_level, inv.reorder_qty
FROM         inventory_transactions trn INNER JOIN
                      inventory inv ON trn.inventory_id = inv.inventory_id INNER JOIN
                      item ON inv.item_id = item.item_id INNER JOIN
                      location ON inv.location_id = location.location_id INNER JOIN
                      sites ON location.site_id = sites.site_id INNER JOIN
                      customer ON trn.customer_id = customer.customer_id INNER JOIN
                      supplier ON trn.supplier_id = supplier.supplier_id
WHERE     (trn.record_status = 1) AND (trn.company_id = 1) and trn.trans_type IN (150, 250, 450, 100, 200, 400, 500 ) AND (inv.location_id IN
                          (SELECT     loc.location_id
                            FROM          location loc))
GROUP BY trn.pallet, trn.lot, trn.po, trn.date_code, trn.serial_number, item.item_number, item.description, sites.site_name, location.code, 
                      supplier.supplier_number, supplier.name, trn.date_acquired,inv.min_stock_level,
inv.max_stock_level, inv.reorder_qty

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO







CREATE PROCEDURE SpItemSummary
 
AS
SET NOCOUNT ON
 
create table ##jds
(
	item_id int,
	quantity decimal,
	location_id int
)

insert into ##jds select item_id, 0.0 as quantity, 0 as location_id from item where item_id not 

in (select item_id from inventory)

insert into ##jds select item_id, quantity,location_id from inventory

SELECT     dbo.item.item_number, dbo.item.description, dbo.item.cost, dbo.item.avgcost, dbo.category.description AS catagory, 
                      dbo.manufacturer.name AS manufacturer, dbo.supplier.name AS supplier, dbo.item.min_stock_level, dbo.item.reorder_qty, 
                      dbo.item.record_status AS itemStatus, dbo.item.company_id, 
                      dbo.location.code, dbo.sites.description AS siteDes, dbo.location.description AS locationDes, ##jds.quantity
FROM         dbo.item inner JOIN
                      ##jds ON dbo.item.item_id = ##jds.item_id INNER JOIN
                      dbo.category ON dbo.item.category_id = dbo.category.category_id INNER JOIN
                      dbo.manufacturer ON dbo.item.manufacturer_id = dbo.manufacturer.manufacturer_id INNER JOIN
                      dbo.supplier ON dbo.item.supplier_id = dbo.supplier.supplier_id INNER JOIN
                      dbo.location ON dbo.location.location_id = ##jds.location_id INNER JOIN
                      dbo.sites ON dbo.sites.site_id = dbo.location.site_id


drop table ##jds






GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO










CREATE PROCEDURE SpManufacturerInfo


AS
SET NOCOUNT ON

SELECT     
manufacturer_id, 
dbo.manufacturer.name, 
email, 
website, 
contact_name,
record_status,
company_id
into #t1
FROM         dbo.manufacturer

select  manufacturer_id, phone_number, extension
into #t2
FROM         dbo.manufacturer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.manufacturer.manufacturer_id AND dbo.phone.table_name = 'Manufacturer' and dbo.phone.phone_type_id=1

select  manufacturer_id,phone_number as 'Fax'
into #t3
FROM         dbo.manufacturer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.manufacturer.manufacturer_id AND dbo.phone.table_name = 'Manufacturer' and dbo.phone.phone_type_id=5

select manufacturer_id,phone_number as 'cPhone' ,extension as 'cExtension'
into #t4
FROM         dbo.manufacturer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.manufacturer.manufacturer_id AND dbo.phone.table_name = 'Manufacturer' and dbo.phone.phone_type_id=4

select manufacturer_id,phone_number as 'cCell' 
into #t5
FROM         dbo.manufacturer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.manufacturer.manufacturer_id AND dbo.phone.table_name = 'Manufacturer' and dbo.phone.phone_type_id=2

select manufacturer_id,phone_number as 'cFax' 
into #t6
FROM         dbo.manufacturer LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.manufacturer.manufacturer_id AND dbo.phone.table_name = 'Manufacturer' and dbo.phone.phone_type_id=3

SET NOCOUNT OFF

SELECT     
#t1.manufacturer_id, 
#t1.name, 
email, 
website, 
contact_name,
record_status,
company_id,
phone_number, 
extension,
fax,
cphone,
cextension,
ccell,
cfax

from #t1 inner join #t2 on #t1.manufacturer_id = #t2.manufacturer_id
inner join #t3 on #t3.manufacturer_id = #t2.manufacturer_id
inner join #t4 on #t4.manufacturer_id = #t2.manufacturer_id
inner join #t5 on #t5.manufacturer_id = #t2.manufacturer_id
inner join #t6 on #t6.manufacturer_id = #t2.manufacturer_id

where #t1.manufacturer_id>0

drop table #t1
drop table #t2
drop table #t3
drop table #t4
drop table #t5
drop table #t6

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO









CREATE PROCEDURE SpNotCountedItems
 
AS
SET NOCOUNT ON

declare @start_date  datetime 
declare @end_date datetime 

SELECT      top 1  @start_date  =  start_date, @end_date  =end_date
FROM         dbo.inv_audit
order by start_date desc

 
if @end_date is null
begin
	

SELECT     dbo.item.item_number, dbo.item.description AS item_description, dbo.location.description AS location_description, dbo.location.code, 
		dbo.sites.site_name, dbo.sites.description AS site_description, 
                      dbo.item.company_id, dbo.vItemTrackBy.serial_number, dbo.vItemTrackBy.date_code, dbo.vItemTrackBy.pallet, dbo.vItemTrackBy.lot, 
                      dbo.item.record_status
FROM         dbo.item INNER JOIN
                      dbo.vItemTrackBy ON dbo.item.item_id = dbo.vItemTrackBy.item_id INNER JOIN
                      dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id ON dbo.vItemTrackBy.location_id = dbo.location.location_id

	where  not exists (	
	SELECT  * 
	
	from dbo.vAuditInfo   
	where  trans_date >= @start_date 
	and  dbo.item.item_number= dbo.vAuditInfo.item_number
	and  dbo.sites.site_name= dbo.vAuditInfo.site_name
	and  dbo.location.code= dbo.vAuditInfo.code
	and dbo.vItemTrackBy.serial_number = dbo.vAuditInfo.serial_number
	and dbo.vItemTrackBy.date_code = dbo.vAuditInfo.date_code
	and  dbo.vItemTrackBy.pallet = dbo.vAuditInfo.pallet
	and dbo.vItemTrackBy.lot = dbo.vAuditInfo.lot
	 
	)
end
else
begin
SELECT     dbo.item.item_number, dbo.item.description AS item_description, dbo.location.description AS location_description, dbo.location.code, 
		dbo.sites.site_name, dbo.sites.description AS site_description,  
                      dbo.item.company_id, dbo.vItemTrackBy.serial_number, dbo.vItemTrackBy.date_code, dbo.vItemTrackBy.pallet, dbo.vItemTrackBy.lot, 
                      dbo.item.record_status
FROM         dbo.item INNER JOIN
                      dbo.vItemTrackBy ON dbo.item.item_id = dbo.vItemTrackBy.item_id INNER JOIN
                      dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id ON dbo.vItemTrackBy.location_id = dbo.location.location_id

	where  not exists (	
	SELECT  * 
	
	from dbo.vAuditInfo   
	where  trans_date >= @start_date 
	and  dbo.item.item_number= dbo.vAuditInfo.item_number
	and  dbo.sites.site_name= dbo.vAuditInfo.site_name
	and  dbo.location.code= dbo.vAuditInfo.code
	and dbo.vItemTrackBy.serial_number = dbo.vAuditInfo.serial_number
	and dbo.vItemTrackBy.date_code = dbo.vAuditInfo.date_code
	and  dbo.vItemTrackBy.pallet = dbo.vAuditInfo.pallet
	and dbo.vItemTrackBy.lot = dbo.vAuditInfo.lot
	
	)
end

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO




CREATE PROCEDURE SpSetupWaspReader
 
AS
SET NOCOUNT ON
 
 
if  exists (select * from dbo.sysusers where name = N'WaspReader' and uid < 16382)
	exec sp_dropuser WaspReader
 

if not exists (select * from master.dbo.syslogins where loginname = N'WaspReader')
BEGIN
	declare @logindb nvarchar(132), @loginlang nvarchar(132) select @logindb = N'master', @loginlang = N'us_english'
	if @logindb is null or not exists (select * from master.dbo.sysdatabases where name = @logindb)
		select @logindb = N'master'
	if @loginlang is null or (not exists (select * from master.dbo.syslanguages where name = @loginlang) and @loginlang <> N'us_english')
		select @loginlang = @@language
	exec sp_addlogin N'WaspReader', null, @logindb, @loginlang
END
 

if not exists (select * from dbo.sysusers where name = N'WaspReader' and uid < 16382)
	EXEC sp_grantdbaccess N'WaspReader', N'WaspReader'
 

 

exec sp_addrolemember N'db_datareader', N'WaspReader'
 

 

exec sp_password null, null, WaspReader
 


------------------------------------------------
--   Set Permission for WaspReader Account to 
--   exec stored procedures 
------------------------------------------------

 

DECLARE @spname varchar(255)
DECLARE @sql varchar(255)

DECLARE SPnames CURSOR FOR
select distinct so.[Name]
from sysobjects so
where so.[Type] = 'P' and so.[Name] like 'Sp%'

OPEN SPnames

 
WHILE 1=1
begin
   	FETCH SPnames INTO @spname 
	if (@@FETCH_STATUS <> 0) break
	select @sql = 'grant EXECUTE ON [dbo].[' + @spname +']  TO [WaspReader]'
	exec(@sql)
end

CLOSE SPnames
DEALLOCATE SPnames

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO


CREATE PROCEDURE [dbo].[SpSumNotes]


AS
SET NOCOUNT ON

create   table #t1 ( 
other_id int,
table_name varchar(50) null,
note_text varchar(7000) null)

DECLARE @otherid int,
@lastid int,
@lastname varchar(50),
@tablename varchar(50),
@notetext varchar(1000),
@notedate varchar(20),
@output varchar(7000),
@err int

 
select distinct other_id, table_name
into #t2
from vNotes
 
DECLARE id_cur CURSOR  FOR
SELECT other_id, table_name FROM #t2 ORDER BY other_id



open id_cur

DECLARE note_cur CURSOR  FOR
SELECT other_id, table_name, note_text, note_date FROM vNotes ORDER BY other_id
 


OPEN note_cur

while 1=1
begin
	FETCH id_cur INTO @lastid, @lastname
	if (@@fetch_status<>0) break
 	set @output = ''


 

WHILE 1= 1

BEGIN

	FETCH note_cur INTO @otherid, @tablename, @notetext, @notedate
 	if (@@fetch_status<>0) break
 	 

	IF (@otherid =@lastid and @tablename = @lastname)
	BEGIN

		
		set @output =  @output + @notetext + char(40) + @notedate  + char(41) + char(13)
	 
	END
	 
	 
	 
	 

END
	
	INSERT #t1 (other_id, table_name, note_text)   VALUES (@lastid, @lastname, @output)
	
	close note_cur
	open note_cur
	 

end --id_cur

	 

DEALLOCATE note_cur
DEALLOCATE id_cur


 
SET NOCOUNT OFF

SELECT     other_id, table_name, note_text  from #t1
 

drop table #t1
drop table #t2

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO


CREATE PROCEDURE [dbo].[SpSumNotes4Audits]


AS
 
SELECT  distinct   note_id as other_id, table_name, note_text  
from Notes
where table_name = 'audit_transactions' and record_status=1 and note_text <>''

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO











CREATE PROCEDURE [dbo].[SpSumNotes4Customers]


AS

SELECT  distinct   note_id as other_id, table_name, note_text  
from Notes
where table_name = 'customer' and record_status=1 and note_text <>''
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO






CREATE PROCEDURE [dbo].[SpSumNotes4Inventories]


AS
 

SELECT  distinct   note_id as other_id, table_name, note_text  
from Notes
where table_name = 'inventory_transactions' and record_status=1 and note_text <>''
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO






CREATE PROCEDURE [dbo].[SpSumNotes4Items]


AS
SELECT  distinct   note_id as other_id, table_name, note_text  
from Notes
where table_name = 'item' and record_status=1 and note_text <>''
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO






CREATE PROCEDURE [dbo].[SpSumNotes4Locations]


AS
SELECT distinct    note_id as other_id, table_name, note_text  
 
from Notes
where table_name = 'location' and record_status=1 and note_text <>''
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO






CREATE PROCEDURE [dbo].[SpSumNotes4Manufacturers]


AS
 

SELECT  distinct   note_id as other_id, table_name, note_text  
from Notes
where table_name = 'manufacturer' and record_status=1 and note_text <>''
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO



CREATE PROCEDURE [dbo].[SpSumNotes4Sites]


AS
SELECT  distinct   note_id as other_id, table_name, note_text  
from Notes
where table_name = 'sites' and record_status=1 and note_text <>''
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO






CREATE PROCEDURE [dbo].[SpSumNotes4Vendors]


AS
 

SELECT  distinct   note_id as other_id, table_name, note_text  
from Notes
where table_name = 'supplier' and record_status=1 and note_text <>''
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO










CREATE PROCEDURE SpSupplierInfo


AS
SET NOCOUNT ON

SELECT     
supplier_id, 
supplier_number, 
name, 
email, 
website, 
contact_name, 
record_status,
company_id
into #t1
FROM         dbo.supplier
 

select  Supplier_id, phone_number, extension
into #t2
FROM         dbo.Supplier LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Supplier.Supplier_id AND dbo.phone.table_name = 'supplier' and dbo.phone.phone_type_id=1
 

select  Supplier_id,phone_number as 'Fax'
into #t3
FROM         dbo.Supplier LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Supplier.Supplier_id AND dbo.phone.table_name = 'supplier' and dbo.phone.phone_type_id=2
 

select Supplier_id,phone_number  as 'cPhone' ,extension as 'cExtension'
into #t4
FROM         dbo.Supplier LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Supplier.Supplier_id AND dbo.phone.table_name = 'supplier' and dbo.phone.phone_type_id=4
 

select Supplier_id,phone_number as 'cCell' 
into #t5
FROM         dbo.Supplier LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Supplier.Supplier_id AND dbo.phone.table_name = 'supplier' and dbo.phone.phone_type_id=2
 

select Supplier_id,phone_number as 'cFax' 
into #t6
FROM         dbo.Supplier LEFT OUTER JOIN
                      dbo.phone ON dbo.phone.phone_id = dbo.Supplier.Supplier_id AND dbo.phone.table_name = 'supplier' and dbo.phone.phone_type_id=3
 

SET NOCOUNT OFF

SELECT     
#t1.Supplier_id, 
supplier_number, 
#t1.name, 
email, 
website,
contact_name, 
record_status
company_id,
phone_number, 
extension,
fax,
cphone,
cextension,
ccell,
cfax

from #t1 inner join #t2 on #t1.Supplier_id = #t2.Supplier_id
inner join #t3 on #t3.Supplier_id = #t2.Supplier_id
inner join #t4 on #t4.Supplier_id = #t2.Supplier_id
inner join #t5 on #t5.Supplier_id = #t2.Supplier_id
inner join #t6 on #t6.Supplier_id = #t2.Supplier_id

where #t1.supplier_id>0

drop table #t1
drop table #t2
drop table #t3
drop table #t4
drop table #t5
drop table #t6

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO




print ''
print '------------------------------------'
print '-- Step N-2. updates to [transaction_types]    '
print '------------------------------------'


if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[transaction_types]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[transaction_types]

CREATE TABLE [dbo].[transaction_types] (
	[trans_type_no] [int] NOT NULL ,
	[trans_description] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]
GO

delete from transaction_types

insert into transaction_types (trans_type_no,trans_description) values (100,'Add');
insert into transaction_types (trans_type_no,trans_description) values (150,'Remove');
insert into transaction_types (trans_type_no,trans_description) values (200,'Move To');
insert into transaction_types (trans_type_no,trans_description) values (250,'Move From');
insert into transaction_types (trans_type_no,trans_description) values (300,'Check In');
insert into transaction_types (trans_type_no,trans_description) values (350,'Check Out');
insert into transaction_types (trans_type_no,trans_description) values (400,'Adjust In');
insert into transaction_types (trans_type_no,trans_description) values (450,'Adjust Out');
insert into transaction_types (trans_type_no,trans_description) values (500,'Audit In');
insert into transaction_types (trans_type_no,trans_description) values (550,'Audit');
insert into transaction_types (trans_type_no,trans_description) values (600,'Maintenance');

go

update report_labels set db_field_report='trans_date' WHERE     (rpt_id = 610) and db_field_report='entry_date'
go

DELETE FROM report_names WHERE     (rpt_id = 1003)
DELETE FROM report_names WHERE     (rpt_id = 406)
DELETE FROM report_names WHERE     (rpt_id = 111)
go

UPDATE    report_names SET rpt_name = 'Supplier By Name Report', rpt_default_name = 'Supplier By Name Report' WHERE     rpt_id = 1001


if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[vPendingItems]') and OBJECTPROPERTY(id, N'IsView') = 1)
drop view [dbo].[vPendingItems]
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE VIEW dbo.vPendingItems
AS
SELECT     dbo.inventory_transactions.trans_date, dbo.inventory_transactions.entry_date, dbo.inventory_transactions.date_acquired, 
                      dbo.inventory_transactions.adjust_type, dbo.inventory_transactions.quantity, dbo.inventory_transactions.cost, 
                      dbo.inventory_transactions.serial_number, dbo.inventory_transactions.date_code, dbo.inventory_transactions.po, dbo.inventory_transactions.lot, 
                      dbo.inventory_transactions.pallet, dbo.inventory_transactions.print_label_no, dbo.item.item_number, dbo.item.description AS item_description, 
                      dbo.item.cost AS item_cost, dbo.item.avgcost, dbo.item.alt_item_number, dbo.item.list_price, dbo.item.sale_price, 
                      dbo.inventory_transactions.company_id, dbo.location.code AS location, dbo.location.description AS location_description, 
                      dbo.inventory_transactions.user_id, dbo.sites.site_name, dbo.sites.description AS site_description, dbo.supplier.supplier_number, 
                      dbo.supplier.name AS supplier_name
FROM         dbo.supplier INNER JOIN
                      dbo.inventory_transactions INNER JOIN
                      dbo.sites INNER JOIN
                      dbo.location ON dbo.sites.site_id = dbo.location.site_id ON dbo.inventory_transactions.location_id = dbo.location.location_id INNER JOIN
                      dbo.item ON dbo.inventory_transactions.item_id = dbo.item.item_id ON dbo.supplier.supplier_id = dbo.inventory_transactions.supplier_id
WHERE     (dbo.inventory_transactions.trans_type = 100) AND (dbo.inventory_transactions.record_status = 4)

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

delete label_names 
go

----------------------------------------------------
-- Table Name: label_names
----------------------------------------------------
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (201,1002,1,'Location Tags','Location Tags','Location Tags',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (204,1002,4,'Serial Number Tags','Serial Number Tags','Serial Number Tags',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (202,1002,3,'Site Tags','Site Tags','Site Tags',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (301,1003,1,'Employee Badges','Employee Badges','Employee Badges',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (101,1001,-1,'Item Receive Labels','Item Receive Labels','Item Receive Labels',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (103,1001,3,'Shipping Labels','Shipping Labels','Shipping Labels',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (203,1002,3,'PO Number Tags','PO Number Tags','PO Number Tags',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (102,1001,2,'Item Bar Code Labels','Item Bar Code Labels','Item Bar Code Labels',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (1001,1010,1,'New','New','New',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (1002,1010,2,'Browse...','Browse...','Browse...',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (104,1001,-1,'Pending added items','AddTransactionItemLabelDB','Pending added items',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (105,1001,-1,'Load Ticket','LoadTicketDB','Load Ticket',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (401,1004,1,'Inventory Item','Inventory Item','Inventory Item',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (402,1004,2,'Inventory Lot','Inventory Lot','Inventory Lot',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (403,1004,3,'Inventory Pallet','Inventory Pallet','Inventory Pallet',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (404,1004,4,'Inventory DateCode','Inventory DateCode','Inventory DateCode',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (405,1004,5,'Inventory Location','Inventory Location','Inventory Location',null);
insert into label_names (lbl_id,lbl_type,lbl_display_order,lbl_name,lbl_file_name,lbl_default_name,lbl_tool_tips) values (406,1004,6,'Inventory Serial Number','Inventory Serial Number','Inventory Serial Number',null);
GO




print '.. recreate trDateUpdated'

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[trDateUpdated]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[trDateUpdated]
GO

CREATE TRIGGER trDateUpdated ON dbo.item 
FOR INSERT, UPDATE 
AS
	update item set date_updated = getdate() where item_id in (select item_id from inserted)

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO



